@@ -29,7 +29,7 @@
 *
 * Version Creation Date:   5/5/00
 *
-* $Revision: 1.31 $
+* $Revision: 1.34 $
 *
 * File Description: 
 *
@@ -74,6 +74,12 @@ NLM_EXTERN CONN PubSeqFetchOpenConnection (
   Int4 flags
 );
 
+NLM_EXTERN CONN PubSeqFetchOpenConnectionString (
+  CharPtr id,
+  Int2 retcode,
+  Int4 flags
+);
+
 NLM_EXTERN CONN PubSeqFetchTraceOpenConnection (
   Uint4 tid,
   Int2 retcode,
@@ -145,12 +151,33 @@ NLM_EXTERN PubmedEntryPtr PubMedSynchronousQuery (
   Int4 uid
 );
 
+NLM_EXTERN SeqEntryPtr PubSeqSynchronousQueryEx (
+  Int4 uid,
+  Int2 retcode,
+  Int4 flags,
+  CharPtr id_str
+);
+
 NLM_EXTERN SeqEntryPtr PubSeqSynchronousQuery (
   Int4 uid,
   Int2 retcode,
   Int4 flags
 );
 
+NLM_EXTERN SeqEntryPtr PubSeqSynchronousQueryId (
+  SeqIdPtr sip,
+  Int2 retcode,
+  Int4 flags
+);
+
+NLM_EXTERN SeqIdPtr SeqIdFromPubSeqString (CharPtr str);
+
+NLM_EXTERN SeqEntryPtr PubSeqSynchronousQueryString (
+  CharPtr str,
+  Int2 retcode,
+  Int4 flags
+);
+
 NLM_EXTERN SeqEntryPtr PubSeqSynchronousQueryTI (
   Uint4 tid,
   Int2 retcode,
@@ -340,7 +367,8 @@ NLM_EXTERN Boolean PubSeqFetchEnableEx (
   Boolean seqidtogi,
   Boolean gitoseqid,
   Boolean precache,
-  Boolean seqidset
+  Boolean seqidset,
+  Int4 flags
 );
 
 NLM_EXTERN void PubSeqFetchDisable (
