@@ -1,4 +1,4 @@
-/* $Id: redo_alignment.h,v 1.12 2007/10/11 14:25:37 kazimird Exp $
+/* $Id: redo_alignment.h,v 1.15 2012/06/04 14:49:33 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -43,6 +43,9 @@
 #include <algo/blast/composition_adjustment/smith_waterman.h>
 #include <algo/blast/composition_adjustment/compo_heap.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 /**
  * Within the composition adjustment module, an object of type
@@ -203,10 +206,13 @@ typedef int
 get_range_type(const BlastCompo_MatchingSequence * sequence,
                const BlastCompo_SequenceRange * range,
                BlastCompo_SequenceData * data,
-	       const BlastCompo_SequenceData * queryData,
-	       const int queryOffset,
+	       const BlastCompo_SequenceData * origQuery,
+               const BlastCompo_SequenceRange * q_range,
+               BlastCompo_SequenceData * q_data,
 	       const BlastCompo_Alignment *align,
-	       const Boolean shouldTestIdentical);
+	       const Boolean shouldTestIdentical,
+	       const ECompoAdjustModes compo_adjust_mode,
+	       const Boolean isSmithWaterman);
 
 /**
  * Function type: Calculate the traceback for one alignment by
@@ -321,6 +327,7 @@ typedef struct Blast_RedoAlignParams {
                                  relative-entropy based composition
                                  adjustment. */
     int subject_is_translated; /**< true if the subject is translated */
+    int query_is_translated; /**< true if the query is translated */
     int ccat_query_length;  /**< length of the concatenated query, or
                                 just the length of the query if not
                                 concatenated */
@@ -347,6 +354,7 @@ Blast_RedoAlignParamsNew(Blast_MatrixInfo ** pmatrix_info,
                          ECompoAdjustModes compo_adjust_mode,
                          int positionBased,
                          int subject_is_translated,
+                         int query_is_translated,
                          int ccat_query_length, int cutoff_s,
                          double cutoff_e, int do_link_hsps,
                          const Blast_RedoAlignCallbacks * callbacks);
@@ -463,4 +471,8 @@ int BlastCompo_EarlyTermination(double evalue,
                                 BlastCompo_Heap significantMatches[],
                                 int numQueries);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
