@@ -1,4 +1,4 @@
-/* $Id: blast_engine.h,v 1.57 2006/11/29 17:25:50 bealer Exp $
+/* $Id: blast_engine.h,v 1.58 2010/12/02 16:14:52 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -174,6 +174,40 @@ Blast_RunPreliminarySearch(EBlastProgramType program,
    const PSIBlastOptions* psi_options, const BlastDatabaseOptions* db_options, 
    BlastHSPStream* hsp_stream, BlastDiagnostics* diagnostics);
 
+
+/** Same as above, with support for user interrupt function
+ * @param program_number Type of BLAST program [in]
+ * @param query The query sequence [in]
+ * @param query_info Additional query information [in]
+ * @param seq_src Structure containing BLAST database [in]
+ * @param score_options Hit scoring options [in]
+ * @param sbp Scoring and statistical parameters [in]
+ * @param lookup_wrap The lookup table, constructed earlier [in] 
+ * @param word_options Options for processing initial word hits [in]
+ * @param ext_options Options and parameters for the gapped extension [in]
+ * @param hit_options Options for saving the HSPs [in]
+ * @param eff_len_options Options for setting effective lengths [in]
+ * @param psi_options Options specific to PSI-BLAST [in]
+ * @param db_options Options for handling BLAST database [in]
+ * @param hsp_stream Structure for streaming results [in] [out]
+ * @param diagnostics Return statistics containing numbers of hits on 
+ *                    different stages of the search [out]
+ * @param interrupt_search User defined function to interrupt search [in]
+ * @param progress_info User supplied data structure to aid interrupt [in]
+ */
+Int2 
+Blast_RunPreliminarySearchWithInterrupt(EBlastProgramType program, 
+   BLAST_SequenceBlk* query, BlastQueryInfo* query_info, 
+   const BlastSeqSrc* seq_src, const BlastScoringOptions* score_options,
+   BlastScoreBlk* sbp, LookupTableWrap* lookup_wrap,
+   const BlastInitialWordOptions* word_options, 
+   const BlastExtensionOptions* ext_options,
+   const BlastHitSavingOptions* hit_options,
+   const BlastEffectiveLengthsOptions* eff_len_options,
+   const PSIBlastOptions* psi_options, const BlastDatabaseOptions* db_options, 
+   BlastHSPStream* hsp_stream, BlastDiagnostics* diagnostics,
+   TInterruptFnPtr interrupt_search, SBlastProgress* progress_info);
+
 /** Gapped extension function pointer type */
 typedef Int2 (*BlastGetGappedScoreType) 
      (EBlastProgramType, /**< @todo comment function pointer types */
