@@ -1,4 +1,4 @@
-/* $Id: blast_nalookup.c,v 1.10 2008/07/17 17:55:44 kazimird Exp $
+/* $Id: blast_nalookup.c,v 1.12 2009/06/22 13:54:32 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -36,7 +36,7 @@
 
 #ifndef SKIP_DOXYGEN_PROCESSING
 static char const rcsid[] =
-    "$Id: blast_nalookup.c,v 1.10 2008/07/17 17:55:44 kazimird Exp $";
+    "$Id: blast_nalookup.c,v 1.12 2009/06/22 13:54:32 kazimird Exp $";
 #endif                          /* SKIP_DOXYGEN_PROCESSING */
 
 /** bitfield used to detect ambiguities in uncompressed
@@ -333,20 +333,20 @@ static BlastSeqLoc* s_SeqLocListInvert(const BlastSeqLoc* locations, Int4 length
      ASSERT(locations);
 
      start = 0;
-     stop = MAX( 0, locations->ssr->left);
+     stop = MAX( 0, locations->ssr->left-1);
 
      if (stop - start > 2)
         tail = BlastSeqLocNew(&retval, start, stop);
 
      while (locations)
      {
-         start = locations->ssr->right;
+         start = locations->ssr->right+1;
          locations = locations->next;
 
          if (locations)
-             stop = locations->ssr->left;
+             stop = locations->ssr->left-1;
          else
-             stop = length;
+             stop = length-1;
 
          if (stop - start > 2)
          {
@@ -359,6 +359,22 @@ static BlastSeqLoc* s_SeqLocListInvert(const BlastSeqLoc* locations, Int4 length
      return retval;
 }
 
+/** Determine whether mask at hash is enabled from the QuerySetUpOptions */
+static Boolean s_HasMaskAtHashEnabled(const QuerySetUpOptions* query_options)
+{
+    if ( !query_options ) {
+        return FALSE;
+    }
+    if (SBlastFilterOptionsMaskAtHash(query_options->filtering_options)) {
+        return TRUE;
+    }
+    if (query_options->filter_string && 
+        strstr(query_options->filter_string, "m")) {
+        return TRUE;
+    }
+    return FALSE;
+}
+
 Int4 BlastSmallNaLookupTableNew(BLAST_SequenceBlk* query, 
                            BlastSeqLoc* locations,
                            BlastSmallNaLookupTable * *lut,
@@ -388,11 +404,10 @@ Int4 BlastSmallNaLookupTableNew(BLAST_SequenceBlk* query,
                                       BITS_PER_NUC,
                                       lookup->lut_word_length,
                                       query, locations);
-    if (locations && lookup->word_length > lookup->lut_word_length && 
-       ((query_options->filtering_options && SBlastFilterOptionsMaskAtHash(query_options->filtering_options)) ||
-        (query_options->filter_string && strstr(query_options->filter_string, "m"))))
-    {
-       lookup->masked_locations = s_SeqLocListInvert(locations, query->length);
+    if (locations && 
+        lookup->word_length > lookup->lut_word_length && 
+        s_HasMaskAtHashEnabled(query_options)) {
+        lookup->masked_locations = s_SeqLocListInvert(locations, query->length);
     }
 
     status = s_BlastSmallNaLookupFinalize(thin_backbone, lookup, query);
@@ -534,6 +549,7 @@ Int4 BlastNaLookupTableNew(BLAST_SequenceBlk* query,
                            BlastSeqLoc* locations,
                            BlastNaLookupTable * *lut,
                            const LookupTableOptions * opt, 
+                           const QuerySetUpOptions* query_options,
                            Int4 lut_width)
 {
     Int4 **thin_backbone;
@@ -557,6 +573,11 @@ Int4 BlastNaLookupTableNew(BLAST_SequenceBlk* query,
                                       BITS_PER_NUC,
                                       lookup->lut_word_length,
                                       query, locations);
+    if (locations && 
+        lookup->word_length > lookup->lut_word_length && 
+        s_HasMaskAtHashEnabled(query_options)) {
+        lookup->masked_locations = s_SeqLocListInvert(locations, query->length);
+    }
     s_BlastNaLookupFinalize(thin_backbone, lookup);
     sfree(thin_backbone);
     return 0;
@@ -566,6 +587,8 @@ BlastNaLookupTable *BlastNaLookupTableDestruct(BlastNaLookupTable * lookup)
 {
     sfree(lookup->thick_backbone);
     sfree(lookup->overflow);
+    if (lookup->masked_locations)
+       lookup->masked_locations = BlastSeqLocFree(lookup->masked_locations);
     sfree(lookup->pv);
     sfree(lookup);
     return NULL;
@@ -912,6 +935,7 @@ s_FillContigMBTable(BLAST_SequenceBlk* query,
 Int2 BlastMBLookupTableNew(BLAST_SequenceBlk* query, BlastSeqLoc* location,
         BlastMBLookupTable** mb_lt_ptr,
         const LookupTableOptions* lookup_options,
+        const QuerySetUpOptions* query_options,
         Int4 approx_table_entries,
         Int4 lut_width)
 {
@@ -944,6 +968,12 @@ Int2 BlastMBLookupTableNew(BLAST_SequenceBlk* query, BlastSeqLoc* location,
       return -1;
    }
 
+   if (location && 
+       mb_lt->word_length > mb_lt->lut_word_length && 
+       s_HasMaskAtHashEnabled(query_options)) {
+       mb_lt->masked_locations = s_SeqLocListInvert(location, query->length);
+   }
+
    /* Allocate the PV array. To fit in the external cache of 
       latter-day microprocessors, the PV array cannot have one
       bit for for every lookup table entry. Instead we choose
@@ -1014,6 +1044,8 @@ BlastMBLookupTable* BlastMBLookupTableDestruct(BlastMBLookupTable* mb_lt)
    sfree(mb_lt->hashtable2);
    sfree(mb_lt->next_pos2);
    sfree(mb_lt->pv_array);
+   if (mb_lt->masked_locations)
+      mb_lt->masked_locations = BlastSeqLocFree(mb_lt->masked_locations);
    sfree(mb_lt);
    return mb_lt;
 }
