@@ -1,4 +1,4 @@
-/* $Id: blast_options.h,v 1.154 2009/06/15 18:34:32 kazimird Exp $
+/* $Id: blast_options.h,v 1.161 2012/05/21 15:56:03 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -60,6 +60,7 @@ extern "C" {
                                           (contiguous megablast) */
 #define BLAST_WINDOW_SIZE_DISC 40  /**< default window size 
                                           (discontiguous megablast) */
+#define BLAST_SCAN_RANGE_NUCL 0   /**< default scan range (blastn) */
 
 /** length of word to trigger an extension. */
 #define BLAST_WORDSIZE_PROT 3   /**< default word size (all protein searches) */
@@ -118,7 +119,7 @@ extern "C" {
                                          based gapped extensions) */
 #define BLAST_GAP_X_DROPOFF_NUCL 30 /**< default dropoff for non-greedy
                                          nucleotide gapped extensions */
-#define BLAST_GAP_X_DROPOFF_GREEDY 30 /**< default dropoff for greedy
+#define BLAST_GAP_X_DROPOFF_GREEDY 25 /**< default dropoff for greedy
                                          nucleotide gapped extensions */
 #define BLAST_GAP_X_DROPOFF_TBLASTX 0 /**< default dropoff for tblastx */
 
@@ -145,9 +146,10 @@ extern "C" {
                                      value exceeds this number are discarded */
 #define BLAST_HITLIST_SIZE 500 /**< Number of database sequences to save hits 
                                   for */
-/** Defaults for PSI-BLAST options */
+/** Defaults for PSI-BLAST and DELTA-BLAST options */
 #define PSI_INCLUSION_ETHRESH 0.002 /**< Inclusion threshold for PSI BLAST */
 #define PSI_PSEUDO_COUNT_CONST 0 /**< Pseudo-count constant for PSI-BLAST */
+#define DELTA_INCLUSION_ETHRESH 0.05 /**< Inclusion threshold for DELTA-BLAST */
 
 /** Default genetic code for query and/or database */
 #define BLAST_GENETIC_CODE 1  /**< Use the standard genetic code for converting
@@ -169,7 +171,9 @@ typedef enum {
     ePhiLookupTable,  /**< protein lookup table specialized for phi-blast */
     ePhiNaLookupTable,  /**< nucleotide lookup table for phi-blast */
     eRPSLookupTable, /**< RPS lookup table (rpsblast and rpstblastn) */
-    eIndexedMBLookupTable /**< use database index as a lookup structure */
+    eIndexedMBLookupTable, /**< use database index as a lookup structure */
+    eMixedMBLookupTable /**< use when some volumes are searched with index and 
+                             some are not */
 } ELookupTableType;
 
 /** Options needed to construct a lookup table 
@@ -207,7 +211,7 @@ typedef struct SSegOptions {
 } SSegOptions;
 
 /// Default value for repeats database filtering
-#define kDefaultRepeatFilterDb "humrep"
+#define kDefaultRepeatFilterDb "repeat/repeat_9606"
 
 /** Filtering options for organsim specific repeats filtering.   
     Currently this consist of only the db name but could be expanded
@@ -254,6 +258,7 @@ typedef struct BlastInitialWordOptions {
    double gap_trigger; /**< Score in bits for starting gapped extension */
    Int4 window_size; /**< Maximal allowed distance between 2 hits in case 2 
                         hits are required to trigger the extension */
+   Int4 scan_range;  /**< Maximal number of gaps allowed between 2 hits */
    double x_dropoff; /**< X-dropoff value (in bits) for the ungapped 
                          extension */
    EBlastProgramType program_number; /**< indicates blastn, blastp, etc. */
@@ -342,6 +347,9 @@ typedef struct BlastHitSavingOptions {
    Int4 culling_limit; /**< If the query range of an HSP is contained in
                             at least this many higher-scoring HSPs, throw
                             away the HSP as redundant (turned off if zero) */
+   Int4 mask_level; /**< Only keep the highest scoring HSP when more than
+                          one HSP overlaps the same region of the query by
+                          more than or equal to mask_level %. -RMH- */
 
    /********************************************************************/
    /* Merge all these in a structure for clarity? */
@@ -363,6 +371,13 @@ typedef struct BlastHitSavingOptions {
     */
    BlastHSPFilteringOptions* hsp_filt_opt;
 
+   /** Low-score option.  Do not pass ungapped alignments on for later processing if
+    * the hitlist is already full of other alignments unless the ungapped aligment 
+    * is above the fraction X of the least significant database match.
+    * zero should turn this off.
+    */
+   double low_score_perc;
+
 } BlastHitSavingOptions;
 
 /** Scoring options block 
@@ -377,6 +392,8 @@ typedef struct BlastScoringOptions {
    Int2 reward;      /**< Reward for a match */
    Int2 penalty;     /**< Penalty for a mismatch */
    Boolean gapped_calculation; /**< gap-free search if FALSE */
+   Boolean complexity_adjusted_scoring; /**< Use cross_match-like complexity
+                                           adjustment on raw scores. -RMH- */
    Int4 gap_open;    /**< Extra penalty for starting a gap */
    Int4 gap_extend;  /**< Penalty for each gap residue */
 
@@ -462,6 +479,7 @@ typedef struct PSIBlastOptions {
 
 } PSIBlastOptions;
 
+
 /** Options used to create the ReadDBFILE structure 
  *  Include database name and various information for restricting the database
  *  to a subset.
