@@ -1,4 +1,4 @@
-/* $Id: blast_traceback.h,v 1.51 2009/03/26 14:34:31 kazimird Exp $
+/* $Id: blast_traceback.h,v 1.52 2010/12/02 16:14:52 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -175,6 +175,44 @@ Blast_RunTracebackSearch(EBlastProgramType program,
    SPHIPatternSearchBlk* pattern_blk, BlastHSPResults** results);
 
 
+/** Entry point from the API level to perform the traceback stage of a BLAST 
+ * search, given the source of HSP lists, obtained from the preliminary stage. 
+ * The parameters internal to the engine are calculated here independently of 
+ * the similar calculation in the preliminary stage, effectively making the two 
+ * stages independent of each other.
+ * @param program BLAST program type [in]
+ * @param query Query sequence(s) structure [in]
+ * @param query_info Additional query information [in]
+ * @param seq_src Source of subject sequences [in]
+ * @param score_options Scoring options [in]
+ * @param ext_options Word extension options, needed for cutoff scores 
+ *                    calculation only [in]
+ * @param hit_options Hit saving options [in]
+ * @param eff_len_options Options for calculating effective lengths [in]
+ * @param db_options Database options (database genetic code) [in]
+ * @param psi_options PSI BLAST options [in]
+ * @param sbp Scoring block with statistical parameters and matrix [in]
+ * @param hsp_stream Source of HSP lists. [in]
+ * @param rps_info RPS database information structure [in]
+ * @param pattern_blk PHI BLAST auxiliary data structure [in]
+ * @param results Where to save the results after traceback. [out]
+ * @param interrupt_search User specified function to interrupt search [in]
+ * @param progress_info User supplied data structure to aid interrupt [in]
+ */
+NCBI_XBLAST_EXPORT
+Int2 
+Blast_RunTracebackSearchWithInterrupt(EBlastProgramType program, 
+   BLAST_SequenceBlk* query, BlastQueryInfo* query_info, 
+   const BlastSeqSrc* seq_src, const BlastScoringOptions* score_options,
+   const BlastExtensionOptions* ext_options,
+   const BlastHitSavingOptions* hit_options,
+   const BlastEffectiveLengthsOptions* eff_len_options,
+   const BlastDatabaseOptions* db_options, 
+   const PSIBlastOptions* psi_options, BlastScoreBlk* sbp,
+   BlastHSPStream* hsp_stream, const BlastRPSInfo* rps_info, 
+   SPHIPatternSearchBlk* pattern_blk, BlastHSPResults** results,
+   TInterruptFnPtr interrupt_search, SBlastProgress* progress_info);
+
 #ifdef __cplusplus
 }
 #endif
