@@ -1,4 +1,4 @@
-/* $Id: ncbi_math.c,v 1.16 2005/04/27 19:06:25 coulouri Exp $
+/* $Id: ncbi_math.c,v 1.18 2012/02/01 17:14:32 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -30,7 +30,7 @@
 
 #ifndef SKIP_DOXYGEN_PROCESSING
 static char const rcsid[] = 
-    "$Id: ncbi_math.c,v 1.16 2005/04/27 19:06:25 coulouri Exp $";
+    "$Id: ncbi_math.c,v 1.18 2012/02/01 17:14:32 kazimird Exp $";
 #endif /* SKIP_DOXYGEN_PROCESSING */
 
 #include <algo/blast/core/ncbi_math.h>
@@ -484,63 +484,16 @@ double BLAST_LnFactorial (double x) {
         
 }
 
-/*
- * ===========================================================================
- *
- * $Log: ncbi_math.c,v $
- * Revision 1.16  2005/04/27 19:06:25  coulouri
- * remove incorrect optimization
- *
- * Revision 1.15  2005/03/10 16:10:58  papadopo
- * doxygen fixes
- *
- * Revision 1.14  2005/03/08 18:28:55  papadopo
- * do not use a const int to declare the dimension of an array
- *
- * Revision 1.13  2005/03/08 17:42:29  papadopo
- * add doxygen comments, refactor several functions
- *
- * Revision 1.12  2005/03/07 18:46:05  camacho
- * Removed dead code
- *
- * Revision 1.11  2004/11/18 21:26:15  dondosha
- * Added BLAST_Gdb3, needed for greedy alignment; removed extern from function signatures; renamed static functions according to C++ toolkit guidelines
- *
- * Revision 1.10  2004/11/02 17:56:48  camacho
- * Add DOXYGEN_SKIP_PROCESSING to guard rcsid string
- *
- * Revision 1.9  2004/06/08 17:30:07  dondosha
- * Compiler warnings fixes
- *
- * Revision 1.8  2004/05/19 14:52:03  camacho
- * 1. Added doxygen tags to enable doxygen processing of algo/blast/core
- * 2. Standardized copyright, CVS $Id string, $Log and rcsid formatting and i
- *    location
- * 3. Added use of @todo doxygen keyword
- *
- * Revision 1.7  2003/12/05 16:03:57  camacho
- * Remove compiler warnings
- *
- * Revision 1.6  2003/09/26 20:39:32  dondosha
- * Rearranged code so it compiles
- *
- * Revision 1.5  2003/09/26 19:01:59  madden
- * Prefix ncbimath functions with BLAST_
- *
- * Revision 1.4  2003/09/10 21:36:29  dondosha
- * Removed Nlm_ prefix from math functions definitions
- *
- * Revision 1.3  2003/08/25 22:32:51  dondosha
- * Added #ifndef for definition of DBL_EPSILON
- *
- * Revision 1.2  2003/08/11 15:02:00  dondosha
- * Added algo/blast/core to all #included headers
- *
- * Revision 1.1  2003/08/02 16:31:48  camacho
- * Moved ncbimath.c -> ncbi_math.c
- *
- * Revision 1.1  2003/08/01 21:03:46  madden
- * Cleaned up version of file for C++ toolkit
- *
- * ===========================================================================
- */
+#ifdef _NCBILCL_ /* C Toolkit */
+#  ifdef OS_UNIX
+#    define HAVE_ERF 1
+#  endif
+#  ifdef IS_BIG_ENDIAN
+#    define WORDS_BIGENDIAN 1
+#  endif
+#endif
+/* erf/erfc implementation, cloned from the C++ Toolkit's util directory. */
+#define NCBI_Erf  BLAST_Erf
+#define NCBI_ErfC BLAST_ErfC
+#define NCBI_INCLUDE_NCBI_ERF_C 1
+#include "ncbi_erf.c"
