@@ -1,4 +1,4 @@
-/* $Id: phi_gapalign.c,v 1.9 2005/11/30 18:25:32 papadopo Exp $
+/* $Id: phi_gapalign.c,v 1.15 2008/07/17 17:55:44 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -51,18 +51,13 @@
  *    s_PHIBlastAlignPatterns(...)    
  *    Right score = Blast_SemiGappedAlign(...) 
  * </pre>
- * @todo FIXME The alignment code uses complicated representation of the
- *             pattern, and may produce wrong alignments of patterns in case
- *             when pattern has variable length pieces longer than 32 residues.
  */
 
 #ifndef SKIP_DOXYGEN_PROCESSING
 static char const rcsid[] = 
-    "$Id: phi_gapalign.c,v 1.9 2005/11/30 18:25:32 papadopo Exp $";
+    "$Id: phi_gapalign.c,v 1.15 2008/07/17 17:55:44 kazimird Exp $";
 #endif /* SKIP_DOXYGEN_PROCESSING */
 
-#include <algo/blast/core/blast_options.h>
-#include <algo/blast/core/blast_def.h>
 #include <algo/blast/core/phi_gapalign.h>
 #include <algo/blast/core/blast_encoding.h>
 #include <algo/blast/core/blast_gapalign.h>
@@ -293,7 +288,6 @@ s_BandedAlign(Uint1 *seq1, Uint1 *seq2,Int4 start1, Int4 start2,
 { 
 	Int4 score; /*score to return*/
         Int4 i; /*index over sequences*/
-	Int4 band; /*width of band*/
     
 	lowDiag = MIN(MAX(-start1, lowDiag),MIN(start2-start1,0));
 	highDiag = MAX(MIN(start2, highDiag),MAX(start2-start1,0));
@@ -308,7 +302,7 @@ s_BandedAlign(Uint1 *seq1, Uint1 *seq2,Int4 start1, Int4 start2,
         return -s_GapCost(gapOpen, gapExtend, start2);
 	}
 
-	if ((band = highDiag-lowDiag+1) <= 1) {
+	if ((highDiag-lowDiag+1) <= 1) {
         score = 0;
         for (i = 1; i <= start1; i++) {
             GapPrelimEditBlockAdd(alignScript, eGapAlignSub, 1);
@@ -709,8 +703,8 @@ s_PHIGappedAlignment(BLAST_SequenceBlk* query_blk,
       score_left = 
          Blast_SemiGappedAlign(query, subject, q_length, s_length,
             &private_q_start, &private_s_start, TRUE, NULL, gap_align, 
-            score_params, query_offset, FALSE, TRUE);
-        
+            score_params, query_offset, FALSE, TRUE, NULL);
+      
       gap_align->query_start = q_length - private_q_start + 1;
       gap_align->subject_start = s_length - private_s_start + 1;
       
@@ -727,7 +721,7 @@ s_PHIGappedAlignment(BLAST_SequenceBlk* query_blk,
          subject+s_length, query_blk->length-q_length-1, 
          subject_blk->length-s_length-1, &(gap_align->query_stop), 
          &(gap_align->subject_stop), TRUE, NULL, gap_align, 
-         score_params, q_length, FALSE, FALSE);
+         score_params, q_length, FALSE, FALSE, NULL);
       gap_align->query_stop += q_length;
       gap_align->subject_stop += s_length;
    }
@@ -755,7 +749,8 @@ Int2 PHIGetGappedScore (EBlastProgramType program_number,
         const BlastExtensionParameters* ext_params,
         const BlastHitSavingParameters* hit_params,
         BlastInitHitList* init_hitlist,
-        BlastHSPList** hsp_list_ptr, BlastGappedStats* gapped_stats)
+        BlastHSPList** hsp_list_ptr, BlastGappedStats* gapped_stats,
+        Boolean * fence_hit)
 
 {
    BlastHSPList* hsp_list;
@@ -765,7 +760,11 @@ Int2 PHIGetGappedScore (EBlastProgramType program_number,
    BlastHitSavingOptions* hit_options;
    Int4 pattern_index;
    Int4 num_patterns;
-
+   Int4 HspNumMax=0;
+   
+   /* PHI does not support partial fetching at the moment. */
+   ASSERT(! fence_hit);
+   
    if (!query || !subject || !gap_align || !score_params ||
        !hit_params || !init_hitlist || !hsp_list_ptr)
       return -1;
@@ -774,8 +773,10 @@ Int2 PHIGetGappedScore (EBlastProgramType program_number,
       return 0;
 
    hit_options = hit_params->options;
+   HspNumMax = BlastHspNumMax(score_params->options->gapped_calculation, hit_options);
+
    if (*hsp_list_ptr == NULL)
-      *hsp_list_ptr = hsp_list = Blast_HSPListNew(hit_options->hsp_num_max);
+      *hsp_list_ptr = hsp_list = Blast_HSPListNew(HspNumMax);
    else 
       hsp_list = *hsp_list_ptr;
 
@@ -810,7 +811,7 @@ Int2 PHIGetGappedScore (EBlastProgramType program_number,
 
            /* PHI BLAST does not support query concatenation, so context is 
               always 0. */
-           if (gap_align->score >= hit_params->cutoff_score) {
+           if (gap_align->score >= hit_params->cutoff_score_min) {
                Blast_HSPInit(gap_align->query_start, gap_align->query_stop, 
                              gap_align->subject_start, gap_align->subject_stop, 
                              q_pat_offset, s_pat_offset, 
@@ -865,7 +866,7 @@ Int2 PHIGappedAlignmentWithTraceback(Uint1* query, Uint1* subject,
     score_left = 
        Blast_SemiGappedAlign(query, subject, q_start, s_start, 
            &private_q_length, &private_s_length, FALSE, rev_prelim_tback,
-          gap_align, score_params, q_start, FALSE, TRUE);
+          gap_align, score_params, q_start, FALSE, TRUE, NULL);
     gap_align->query_start = q_start - private_q_length;
     gap_align->subject_start = s_start - private_s_length;
 
@@ -890,7 +891,7 @@ Int2 PHIGappedAlignmentWithTraceback(Uint1* query, Uint1* subject,
           Blast_SemiGappedAlign(query+q_start, subject+s_start, 
              query_length-q_start-1, subject_length-s_start-1, 
              &private_q_length, &private_s_length, FALSE, fwd_prelim_tback,
-             gap_align, score_params, q_start, FALSE, FALSE);
+             gap_align, score_params, q_start, FALSE, FALSE, NULL);
 
        gap_align->query_stop = q_start + private_q_length + 1;
        gap_align->subject_stop = s_start + private_s_length + 1; 
