@@ -29,7 +29,7 @@
 *
 * Version Creation Date:   10/7/94
 *
-* $Revision: 6.12 $
+* $Revision: 6.14 $
 *
 * File Description: 
 *
@@ -39,6 +39,14 @@
 * -------  ----------  -----------------------------------------------------
 *
 * $Log: gather.h,v $
+* Revision 6.14  2006/07/13 17:06:38  bollin
+* use Uint4 instead of Uint2 for itemID values
+* removed unused variables
+* resolved compiler warnings
+*
+* Revision 6.13  2004/10/25 20:13:27  kans
+* added AssignIDsInEntityEx and GatherObjectsInEntityEx to index remotely fetched features
+*
 * Revision 6.12  2002/05/08 18:58:09  kans
 * itemID is Uint4
 *
@@ -209,14 +217,15 @@ typedef struct alignrange{
 *
 *****************************************************************************/
 typedef struct gatherelement {
-	Uint2 itemID, itemtype;
+	Uint4 itemID;
+	Uint2 itemtype;
 	Pointer thisitem;
 	Boolean tempload;
 } GatherElement, PNTR GatherElementPtr;
 
 typedef struct gathercontext {
-	Uint2  entityID ,
-		  itemID;
+	Uint2  entityID;
+    Uint4  itemID;
 	Pointer thisitem,
 		  previtem,
 		  parentitem;
@@ -281,7 +290,7 @@ typedef struct internalgcc {
 	Boolean rev;                /* TRUE if scope->target is on complement */
 	Int2 max_interval;
 	BioseqPtr bsp;              /* for checking a range on a Bioseq */
-	Int2 itemIDs[OBJ_MAX];
+	Uint4 itemIDs[OBJ_MAX];
 	SeqLocPtr segloc;           /* if target is segmented and seglevel > 0 */
 	Int2 first_seg, last_seg;   /* see SeqLocCopyPart() in edutil.h */
 	Int2 segcnt;                /* count of segments in segloc */
@@ -289,7 +298,7 @@ typedef struct internalgcc {
 	BoolPtr found_annot;     /* TRUE if annot found in this region of current Bioseq */
 	                            /*    Not an indication of annot found in this segment */
 	Uint1 locatetype;           /* itemtype to locate */
-	Int2 locateID;              /* itemID to locate */
+	Uint4 locateID;              /* itemID to locate */
 	Pointer locatePtr;          /* data item to locate */
 	ObjMgrDataPtr omdp;         /* top level omdp in entity */
 	Boolean reloaded;           /* TRUE if entity was reloaded from cache by IGCCBuild() */
@@ -372,7 +381,7 @@ NLM_EXTERN Int2 LIBCALL FocusSeqEntry PROTO((SeqEntryPtr sep, GatherScopePtr sco
 *        only those included in GITEM_ defined above will be found
 *
 *****************************************************************************/
-NLM_EXTERN Boolean LIBCALL GatherItem PROTO((Uint2 entityID, Uint2 itemID, Uint2 itemtype,
+NLM_EXTERN Boolean LIBCALL GatherItem PROTO((Uint2 entityID, Uint4 itemID, Uint2 itemtype,
                                    Pointer userdata, GatherItemProc userfunc));
 
 /*****************************************************************************
@@ -401,7 +410,7 @@ NLM_EXTERN Boolean LIBCALL GatherData PROTO((Uint2 entityID, Pointer dataptr, Ui
 *      itemtype is as defined in objmgr.h for OBJ_
 *
 *****************************************************************************/
-NLM_EXTERN Uint2 LIBCALL GatherItemIDByData PROTO((Uint2 entityID, Uint2 itemtype, Pointer dataptr));
+NLM_EXTERN Uint4 LIBCALL GatherItemIDByData PROTO((Uint2 entityID, Uint2 itemtype, Pointer dataptr));
 
 
 /****************************************************************************
@@ -537,7 +546,7 @@ NLM_EXTERN Boolean LIBCALL ReplaceDataForProc PROTO((OMProcControlPtr ompcp, Boo
 *     returns the return from the proc, or OM_MSG_RET_NOPROC if not found
 *
 *****************************************************************************/
-NLM_EXTERN Int2 GatherProcLaunch PROTO((Uint2 proctype, Boolean sel, Uint2 entityID, Uint2 itemID,
+NLM_EXTERN Int2 GatherProcLaunch PROTO((Uint2 proctype, Boolean sel, Uint2 entityID, Uint4 itemID,
                     Uint2 itemtype, Uint2 inputtype, Uint2 subinputtype, Uint2 outputtype, Uint2 suboutputtype));
 
 /*****************************************************************************
@@ -548,7 +557,7 @@ NLM_EXTERN Int2 GatherProcLaunch PROTO((Uint2 proctype, Boolean sel, Uint2 entit
 *
 *****************************************************************************/
 NLM_EXTERN Int2 GatherSpecificProcLaunch PROTO((Uint2 procid, CharPtr procname, Uint2 proctype,
-                                          Boolean sel, Uint2 entityID, Uint2 itemID, Uint2 itemtype));
+                                          Boolean sel, Uint2 entityID, Uint4 itemID, Uint2 itemtype));
 
 /*****************************************************************
 *
@@ -582,6 +591,9 @@ NLM_EXTERN Boolean LIBCALL GatherOverWrite PROTO((Pointer oldptr, Pointer newptr
 *       every object type is visited, otherwise the array length should be OBJ_MAX, and
 *       the elements are from the OBJ_ list.
 *
+*   The Ex versions take a ValNodePtr parameter whose data.ptrvalue fields point to
+*       a Bioseq that contains a SeqAnnot with remotely fetched features.
+*
 *****************************************************************************/
 
 typedef struct gatherobject {
@@ -598,10 +610,36 @@ typedef struct gatherobject {
 
 typedef Boolean (*GatherObjectProc) (GatherObjectPtr gop);
 
-NLM_EXTERN Boolean LIBCALL AssignIDsInEntity (Uint2 entityID, Uint2 datatype, Pointer dataptr);
+NLM_EXTERN Boolean LIBCALL AssignIDsInEntity (
+  Uint2 entityID,
+  Uint2 datatype,
+  Pointer dataptr
+);
 
-NLM_EXTERN Boolean LIBCALL GatherObjectsInEntity (Uint2 entityID, Uint2 datatype, Pointer dataptr,
-                                                  GatherObjectProc callback, Pointer userdata, BoolPtr objMgrFilter);
+NLM_EXTERN Boolean LIBCALL AssignIDsInEntityEx (
+  Uint2 entityID,
+  Uint2 datatype,
+  Pointer dataptr,
+  ValNodePtr extra
+);
+
+NLM_EXTERN Boolean LIBCALL GatherObjectsInEntity (
+  Uint2 entityID,
+  Uint2 datatype,
+  Pointer dataptr,
+  GatherObjectProc callback,
+  Pointer userdata,
+  BoolPtr objMgrFilter
+);
+
+NLM_EXTERN Boolean LIBCALL GatherObjectsInEntityEx (
+  Uint2 entityID,
+  Uint2 datatype, Pointer dataptr,
+  GatherObjectProc callback,
+  Pointer userdata,
+  BoolPtr objMgrFilter,
+  ValNodePtr extra
+);
 
 /*****************************************************************************
 *
@@ -619,7 +657,7 @@ NLM_EXTERN Boolean DeleteMarkedObjects (Uint2 entityID, Uint2 datatype, Pointer
 *
 *****************************************************************************/
 
-NLM_EXTERN Pointer LIBCALL GetPointerForIDs (Uint2 entityID, Uint2 itemID, Uint2 itemtype);
+NLM_EXTERN Pointer LIBCALL GetPointerForIDs (Uint2 entityID, Uint4 itemID, Uint2 itemtype);
 
 /*****************************************************************************
 *
