@@ -65,8 +65,9 @@ static GbFeatName STATIC__ParFlat_GBQual_names[ParFlat_TOTAL_GBQUAL] = {
  {"tag_peptide", Class_text}, { "mating_type", Class_text},
  {"satellite", Class_text}, { "gene_synonym", Class_text},
  {"UniProtKB_evidence", Class_text}, {"haplogroup", Class_text},
- {"artificial_location", Class_text}, {"non_functional", Class_none},
- {"pseudogene", Class_none}, {"mobile_element_type", Class_text}
+ {"artificial_location", Class_text}, {"non_functional", Class_text},
+ {"pseudogene", Class_text}, {"mobile_element_type", Class_text} ,
+ {"gap_type", Class_text }, {"linkage_evidence", Class_text }
 };
 
 NLM_EXTERN GbFeatNamePtr x_ParFlat_GBQual_names(void) {
@@ -85,7 +86,7 @@ CharPtr ParFlat_RptString[ParFlat_TOTAL_Rpt] = {
        "dispersed", "other"};
 
 static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
-   {"allele", 0, {-1, -1, -1, -1, -1}, 19,
+   {"allele", 0, {-1, -1, -1, -1, -1}, 18,
      {
       GBQUAL_citation,
       GBQUAL_db_xref,
@@ -109,8 +110,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1}},
-   {"attenuator", 0, {-1, -1, -1, -1, -1}, 17,
+      -1, -1, -1, -1, -1, -1, -1}},
+   {"attenuator", 0, {-1, -1, -1, -1, -1}, 16,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -132,8 +133,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"C_region", 0, {-1, -1, -1, -1, -1}, 20,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"C_region", 0, {-1, -1, -1, -1, -1}, 19,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -158,8 +159,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1}},
-   {"CAAT_signal", 0, {-1, -1, -1, -1, -1}, 15,
+      -1, -1, -1, -1, -1, -1}},
+   {"CAAT_signal", 0, {-1, -1, -1, -1, -1}, 14,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -179,8 +180,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"CDS", 0, {-1, -1, -1, -1, -1}, 35,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"CDS", 0, {-1, -1, -1, -1, -1}, 34,
      {
       GBQUAL_allele,
       GBQUAL_artificial_location,
@@ -218,7 +219,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_usedin,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
    {"conflict", 1, {
       GBQUAL_citation, -1, -1, -1, -1}, 14,
      {
@@ -242,7 +243,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1}},
-   {"D-loop", 0, {-1, -1, -1, -1, -1}, 15,
+   {"D-loop", 0, {-1, -1, -1, -1, -1}, 14,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -262,8 +263,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"D_segment", 0, {-1, -1, -1, -1, -1}, 20,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"D_segment", 0, {-1, -1, -1, -1, -1}, 19,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -288,8 +289,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1}},
-   {"enhancer", 0, {-1, -1, -1, -1, -1}, 17,
+      -1, -1, -1, -1, -1, -1}},
+   {"enhancer", 0, {-1, -1, -1, -1, -1}, 16,
      {
       GBQUAL_allele,
       GBQUAL_bound_moiety,
@@ -311,7 +312,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1}},
+      -1, -1, -1, -1, -1, -1, -1, -1, -1}},
    {"exon", 0, {-1, -1, -1, -1, -1}, 23,
      {
       GBQUAL_allele,
@@ -335,6 +336,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_pseudo,
       GBQUAL_pseudogene,
       GBQUAL_standard_name,
+      GBQUAL_trans_splicing,
       GBQUAL_usedin,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
@@ -355,7 +357,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"GC_signal", 0, {-1, -1, -1, -1, -1}, 15,
+   {"GC_signal", 0, {-1, -1, -1, -1, -1}, 14,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -375,8 +377,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"gene", 0, {-1, -1, -1, -1, -1}, 23,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"gene", 0, {-1, -1, -1, -1, -1}, 22,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -404,8 +406,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1}},
-    {"iDNA", 0, {-1, -1, -1, -1, -1}, 18,
+      -1, -1, -1}},
+   {"iDNA", 0, {-1, -1, -1, -1, -1}, 17,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -428,7 +430,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1}},
+      -1, -1, -1, -1, -1, -1, -1, -1}},
    {"intron", 0, {-1, -1, -1, -1, -1}, 22,
      {
       GBQUAL_allele,
@@ -451,13 +453,14 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_pseudo,
       GBQUAL_pseudogene,
       GBQUAL_standard_name,
+      GBQUAL_trans_splicing,
       GBQUAL_usedin,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1}},
-   {"J_segment", 0, {-1, -1, -1, -1, -1}, 20,
+   {"J_segment", 0, {-1, -1, -1, -1, -1}, 19,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -482,8 +485,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1}},
-   {"LTR", 0, {-1, -1, -1, -1, -1}, 16,
+      -1, -1, -1, -1, -1, -1}},
+   {"LTR", 0, {-1, -1, -1, -1, -1}, 15,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -504,8 +507,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"mat_peptide", 0, {-1, -1, -1, -1, -1}, 25,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"mat_peptide", 0, {-1, -1, -1, -1, -1}, 24,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -534,9 +537,9 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
    {"misc_binding", 1, {
-      GBQUAL_bound_moiety, -1, -1, -1, -1}, 16,
+      GBQUAL_bound_moiety, -1, -1, -1, -1}, 15,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -557,8 +560,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"misc_difference", 0, {-1, -1, -1, -1, -1}, 20,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"misc_difference", 0, {-1, -1, -1, -1, -1}, 19,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -583,8 +586,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1}},
-   {"misc_feature", 0, {-1, -1, -1, -1, -1}, 23,
+      -1, -1, -1, -1, -1, -1}},
+   {"misc_feature", 0, {-1, -1, -1, -1, -1}, 22,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -612,8 +615,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1}},
-   {"misc_recomb", 0, {-1, -1, -1, -1, -1}, 16,
+      -1, -1, -1}},
+   {"misc_recomb", 0, {-1, -1, -1, -1, -1}, 15,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -634,8 +637,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"misc_RNA", 0, {-1, -1, -1, -1, -1}, 23,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"misc_RNA", 0, {-1, -1, -1, -1, -1}, 22,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -663,8 +666,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1}},
-   {"misc_signal", 0, {-1, -1, -1, -1, -1}, 19,
+      -1, -1, -1}},
+   {"misc_signal", 0, {-1, -1, -1, -1, -1}, 18,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -688,8 +691,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1}},
-   {"misc_structure", 0, {-1, -1, -1, -1, -1}, 17,
+      -1, -1, -1, -1, -1, -1, -1}},
+   {"misc_structure", 0, {-1, -1, -1, -1, -1}, 16,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -711,9 +714,9 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1}},
+      -1, -1, -1, -1, -1, -1, -1, -1, -1}},
    {"modified_base", 1, {
-      GBQUAL_mod_base, -1, -1, -1, -1}, 15,
+      GBQUAL_mod_base, -1, -1, -1, -1}, 14,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -733,8 +736,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"mRNA", 0, {-1, -1, -1, -1, -1}, 25,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"mRNA", 0, {-1, -1, -1, -1, -1}, 24,
      {
       GBQUAL_allele,
       GBQUAL_artificial_location,
@@ -763,8 +766,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"mutation", 0, {-1, -1, -1, -1, -1}, 18,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"mutation", 0, {-1, -1, -1, -1, -1}, 17,
      {
       GBQUAL_citation,
       GBQUAL_db_xref,
@@ -787,8 +790,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1}},
-   {"N_region", 0, {-1, -1, -1, -1, -1}, 18,
+      -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"N_region", 0, {-1, -1, -1, -1, -1}, 17,
      {
       GBQUAL_citation,
       GBQUAL_db_xref,
@@ -811,9 +814,9 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1}},
+      -1, -1, -1, -1, -1, -1, -1, -1}},
    {"ncRNA", 1, {
-      GBQUAL_ncRNA_class, -1, -1, -1, -1}, 23,
+      GBQUAL_ncRNA_class, -1, -1, -1, -1}, 22,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -841,7 +844,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1}},
+      -1, -1, -1}},
    {"old_sequence",   1, {
       GBQUAL_citation, -1, -1, -1, -1}, 15,
      {
@@ -866,7 +869,7 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
    {"operon", 1, {
-      GBQUAL_operon, -1, -1, -1, -1}, 16,
+      GBQUAL_operon, -1, -1, -1, -1}, 15,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -887,8 +890,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"oriT", 0, {-1, -1, -1, -1, -1}, 23,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"oriT", 0, {-1, -1, -1, -1, -1}, 22,
      {
       GBQUAL_allele,
       GBQUAL_bound_moiety,
@@ -916,8 +919,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1}},
-   {"polyA_signal", 0, {-1, -1, -1, -1, -1}, 15,
+      -1, -1, -1}},
+   {"polyA_signal", 0, {-1, -1, -1, -1, -1}, 14,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -937,8 +940,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"polyA_site", 0, {-1, -1, -1, -1, -1}, 14,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"polyA_site", 0, {-1, -1, -1, -1, -1}, 13,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -958,8 +961,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1}},
-   {"precursor_RNA", 0, {-1, -1, -1, -1, -1}, 20,
+      -1, -1}},
+   {"precursor_RNA", 0, {-1, -1, -1, -1, -1}, 19,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -984,8 +987,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1}},
-   {"prim_transcript", 0, {-1, -1, -1, -1, -1}, 18,
+      -1, -1, -1, -1, -1, -1}},
+   {"prim_transcript", 0, {-1, -1, -1, -1, -1}, 17,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1008,8 +1011,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1}},
-   {"primer_bind", 0, {-1, -1, -1, -1, -1}, 17,
+      -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"primer_bind", 0, {-1, -1, -1, -1, -1}, 16,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1031,8 +1034,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"promoter", 0, {-1, -1, -1, -1, -1}, 23,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"promoter", 0, {-1, -1, -1, -1, -1}, 22,
      {
       GBQUAL_allele,
       GBQUAL_bound_moiety,
@@ -1060,9 +1063,9 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1}},
+      -1, -1, -1}},
    {"protein_bind", 1, {
-      GBQUAL_bound_moiety, -1, -1, -1, -1}, 18,
+      GBQUAL_bound_moiety, -1, -1, -1, -1}, 17,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1085,8 +1088,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1}},
-   {"RBS", 0, {-1, -1, -1, -1, -1}, 16,
+      -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"RBS", 0, {-1, -1, -1, -1, -1}, 15,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1107,8 +1110,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"repeat_region", 0, {-1, -1, -1, -1, -1}, 26,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"repeat_region", 0, {-1, -1, -1, -1, -1}, 25,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1138,8 +1141,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"repeat_unit", 0, {-1, -1, -1, -1, -1}, 21,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"repeat_unit", 0, {-1, -1, -1, -1, -1}, 20,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1165,8 +1168,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1}},
-   {"rep_origin", 0, {-1, -1, -1, -1, -1}, 17,
+      -1, -1, -1, -1, -1}},
+   {"rep_origin", 0, {-1, -1, -1, -1, -1}, 16,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1188,8 +1191,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"rRNA", 0, {-1, -1, -1, -1, -1}, 22,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"rRNA", 0, {-1, -1, -1, -1, -1}, 21,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1216,8 +1219,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1}},
-   {"S_region", 0, {-1, -1, -1, -1, -1}, 20,
+      -1, -1, -1, -1}},
+   {"S_region", 0, {-1, -1, -1, -1, -1}, 19,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1242,8 +1245,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1}},
-   {"satellite", 0, {-1, -1, -1, -1, -1}, 21,
+      -1, -1, -1, -1, -1, -1}},
+   {"satellite", 0, {-1, -1, -1, -1, -1}, 20,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1269,8 +1272,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1}},
-   {"scRNA", 0, {-1, -1, -1, -1, -1}, 21,
+      -1, -1, -1, -1, -1}},
+   {"scRNA", 0, {-1, -1, -1, -1, -1}, 20,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1296,8 +1299,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1}},
-   {"sig_peptide", 0, {-1, -1, -1, -1, -1}, 21,
+      -1, -1, -1, -1, -1}},
+   {"sig_peptide", 0, {-1, -1, -1, -1, -1}, 20,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1323,8 +1326,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1}},
-   {"snoRNA", 0, {-1, -1, -1, -1, -1}, 21,
+      -1, -1, -1, -1, -1}},
+   {"snoRNA", 0, {-1, -1, -1, -1, -1}, 20,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1350,8 +1353,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1}},
-   {"snRNA", 0, {-1, -1, -1, -1, -1}, 21,
+      -1, -1, -1, -1, -1}},
+   {"snRNA", 0, {-1, -1, -1, -1, -1}, 20,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1377,9 +1380,9 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1}},
+      -1, -1, -1, -1, -1}},
    {"source", 1, {
-      GBQUAL_organism, -1, -1, -1, -1}, 63,
+      GBQUAL_organism, -1, -1, -1, -1}, 62,
      {
       GBQUAL_bio_material,
       GBQUAL_cell_line,
@@ -1443,8 +1446,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       GBQUAL_variety,
       GBQUAL_virion,
       GBQUAL_haplogroup,
-      -1, -1}},
-   {"stem_loop", 0, {-1, -1, -1, -1, -1}, 18,
+      -1, -1, -1}},
+   {"stem_loop", 0, {-1, -1, -1, -1, -1}, 17,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1467,8 +1470,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1}},
-   {"STS", 0, {-1, -1, -1, -1, -1}, 16,
+      -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"STS", 0, {-1, -1, -1, -1, -1}, 15,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1489,8 +1492,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"TATA_signal", 0, {-1, -1, -1, -1, -1}, 15,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"TATA_signal", 0, {-1, -1, -1, -1, -1}, 14,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1510,8 +1513,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"terminator", 0, {-1, -1, -1, -1, -1}, 17,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"terminator", 0, {-1, -1, -1, -1, -1}, 16,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1533,8 +1536,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"tmRNA", 0, {-1, -1, -1, -1, -1}, 23,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"tmRNA", 0, {-1, -1, -1, -1, -1}, 22,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1562,8 +1565,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1}},
-   {"transit_peptide", 0, {-1, -1, -1, -1, -1}, 21,
+      -1, -1, -1}},
+   {"transit_peptide", 0, {-1, -1, -1, -1, -1}, 20,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1589,8 +1592,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1}},
-   {"tRNA", 0, {-1, -1, -1, -1, -1}, 24,
+      -1, -1, -1, -1, -1}},
+   {"tRNA", 0, {-1, -1, -1, -1, -1}, 23,
      {
       GBQUAL_allele,
       GBQUAL_anticodon,
@@ -1619,8 +1622,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1}},
-   {"unsure", 0, {-1, -1, -1, -1, -1}, 15,
+      -1, -1}},
+   {"unsure", 0, {-1, -1, -1, -1, -1}, 14,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1640,8 +1643,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"V_region", 0, {-1, -1, -1, -1, -1}, 20,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"V_region", 0, {-1, -1, -1, -1, -1}, 19,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1666,8 +1669,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1}},
-   {"V_segment", 0, {-1, -1, -1, -1, -1}, 20,
+      -1, -1, -1, -1, -1, -1}},
+   {"V_segment", 0, {-1, -1, -1, -1, -1}, 19,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1692,8 +1695,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1}},
-   {"variation", 0, {-1, -1, -1, -1, -1}, 21,
+      -1, -1, -1, -1, -1, -1}},
+   {"variation", 0, {-1, -1, -1, -1, -1}, 20,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1719,8 +1722,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1}},
-   {"3'clip", 0, {-1, -1, -1, -1, -1}, 18,
+      -1, -1, -1, -1, -1}},
+   {"3'clip", 0, {-1, -1, -1, -1, -1}, 17,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1743,8 +1746,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1}},
-   {"3'UTR", 0, {-1, -1, -1, -1, -1}, 18,
+      -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"3'UTR", 0, {-1, -1, -1, -1, -1}, 17,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1767,8 +1770,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1}},
-   {"5'clip", 0, {-1, -1, -1, -1, -1}, 18,
+      -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"5'clip", 0, {-1, -1, -1, -1, -1}, 17,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1791,8 +1794,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1}},
-   {"5'UTR", 0, {-1, -1, -1, -1, -1}, 18,
+      -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"5'UTR", 0, {-1, -1, -1, -1, -1}, 17,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1815,8 +1818,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1}},
-   {"-10_signal", 0, {-1, -1, -1, -1, -1}, 17,
+      -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"-10_signal", 0, {-1, -1, -1, -1, -1}, 16,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1838,8 +1841,8 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1}},
-   {"-35_signal", 0, {-1, -1, -1, -1, -1}, 17,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"-35_signal", 0, {-1, -1, -1, -1, -1}, 16,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1861,9 +1864,9 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-      -1, -1, -1, -1, -1, -1, -1, -1}},
+      -1, -1, -1, -1, -1, -1, -1, -1, -1}},
    {"mobile_element", 1, {
-      GBQUAL_mobile_element_type, -1, -1, -1, -1}, 21,
+      GBQUAL_mobile_element_type, -1, -1, -1, -1}, 20,
      {
       GBQUAL_allele,
       GBQUAL_citation,
@@ -1889,6 +1892,48 @@ static SematicFeat STATIC__ParFlat_GBFeat[ParFlat_TOTAL_GBFEAT] = {
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1}},
+   {"centromere", 0, {-1, -1, -1, -1, -1}, 6,
+     {
+      GBQUAL_citation,
+      GBQUAL_db_xref,
+      GBQUAL_experiment,
+      GBQUAL_inference,
+      GBQUAL_note,
+      GBQUAL_standard_name,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1}},
+   {"telomere", 0, {-1, -1, -1, -1, -1}, 9,
+     {
+      GBQUAL_citation,
+      GBQUAL_db_xref,
+      GBQUAL_experiment,
+      GBQUAL_inference,
+      GBQUAL_note,
+      GBQUAL_rpt_type,
+      GBQUAL_rpt_unit_range,
+      GBQUAL_rpt_unit_seq,
+      GBQUAL_standard_name,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1, -1}},
+   {"assembly_gap", 2, {
+      GBQUAL_estimated_length, GBQUAL_gap_type, -1, -1, -1}, 1,
+     {
+      GBQUAL_linkage_evidence,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
       -1, -1, -1, -1}}
 };
 
