@@ -1,4 +1,4 @@
-/* $Id: jzcoll.h,v 6.3 1997/12/30 19:31:48 kans Exp $
+/* $Id: jzcoll.h,v 6.8 2006/07/13 17:06:38 bollin Exp $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
@@ -29,12 +29,30 @@
 *
 * Initial Version Creation Date: 03/24/97
 *
-* $Revision: 6.3 $
+* $Revision: 6.8 $
 *
 * File Description:
 *         File for various alignments
 *
 * $Log: jzcoll.h,v $
+* Revision 6.8  2006/07/13 17:06:38  bollin
+* use Uint4 instead of Uint2 for itemID values
+* removed unused variables
+* resolved compiler warnings
+*
+* Revision 6.7  2000/11/16 22:10:38  shavirin
+* Moved many functions from txalign.c - due to move of txalign.c to
+* distrib/tools directory and libncbitool.a library.
+*
+* Revision 6.6  2000/11/01 14:43:12  madden
+* Changes from Futamura for psitblastn
+*
+* Revision 6.5  1999/08/06 17:58:22  egorov
+* Print correct GI in formated output when user has specified list of gi's in blast search
+*
+* Revision 6.4  1998/07/22 18:57:34  kans
+* reconciled in new functions from JZ
+*
 * Revision 6.3  1997/12/30 19:31:48  kans
 * added CollectItemForSeqLocEx to restore propagation of features from parts to segmented bioseq
 *
@@ -50,12 +68,30 @@
 * Revision 5.13  1997/08/13 18:45:33  zjing
 * add support for tblastx
 *
-* $Revision: 6.3 $
+* $Revision: 6.8 $
 *
 * File Description:
 *         File for various alignments
 *
 * $Log: jzcoll.h,v $
+* Revision 6.8  2006/07/13 17:06:38  bollin
+* use Uint4 instead of Uint2 for itemID values
+* removed unused variables
+* resolved compiler warnings
+*
+* Revision 6.7  2000/11/16 22:10:38  shavirin
+* Moved many functions from txalign.c - due to move of txalign.c to
+* distrib/tools directory and libncbitool.a library.
+*
+* Revision 6.6  2000/11/01 14:43:12  madden
+* Changes from Futamura for psitblastn
+*
+* Revision 6.5  1999/08/06 17:58:22  egorov
+* Print correct GI in formated output when user has specified list of gi's in blast search
+*
+* Revision 6.4  1998/07/22 18:57:34  kans
+* reconciled in new functions from JZ
+*
 * Revision 6.3  1997/12/30 19:31:48  kans
 * added CollectItemForSeqLocEx to restore propagation of features from parts to segmented bioseq
 *
@@ -128,6 +164,7 @@ extern "C" {
 #define EXTRA_MDUP		((Uint4)32)
 #define EXTRA_DUP		((Uint4)64)
 #define EXTRA_CONTIG_STS	((Uint4)128)
+#define EXTRA_LOD_SCORE		((Uint4)256)
 
 
 /*the different types for a marker in its genetic context, EG for Eric Green*/
@@ -193,6 +230,7 @@ typedef struct collectalignoption {	/*option for drawing the sequence+feature*/
 	
 	Boolean show_feature;		/*show any feature?*/
 	Int4 	align_num;	/*the maximun number of alignment to collect*/
+	Int4 curr_align_num;	/*the current number of the alignments*/
 	SeqLocPtr segloc;			/*for marking the regions used in a segmented sequence*/
 	Int2 label_size;
 	Int4 graphic_offset;
@@ -246,7 +284,7 @@ NLM_EXTERN ValNodePtr CollectItemForAlignment PROTO((SeqLocPtr slp, Uint2 entity
 NLM_EXTERN ValNodePtr collect_anpnode_with_option PROTO((CollectAlignOptionPtr caop, SeqLocPtr m_loc, Uint2 entityID, Int4 style, Uint1 itemType, Uint1Ptr f_order, Uint1Ptr g_order, Boolean take_all_annot));
 
 typedef struct featnode {       /*for collecting the features*/
-  Uint2       itemID;
+  Uint4       itemID;
   Uint2       entityID;
   Uint1       feattype;         /*type for Seq-feat*/
   Uint1	      subtype;		/*subtype for Seq-feat*/
@@ -318,7 +356,7 @@ NLM_EXTERN ValNodePtr SortFeatNode PROTO((ValNodePtr list, Uint1Ptr featureOrder
 *	return the list of FeatNode with the same itemID
 *
 **********************************************************************/
-NLM_EXTERN ValNodePtr merge_same_itemID PROTO((ValNodePtr PNTR head, Int2 itemID));
+NLM_EXTERN ValNodePtr merge_same_itemID PROTO((ValNodePtr PNTR head, Uint4 itemID));
 
 
 typedef struct alignblock{
@@ -348,13 +386,14 @@ typedef struct alignblock{
 #define ALIGN_BLASTX    3
 #define ALIGN_TBLASTN   4
 #define ALIGN_TBLASTX	5
+#define ALIGN_PSITBLASTN   6
 
 typedef struct annotinfo {	/*information stored in Seq-annot*/
 	Uint1 displayOrder;
 	Uint1 consistent;	/*the type of the consistency*/
 	Char annotDB[21];
 	Uint2 entityID;
-	Uint2 itemID;
+	Uint4 itemID;
 	Uint1 annot_type;	/*is it a BLAST/Consist/FISH alignment */
 	Uint1 blast_type;	/*if it is alignment from BLAST, what is the type*/
 	Boolean is_fish_align;	/*is it the alignment for the FISH map */
@@ -412,6 +451,7 @@ typedef struct alignnode {      /*for collecting the alignment*/
   Uint1			index;	/*0, 1, 2 to indicate if it is a sequence/map index or 
 				  a normal alignment */
   CharPtr		label;		/*label for the aligned sequence*/
+  Boolean		keep_label;	/* says if a function can change the 'label' field */
   Uint1			m_frame;		/*mapped to the frame of translation in the master DNA sequence*/
   Boolean		is_master;	/*is it a master AlignNode*/
   GatherRange	extremes;
@@ -422,10 +462,10 @@ typedef struct alignnode {      /*for collecting the alignment*/
 
   Int4			seqpos;			/*the position of the sequence*/
   SeqIdPtr		sip;			/*the SeqId of the aligned sequence*/
-  Uint2			itemID;
+  Uint4			itemID;
   Uint2			entityID;
-  Uint2			seq_entityID;		/*entity id for the sequence*/
-  Uint2			bsp_itemID;		/*itemID for the current Bioseq*/
+  Uint4			seq_entityID;		/*entity id for the sequence*/
+  Uint4			bsp_itemID;		/*itemID for the current Bioseq*/
   Uint2			seqOrder;
   Uint2			chain;	
   Boolean		seq_has_align;	/*is the aligned segment itself contains alignment*/
@@ -567,7 +607,7 @@ NLM_EXTERN Int2 find_insert_ypos PROTO((Int4Ptr left, Int4 seglen, Int4 ins, Int
 *	itemID for the Bioseq
 *
 *****************************************************************/
-NLM_EXTERN Uint2 get_bioseq_itemID PROTO((BioseqPtr bsp, Uint2 entityID));
+NLM_EXTERN Uint4 get_bioseq_itemID PROTO((BioseqPtr bsp, Uint2 entityID));
 
 
 NLM_EXTERN ValNodePtr clean_annot_for_anp PROTO((ValNodePtr PNTR head));
@@ -603,6 +643,7 @@ NLM_EXTERN Uint1 get_alignment_type PROTO((AnnotInfoPtr annot_info));
 **********************************************************************/
 NLM_EXTERN Boolean FlatAlignNode PROTO((ValNodePtr anp_list));
 
+NLM_EXTERN void AddOffsetToAlignNode PROTO((AlignNodePtr anp, Int4 offset));
 /*
 *       Delete all the bad YACs from the list
 *       anything on the NHGRI map that is recorded inconsistent will
@@ -615,6 +656,49 @@ NLM_EXTERN Boolean FlatAlignNode PROTO((ValNodePtr anp_list));
 */
 NLM_EXTERN void CleanUpAmbiguousYAC PROTO((ValNodePtr PNTR anp_node, Uint1 db, SeqIdPtr chr_id));
 
+/***********************************************************************
+*
+*	ProcessTextAlignNode(anp, left, right, p_stop, m_buf, locus)
+*	process an AlignNode to generate a list of text buffer
+*
+*	anp: the AlignNode
+*	left, right: the range of alignment in process. mapped to 
+*	anp->extremes.left, and anp->extremes.right
+*	p_stop: the previous stop position in the sequence. It is used 
+*	to label the position of line which is a gap
+*	m_buf: the buffer of the master sequence. Can be used to compare
+*	mismatches
+*	locus: if TRUE, use the locus name for sequence
+*
+*
+*
+************************************************************************/
+NLM_EXTERN ValNodePtr ProcessTextAlignNode PROTO((
+                    AlignNodePtr anp, Int4 m_left, 
+                    Int4 m_right, Int4Ptr p_stop, 
+                    CharPtr m_buf, Int4 line_len, 
+                    Int1 m_frame, 
+                    Uint4 option, Int4Ptr PNTR matrix
+                    ));
+NLM_EXTERN ValNodePtr ProcessTextAlignNode2 PROTO((
+                    AlignNodePtr anp, Int4 m_left, 
+                    Int4 m_right, Int4Ptr p_stop, 
+                    CharPtr m_buf, Int4 line_len, 
+                    Int1 m_frame, 
+                    Uint4 option, Int4Ptr PNTR matrix,
+                    Int4Ptr PNTR posMatrix, Int4 q_start
+                    ));
+
+NLM_EXTERN ValNodePtr FreeTextAlignList PROTO((ValNodePtr tdp_list));
+
+NLM_EXTERN SeqIdPtr LIBCALL GetUseThisGi PROTO((SeqAlignPtr seqalign));
+NLM_EXTERN SeqIdPtr LIBCALL ScorePtrUseThisGi PROTO((ScorePtr sp));
+
+
+/* setting up the matrix for the positive residue of the alignment */
+
+NLM_EXTERN Int4Ptr PNTR load_default_matrix PROTO((void));
+NLM_EXTERN void free_default_matrix PROTO((Int4Ptr PNTR matrix));
 
 #ifdef __cplusplus
 }
