@@ -36,130 +36,6 @@
 * --------------------------------------------------------------------------
 * Date     Name        Description of modification
 *
-* $Log: lsqfetch.c,v $
-* Revision 6.30  2004/10/27 20:07:14  kans
-* LsqFetch_AsnIoOpen to suppress missing file warning, similar to LsqFetch_FileOpen
-*
-* Revision 6.29  2004/10/26 14:45:30  kans
-* LsqFetch_FileOpen suppresses FileOpen failure INFO message
-*
-* Revision 6.28  2004/10/05 19:11:23  kans
-* separate internal CreateBinaryAsnIndex and CreateTextAsnIndex functions
-*
-* Revision 6.27  2004/10/05 18:56:48  kans
-* AsnIndexedLibFetchEnable only works in text mode, backed out SeqEntryAsnRead change - will later implement use of catenated Seq-entry instead of se2bss processed input if text
-*
-* Revision 6.26  2004/10/05 17:34:16  kans
-* protect all binary search functions against R out of range
-*
-* Revision 6.25  2004/10/05 17:25:04  kans
-* AsnIndexedLibBioseqFetchFunc handles all Seq-id types, passes atp_se to SeqEntryAsnRead
-*
-* Revision 6.24  2004/10/05 16:21:37  kans
-* LocalSeqFetchInit checks for INDEXED_TEXT_ASN and INDEXED_BIN_ASN, calls AsnIndexedLibFetchEnable
-*
-* Revision 6.23  2004/08/04 20:21:04  kans
-* record alfp->binary at correct place in asn indexed fetch enable function
-*
-* Revision 6.22  2004/08/03 17:51:49  kans
-* added AsnIndexedLibFetch enable and disable functions
-*
-* Revision 6.21  2004/08/02 19:10:14  kans
-* added CreateAsnIndex for indexing Bioseq-set ftp release files
-*
-* Revision 6.20  2004/04/13 16:58:32  kans
-* allow alt index to have gi numbers, also test .fsa if .fa fails
-*
-* Revision 6.19  2003/11/13 17:18:02  kans
-* added SearchAltIndex, finished Alt fetch for chimp revision
-*
-* Revision 6.18  2003/11/12 23:49:11  kans
-* SortIfpByID needed LIBCALLBACK for PC
-*
-* Revision 6.17  2003/11/12 23:38:48  kans
-* changing AltIndexedFastaLibFetchEnable prototype, implementation not yet finished
-*
-* Revision 6.16  2003/08/27 21:24:05  kans
-* enable alt indexed fasta looks up previously registered function, changes settings for new path
-*
-* Revision 6.15  2003/08/27 19:27:43  kans
-* added AltIndexedFastaLibFetch functions for chimpanzee genome project
-*
-* Revision 6.14  2002/11/13 23:07:37  johnson
-* Changed make_lib such that it looks to see if it matches the *whole* seq-id
-* (defined by the next character being non-alphanumeric).
-*
-* Revision 6.13  2002/07/19 20:16:33  johnson
-* bug fix in make_lib -- wasn't properly handling sequences >=1000 residues
-*
-* Revision 6.12  2002/01/22 19:50:32  kans
-* IndexedFastaLibBioseqFetchFunc looks for prefix with upper case followed by lower case
-*
-* Revision 6.11  2001/09/21 20:02:04  kans
-* allow U and u to be DNA in CheckDnaResidue for the BLAST guys, even though it is amino acid Selenocysteine in most places
-*
-* Revision 6.10  2001/03/13 16:48:58  kans
-* fixes to saving path, binary search results
-*
-* Revision 6.9  2001/03/12 23:19:33  kans
-* added IndexedFastaLib functions - currently uses genome contig naming conventions
-*
-* Revision 6.8  2001/01/09 00:12:39  kans
-* now handles SEQID_GI
-*
-* Revision 6.7  1999/10/07 16:21:13  kans
-* removed static AddSeqId and SeqIdDupList which were identical to public sequtil functions
-*
-* Revision 6.6  1999/07/20 21:18:39  sicotte
-* add static AddSeqId for linker conflicts
-*
-* Revision 6.5  1999/07/20 21:16:49  sicotte
-* add static SeqIdDupList for linker conflicts
-*
-* Revision 6.4  1999/04/01 22:26:13  sicotte
-* Make lsqfetch Attempt to Parse the fasta defline, otherwise use the supplied SeqId
-*
-* Revision 6.3  1999/03/11 23:39:33  kans
-* sprintf and sscanf casts
-*
-* Revision 6.2  1998/02/06 17:41:33  zjing
-* make the function CheckDnaResidue external
-*
-* Revision 5.3  1997/07/18 21:31:36  zjing
-* move some def to lsqfetch.h
-*
-* Revision 5.2  1997/06/19 18:38:16  vakatov
-* [WIN32,MSVC++]  Adopted for the "NCBIOBJ.LIB" DLL'ization
-*
-* Revision 5.1  1997/02/12 22:42:43  zjing
-* fix a memory leak
-*
- * Revision 5.0  1996/05/28  13:23:23  ostell
- * Set to revision 5.0
- *
- * Revision 4.9  1996/03/06  18:28:53  zjing
- * .
- *
- * Revision 4.4  1995/10/11  19:29:28  zjing
- * add LIBCALL for find_big_bioseq
- *
- * Revision 4.3  1995/08/23  12:37:08  epstein
- * remove leading white space from conditional compilation
- *
- * Revision 4.2  1995/08/04  17:31:32  kans
- * JZ added LocalSeqFetchInit, LocalSeqFetchDisable
- *
- * Revision 4.1  1995/08/03  20:56:18  kans
- * paths can now be specified in a regular NCBI config file
- *
- * Revision 4.0  1995/07/26  13:49:01  ostell
- * force revision to 4.0
- *
- * Revision 1.4  1995/07/10  14:20:31  zjing
- * check in default search path for fasta files
- *
-*
-*
 * ==========================================================================
 */
 
@@ -213,7 +89,6 @@ static AsnIoPtr LIBCALL  LsqFetch_AsnIoOpen (CharPtr file_name, CharPtr mode)
   return aip;
 }
 
-
 /***********************************************************************
 ***
 *
@@ -260,7 +135,7 @@ static SeqEntryPtr Sep_from_ByteStore(ByteStorePtr bsp, Int4 length, Boolean is_
 
 	biosp = BioseqNew();
 	biosp->id = SeqIdDupList(sip);
-        biosp->seq_data = bsp;
+        biosp->seq_data = (SeqDataPtr) bsp;
         biosp->repr = Seq_repr_raw;
         biosp->mol = (is_dna) ? Seq_mol_dna : Seq_mol_aa;
         biosp->length = length;
@@ -1187,7 +1062,8 @@ static FastaIndexPtr ReadFastaIndex (
   Char           ch;
   FastaIndexPtr  fip;
   FILE           *fp;
-  Int4           idx, len;
+  Int4           idx;
+  Int8           len;
   CharPtr        last, ptr, tmp;
   Boolean        outOfOrder;
   Char           path [PATH_MAX];
@@ -1763,32 +1639,38 @@ NLM_EXTERN void CreateFastaIndex (
 static CharPtr asnlibfetchproc = "AsnIndexedLibBioseqFetch";
 
 typedef struct asnlibftch {
-  CharPtr     path;
-  ValNodePtr  fiplist;
-  IdFipPtr    index;
-  Int4        numids;
-  Boolean     binary;
+  CharPtr       datapath;
+  CharPtr       indexpath;
+  ValNodePtr    filelist;
+  CharPtr PNTR  filenames;
+  Int2          numfiles;
+  CharPtr PNTR  seqids;
+  Int4 PNTR     offsets;
+  Int2 PNTR     filenums;
+  Int4          numids;
+  Boolean       binary;
 } AsnLibFetchData, PNTR AsnLibFetchPtr;
 
-static FastaIndexPtr SearchAsnIndex (
+static Boolean SearchMasterAsnIndex (
   AsnLibFetchPtr alfp,
-  CharPtr seqid
+  CharPtr seqid,
+  Int4Ptr offsetP,
+  Int2Ptr filenumP
 )
 
 {
-  int       compare;
-  IdFipPtr  ifp;
-  Int4      L, R, mid;
+  int   compare;
+  Int4  L, R, mid;
 
-  if (alfp == NULL || alfp->index == NULL) return NULL;
-  ifp = alfp->index;
-  if (StringHasNoText (seqid)) return NULL;
+  if (alfp == NULL || alfp->seqids == NULL ||
+      alfp->offsets == NULL || alfp->filenums == NULL) return FALSE;
+  if (StringHasNoText (seqid)) return FALSE;
 
   L = 0;
   R = alfp->numids - 1;
   while (L < R) {
     mid = (L + R) / 2;
-    compare = StringICmp (ifp [mid].seqid, seqid);
+    compare = StringICmp (alfp->seqids [mid], seqid);
     if (compare < 0) {
       L = mid + 1;
     } else {
@@ -1797,22 +1679,250 @@ static FastaIndexPtr SearchAsnIndex (
   }
 
   if (R >= 0 && R < alfp->numids) {
-    if (StringICmp (ifp [R].seqid, seqid) == 0) {
-      return ifp [R].fip;
+    compare = StringICmp (alfp->seqids [R], seqid);
+    if (compare == 0) {
+      *offsetP = (Int4) alfp->offsets [R];
+      *filenumP = (Int2) alfp->filenums [R];
+      return TRUE;
     }
   }
 
+  return FALSE;
+}
+
+static AsnLibFetchPtr FreeMasterAsnIndex (
+  AsnLibFetchPtr alfp
+)
+
+{
+  Int4  i;
+
+  if (alfp == NULL) return NULL;
+
+  MemFree (alfp->datapath);
+  MemFree (alfp->indexpath);
+  for (i = 0; i < alfp->numids; i++) {
+    MemFree (alfp->seqids [i]);
+  }
+  MemFree (alfp->seqids);
+  MemFree (alfp->offsets);
+  MemFree (alfp->filenums);
+  MemFree (alfp->filenames);
+  ValNodeFreeData (alfp->filelist);
+  MemFree (alfp);
+
   return NULL;
 }
 
+static AsnLibFetchPtr ReadMasterAsnIndex (
+  CharPtr indexpath,
+  Boolean binary
+)
+
+{
+  AsnLibFetchPtr  alfp;
+  Char            ch;
+  Int2            col;
+  int             compare;
+  FileCache       fc;
+  Char            filename [PATH_MAX];
+  CharPtr         filenum;
+  Int4            idx;
+  FILE            *ifp;
+  ValNodePtr      lastfile = NULL;
+  CharPtr         lastseqid;
+  Char            line [128];
+  CharPtr         offset;
+  Boolean         outOfOrder;
+  CharPtr         ptr;
+  CharPtr         seqid;
+  CharPtr         str;
+  long int        val;
+  ValNodePtr      vnp;
+
+  if (StringHasNoText (indexpath)) return NULL;
+
+  StringNCpy_0 (filename, indexpath, sizeof (filename));
+  FileBuildPath (filename, NULL, "master.idx");
+
+  if (FileLength (filename) < 1) {
+    ErrPostEx (SEV_ERROR, 0, 0, "Master index file %s does not exist", filename);
+    return NULL;
+  }
+
+  alfp = (AsnLibFetchPtr) MemNew (sizeof (AsnLibFetchData));
+  if (alfp == NULL) return NULL;
+
+  ifp = FileOpen (filename, "r");
+  if (ifp == NULL) {
+    MemFree (alfp);
+    return NULL;
+  }
+
+  alfp->indexpath = StringSave (indexpath);
+  alfp->datapath = StringSave (indexpath);
+  alfp->binary = binary;
+
+  FileCacheSetup (&fc, ifp);
+
+  str = FileCacheReadLine (&fc, line, sizeof (line), NULL);
+
+  if (str != NULL && *str == '[') {
+    
+    /* read data path line */
+    str++;
+    ptr = StringChr (str, ']');
+    if (ptr != NULL) {
+      *ptr = '\0';
+      if (StringDoesHaveText (str)) {
+        alfp->datapath = MemFree (alfp->datapath);
+        alfp->datapath = StringSave (str);
+      }
+    }
+
+    str = FileCacheReadLine (&fc, line, sizeof (line), NULL);
+  }
+
+  while (str != NULL && *str == '(') {
+    
+    /* read index file name line */
+    str++;
+    ptr = StringChr (str, ')');
+    if (ptr != NULL) {
+      *ptr = '\0';
+      ptr = StringChr (str, '\t');
+      if (ptr != NULL) {
+        ptr++;
+        if (StringDoesHaveText (ptr)) {
+          vnp = ValNodeCopyStr (&(lastfile), 0, ptr);
+          if (alfp->filelist == NULL) {
+            alfp->filelist = vnp;
+          }
+          lastfile = vnp;
+          (alfp->numfiles)++;
+        }
+      }
+    }
+
+    str = FileCacheReadLine (&fc, line, sizeof (line), NULL);
+  }
+
+  if (str != NULL && *str == '<') {
+    
+    /* read number of seqids line */
+    str++;
+    ptr = StringChr (str, '>');
+    if (ptr != NULL) {
+      *ptr = '\0';
+      if (sscanf (str, "%ld", &val) == 1) {
+        alfp->numids = (Int4) val;
+      }
+    }
+
+    str = FileCacheReadLine (&fc, line, sizeof (line), NULL);
+  }
+
+  /* create arrays */
+
+  alfp->filenames = MemNew (sizeof (CharPtr) * (size_t) (alfp->numfiles + 3));
+
+  alfp->seqids = MemNew (sizeof (CharPtr) * (size_t) (alfp->numids + 2));
+  alfp->offsets = MemNew (sizeof (Int4) * (size_t) (alfp->numids + 2));
+  alfp->filenums = MemNew (sizeof (Int2) * (size_t) (alfp->numids + 2));
+
+  if (alfp->numids < 1 || alfp->numfiles < 1 ||
+      alfp->filenames == NULL || alfp->seqids == NULL ||
+      alfp->offsets == NULL || alfp->filenums == NULL) {
+
+    FileClose (ifp);
+    return FreeMasterAsnIndex (alfp);
+  }
+
+  /* initialize filenames array */
+
+  idx = 1;
+  for (vnp = alfp->filelist; vnp != NULL; vnp = vnp->next) {
+    ptr = (CharPtr) vnp->data.ptrvalue;
+    if (StringHasNoText (ptr)) continue;
+    alfp->filenames [idx] = StringSave (ptr);
+    idx++;
+  }
+
+  /* continue reading seqid-offset-filenum lines */
+
+  idx = 0;
+  seqid = NULL;
+  offset = NULL;
+  filenum = NULL;
+  while (str != NULL) {
+    if (StringDoesHaveText (str)) {
+
+      /* read line of seqid index data into seqids, offsets and filenums arrays */
+
+      col = 0;
+      ptr = str;
+      ch = *ptr;
+      seqid = ptr;
+      while (ch != '\0') {
+      if (ch == '\t') {
+          *ptr = '\0';
+          ptr++;
+          ch = *ptr;
+          col++;
+          if (col == 1) {
+            offset = ptr;
+         } else if (col == 2) {
+            filenum = ptr;
+          }
+        } else {
+          ptr++;
+          ch = *ptr;
+        }
+      }
+      if (StringDoesHaveText (seqid)) {
+        alfp->seqids [idx] = StringSave (seqid);
+      }
+      if (sscanf (offset, "%ld", &val) == 1) {
+        alfp->offsets [idx] = (Int4) val;
+      }
+      if (sscanf (filenum, "%ld", &val) == 1) {
+        alfp->filenums [idx] = (Int2) val;
+      }
+      idx++;
+    }
+
+    str = FileCacheReadLine (&fc, line, sizeof (line), NULL);
+  }
+
+  FileClose (ifp);
+
+  /* confirm sorted order and uniqueness */
+
+  outOfOrder = FALSE;
+  lastseqid = alfp->seqids [0];
+  for (idx = 1; idx < alfp->numids; idx++) {
+    compare = StringICmp (lastseqid, alfp->seqids [idx]);
+    if (compare >= 0) {
+      outOfOrder = TRUE;
+    }
+    lastseqid = alfp->seqids [idx];
+  }
+
+  if (outOfOrder) {
+    ErrPostEx (SEV_ERROR, 0, 0, "Master index file out of order");
+  }
+
+  return alfp;
+}
+
 static Int2 LIBCALLBACK AsnIndexedLibBioseqFetchFunc (Pointer data)
 
 {
   AsnIoPtr          aip;
   AsnLibFetchPtr    alfp;
   BioseqPtr         bsp;
-  Char              file [FILENAME_MAX], path [PATH_MAX], id [41];
-  FastaIndexPtr     fip;
+  Char              buf [64], file [FILENAME_MAX], path [PATH_MAX];
+  Int2              filenum;
   Int4              offset;
   OMProcControlPtr  ompcp;
   ObjMgrProcPtr     ompp;
@@ -1829,18 +1939,16 @@ static Int2 LIBCALLBACK AsnIndexedLibBioseqFetchFunc (Pointer data)
   sip = (SeqIdPtr) ompcp->input_data;
   if (sip == NULL) return OM_MSG_RET_ERROR;
 
-  SeqIdWrite (sip, id, PRINTID_REPORT, sizeof (id));
-  fip = SearchAsnIndex (alfp, id);
-  if (fip != NULL) {
-    offset = SearchFastaIndex (fip, id);
-    if (offset < 0) return OM_MSG_RET_ERROR;
-    StringCpy (file, fip->file);
+  SeqIdWrite (sip, buf, PRINTID_TEXTID_ACC_VER, sizeof (buf));
+  if (SearchMasterAsnIndex (alfp, buf, &offset, &filenum)) {
+    if (offset < 0 || filenum < 1) return OM_MSG_RET_ERROR;
+    StringCpy (file, alfp->filenames [filenum]);
     tmp = StringStr (file, ".idx");
     if (tmp != NULL) {
       *tmp = '\0';
     }
     StringCat (file, ".aso");
-    StringNCpy_0 (path, fip->path, sizeof (path));
+    StringNCpy_0 (path, alfp->datapath, sizeof (path));
     FileBuildPath (path, NULL, file);
     aip = LsqFetch_AsnIoOpen (path, alfp->binary? "rb" : "r");
     if (aip == NULL) {
@@ -1848,7 +1956,7 @@ static Int2 LIBCALLBACK AsnIndexedLibBioseqFetchFunc (Pointer data)
       if (tmp != NULL) {
         *tmp = '\0';
         StringCat (file, ".asn");
-        StringNCpy_0 (path, fip->path, sizeof (path));
+        StringNCpy_0 (path, alfp->datapath, sizeof (path));
         FileBuildPath (path, NULL, file);
         aip = LsqFetch_AsnIoOpen (path, alfp->binary? "rb" : "r");
       }
@@ -1866,81 +1974,29 @@ static Int2 LIBCALLBACK AsnIndexedLibBioseqFetchFunc (Pointer data)
   return OM_MSG_RET_DONE;
 }
 
-NLM_EXTERN Boolean AsnIndexedLibFetchEnable (CharPtr path, Boolean binary)
+NLM_EXTERN Boolean AsnIndexedLibFetchEnable (CharPtr indexpath, Boolean binary)
 
 {
   AsnLibFetchPtr  alfp = NULL;
-  Char            file [FILENAME_MAX];
-  FastaIndexPtr   fip;
-  ValNodePtr      head;
-  Int4            i;
-  IdFipPtr        ifp;
   Boolean         is_new = FALSE;
-  Int4            j;
-  Int4            numids = 0;
   ObjMgrPtr       omp;
   ObjMgrProcPtr   ompp;
   Char            str [PATH_MAX];
-  CharPtr         tmp;
-  ValNodePtr      vnp;
 
-  StringNCpy_0 (str, path, sizeof (str));
+  StringNCpy_0 (str, indexpath, sizeof (str));
   TrimSpacesAroundString (str);
   omp = ObjMgrGet ();
   ompp = ObjMgrProcFind (omp, 0, asnlibfetchproc, OMPROC_FETCH);
   if (ompp != NULL) {
     alfp = (AsnLibFetchPtr) ompp->procdata;
     if (alfp != NULL) {
-      alfp->path = MemFree (alfp->path);
-      for (vnp = alfp->fiplist; vnp != NULL; vnp = vnp->next) {
-        fip = (FastaIndexPtr) vnp->data.ptrvalue;
-        FreeFastaIndex (fip);
-      }
-      alfp->fiplist = ValNodeFree (alfp->fiplist);
-      alfp->index = MemFree (alfp->index);
+      FreeMasterAsnIndex (alfp);
+      alfp = ReadMasterAsnIndex (indexpath, binary);
+      ompp->procdata = (Pointer) alfp;
     }
   } else {
-    alfp = (AsnLibFetchPtr) MemNew (sizeof (AsnLibFetchData));
     is_new = TRUE;
-    if (alfp != NULL) {
-      alfp->binary = binary;
-    }
-  }
-  if (alfp != NULL) {
-    alfp->path = StringSave (str);
-    head = DirCatalog (str);
-    for (vnp = head; vnp != NULL; vnp = vnp->next) {
-      if (vnp->choice == 0) {
-        tmp = (CharPtr) vnp->data.ptrvalue;
-        if (StringStr (tmp, ".idx") != NULL) {
-          StringCpy (str, alfp->path);
-          sprintf (file, "%s", tmp);
-          FileBuildPath (str, NULL, file);
-          fip = ReadFastaIndex (str);
-          if (fip != NULL) {
-            ValNodeAddPointer (&(alfp->fiplist), 0, (Pointer) fip);
-            numids += fip->numlines;
-          }
-        }
-      }
-    }
-    ValNodeFreeData (head);
-    ifp = (IdFipPtr) MemNew (sizeof (IdFip) * (numids + 2));
-    alfp->index = ifp;
-    alfp->numids = numids;
-    if (ifp != NULL) {
-      i = 0;
-      for (vnp = alfp->fiplist; vnp != NULL; vnp = vnp->next) {
-        fip = (FastaIndexPtr) vnp->data.ptrvalue;
-        if (fip != NULL) {
-          for (j = 0; j < fip->numlines; j++, i++) {
-            ifp [i].seqid = fip->seqids [j];
-            ifp [i].fip = fip;
-          }
-        }
-      }
-      HeapSort (ifp, (size_t) numids, sizeof (IdFip), SortIfpByID);
-    }
+    alfp = ReadMasterAsnIndex (indexpath, binary);
   }
   if (is_new) {
     ObjMgrProcLoad (OMPROC_FETCH, asnlibfetchproc, asnlibfetchproc,
@@ -1954,10 +2010,8 @@ NLM_EXTERN void AsnIndexedLibFetchDisable (void)
 
 {
   AsnLibFetchPtr  alfp;
-  FastaIndexPtr   fip;
   ObjMgrPtr       omp;
   ObjMgrProcPtr   ompp;
-  ValNodePtr      vnp;
 
   omp = ObjMgrGet ();
   ompp = ObjMgrProcFind (omp, 0, asnlibfetchproc, OMPROC_FETCH);
@@ -1965,14 +2019,7 @@ NLM_EXTERN void AsnIndexedLibFetchDisable (void)
   ObjMgrFreeUserData (0, ompp->procid, OMPROC_FETCH, 0);
   alfp = (AsnLibFetchPtr) ompp->procdata;
   if (alfp == NULL) return;
-  alfp->path = MemFree (alfp->path);
-  for (vnp = alfp->fiplist; vnp != NULL; vnp = vnp->next) {
-    fip = (FastaIndexPtr) vnp->data.ptrvalue;
-    FreeFastaIndex (fip);
-  }
-  alfp->fiplist = ValNodeFree (alfp->fiplist);
-  alfp->index = MemFree (alfp->index);
-  MemFree (alfp);
+  FreeMasterAsnIndex (alfp);
 }
 
 /* common function for creating indexes of ASN.1 Bioseq-set ftp release files */
@@ -1990,36 +2037,50 @@ static void SaveAsnIdxOffset (
 )
 
 {
-  AsnIdxPtr  aip;
-  Char       id [41], tmp [64];
-  SeqIdPtr   sip;
+  AsnIdxPtr   aip;
+  Char        id [96], tmp [128];
+  SeqIdPtr    sip;
+  ValNodePtr  vnp;
 
   aip = (AsnIdxPtr) userdata;
   if (bsp == NULL || aip == NULL) return;
 
-  sip = SeqIdFindBest (bsp->id, SEQID_GI);
-  if (sip == NULL) {
-    sip = SeqIdFindBest (bsp->id, 0);
-  }
+  for (sip = bsp->id; sip != NULL; sip = sip->next) {
+    switch (sip->choice) {
+      case SEQID_GENBANK :
+      case SEQID_EMBL :
+      case SEQID_DDBJ :
+      case SEQID_TPG :
+      case SEQID_TPE :
+      case SEQID_TPD :
+      case SEQID_OTHER :
+      case SEQID_GPIPE :
+      case SEQID_PIR :
+      case SEQID_SWISSPROT :
+      case SEQID_PRF :
+      case SEQID_PDB :
+      case SEQID_GI :
+        SeqIdWrite (sip, id, PRINTID_TEXTID_ACC_VER, sizeof (id));
+        if (StringHasNoText (id)) continue;
 
-  SeqIdWrite (sip, id, PRINTID_REPORT, sizeof (id));
-  if (! StringHasNoText (id)) {
+        /* save ID and offset separated by tab character */
 
-    /* save ID and offset separated by tab character */
-
-    sprintf (tmp, "%s\t%ld", id, (long) aip->offset);
-    aip->last = ValNodeNew (aip->last);
-    if (aip->head == NULL) {
-      aip->head = aip->last;
-    }
-    if (aip->last != NULL) {
-      aip->last->data.ptrvalue = StringSave (tmp);
+        sprintf (tmp, "%s\t%ld", id, (long) aip->offset);
+        vnp = ValNodeCopyStr (&(aip->last), 0, tmp);
+        if (aip->head == NULL) {
+          aip->head = vnp;
+        }
+        aip->last = vnp;
+        break;
+      default :
+        break;
     }
   }
 }
 
 static void CreateBinaryAsnIndex (
-  CharPtr file
+  CharPtr datafile,
+  CharPtr indexpath
 )
 
 {
@@ -2027,6 +2088,7 @@ static void CreateBinaryAsnIndex (
   AsnIoPtr      aip;
   AsnModulePtr  amp;
   AsnTypePtr    atp, atp_bss, atp_se;
+  Char          file [PATH_MAX];
   FILE          *ofp;
   ObjMgrPtr     omp;
   Char          path [PATH_MAX];
@@ -2034,18 +2096,39 @@ static void CreateBinaryAsnIndex (
   SeqEntryPtr   sep;
   ValNodePtr    vnp;
 
-  if (StringHasNoText (file)) return;
+  if (StringHasNoText (datafile)) return;
 
   /* replace extension by .idx for index file */
 
-  StringNCpy_0 (path, file, sizeof (path));
-  ptr = StringRChr (path, '.');
-  if (ptr != NULL) {
-    *ptr = '\0';
+  path [0] = '\0';
+  if (StringDoesHaveText (indexpath)) {
+    StringNCpy_0 (file, datafile, sizeof (file));
+    ptr = StringRChr (file, '.');
+    if (ptr != NULL) {
+      *ptr = '\0';
+    }
+    ptr = StringRChr (file, DIRDELIMCHR);
+    if (ptr != NULL) {
+      ptr++;
+      StringNCpy_0 (path, indexpath, sizeof (path));
+      FileBuildPath (path, NULL, ptr);
+      StringCat (path, ".idx");
+    }
+  } else {
+    StringNCpy_0 (path, datafile, sizeof (path));
+    ptr = StringRChr (path, '.');
+    if (ptr != NULL) {
+      *ptr = '\0';
+    }
+    StringCat (path, ".idx");
   }
-  StringCat (path, ".idx");
 
-  aip = LsqFetch_AsnIoOpen (file, "rb");
+  if (FileLength (path) > 0) {
+    Message (MSG_POST, "Index file %s already exists", path);
+    return;
+  }
+
+  aip = LsqFetch_AsnIoOpen (datafile, "rb");
   if (aip == NULL) return;
 
   ofp = LsqFetch_FileOpen (path, "w");
@@ -2110,31 +2193,54 @@ static void CreateBinaryAsnIndex (
 }
 
 static void CreateTextAsnIndex (
-  CharPtr file
+  CharPtr datafile,
+  CharPtr indexpath
 )
 
 {
   AsnIdxData   aid;
   Pointer      dataptr = NULL;
   Uint2        datatype, entityID = 0;
+  Char         file [PATH_MAX];
   FILE         *ifp, *ofp;
   Char         path [PATH_MAX];
   CharPtr      ptr;
   SeqEntryPtr  sep;
   ValNodePtr   vnp;
 
-  if (StringHasNoText (file)) return;
+  if (StringHasNoText (datafile)) return;
 
   /* replace extension by .idx for index file */
 
-  StringNCpy_0 (path, file, sizeof (path));
-  ptr = StringRChr (path, '.');
-  if (ptr != NULL) {
-    *ptr = '\0';
+  path [0] = '\0';
+  if (StringDoesHaveText (indexpath)) {
+    StringNCpy_0 (file, datafile, sizeof (file));
+    ptr = StringRChr (file, '.');
+    if (ptr != NULL) {
+      *ptr = '\0';
+    }
+    ptr = StringRChr (file, DIRDELIMCHR);
+    if (ptr != NULL) {
+      ptr++;
+      StringNCpy_0 (path, indexpath, sizeof (path));
+      FileBuildPath (path, NULL, ptr);
+      StringCat (path, ".idx");
+    }
+  } else {
+    StringNCpy_0 (path, datafile, sizeof (path));
+    ptr = StringRChr (path, '.');
+    if (ptr != NULL) {
+      *ptr = '\0';
+    }
+    StringCat (path, ".idx");
   }
-  StringCat (path, ".idx");
 
-  ifp = LsqFetch_FileOpen (file, "r");
+  if (FileLength (path) > 0) {
+    Message (MSG_POST, "Index file %s already exists", path);
+    return;
+  }
+
+  ifp = LsqFetch_FileOpen (datafile, "r");
   if (ifp == NULL) return;
 
   ofp = LsqFetch_FileOpen (path, "w");
@@ -2184,15 +2290,205 @@ static void CreateTextAsnIndex (
 }
 
 NLM_EXTERN void CreateAsnIndex (
-  CharPtr file,
+  CharPtr datafile,
+  CharPtr indexpath,
   Boolean binary
 )
 
 {
+  if (StringHasNoText (datafile)) return;
+
   if (binary) {
-    CreateBinaryAsnIndex (file);
+    CreateBinaryAsnIndex (datafile, indexpath);
   } else {
-    CreateTextAsnIndex (file);
+    CreateTextAsnIndex (datafile, indexpath);
   }
 }
 
+typedef struct idxdata {
+  CharPtr  seqid;
+  Int4     offset;
+  Int2     filenum;
+} IdxData, PNTR IdxDataPtr;
+
+typedef struct buildidx {
+  CharPtr     path;
+  Int2        filenum;
+  FILE        *ofp;
+  ValNodePtr  head;
+  ValNodePtr  last;
+} BuildIdx, PNTR BuildIdxPtr;
+
+static void AddOneIndex (
+  CharPtr filename,
+  Pointer userdata
+)
+
+{
+  BuildIdxPtr  bip;
+  FileCache    fc;
+  IdxDataPtr   idp;
+  FILE         *ifp;
+  Char         line [128];
+  CharPtr      ptr;
+  CharPtr      str;
+  long int     val;
+  ValNodePtr   vnp;
+
+  if (StringHasNoText (filename) || userdata == NULL) return;
+  bip = (BuildIdxPtr) userdata;
+
+  ptr = StringRChr (filename, DIRDELIMCHR);
+  if (ptr == NULL) return;
+  ptr++;
+  if (StringICmp (ptr, "master.idx") == 0) return;
+
+  (bip->filenum)++;
+  fprintf (bip->ofp, "(%d\t%s)\n", (int) bip->filenum, ptr);
+
+  ifp = FileOpen (filename, "r");
+  if (ifp == NULL) return;
+
+  if (FileCacheSetup (&fc, ifp)) {
+    str = FileCacheReadLine (&fc, line, sizeof (line), NULL);
+    while (str != NULL) {
+      if (StringDoesHaveText (str)) {
+        ptr = StringChr (str, '\t');
+        if (ptr != NULL) {
+          *ptr = '\0';
+          ptr++;
+          if (StringDoesHaveText (str)) {
+            idp = (IdxDataPtr) MemNew (sizeof (IdxData));
+            if (idp != NULL) {
+              idp->seqid = StringSave (str);
+              if (sscanf (ptr, "%ld", &val) == 1) {
+                idp->offset = (Int4) val;
+              }
+              idp->filenum = (Int2) bip->filenum;
+              vnp = ValNodeAddPointer (&(bip->last), 0, (Pointer) idp);
+              if (bip->head == NULL) {
+                bip->head = vnp;
+              }
+              bip->last = vnp;
+            }
+          }
+        }
+      }
+      str = FileCacheReadLine (&fc, line, sizeof (line), NULL);
+    }
+  }
+
+  FileClose (ifp);
+}
+
+static int LIBCALLBACK SortVnpByBuildIdxSeqid (VoidPtr ptr1, VoidPtr ptr2)
+
+{
+  int         compare;
+  IdxDataPtr  idp1, idp2;
+  ValNodePtr  vnp1, vnp2;
+
+  if (ptr1 != NULL && ptr2 != NULL) {
+    vnp1 = *((ValNodePtr PNTR) ptr1);
+    vnp2 = *((ValNodePtr PNTR) ptr2);
+    if (vnp1 != NULL && vnp2 != NULL) {
+      idp1 = (IdxDataPtr) vnp1->data.ptrvalue;
+      idp2 = (IdxDataPtr) vnp2->data.ptrvalue;
+      if (idp1 != NULL && idp2 != NULL) {
+        compare = StringICmp (idp1->seqid, idp2->seqid);
+        if (compare > 0) {
+          return 1;
+        } else if (compare < 0) {
+          return -1;
+        } else return 0;
+      }
+    }
+  }
+  return 0;
+}
+
+static ValNodePtr UniqueVnpByBuildIdx (ValNodePtr list)
+
+{
+  int           compare;
+  IdxDataPtr    curr;
+  IdxDataPtr    last;
+  ValNodePtr    next;
+  Pointer PNTR  prev;
+  ValNodePtr    vnp;
+
+  if (list == NULL) return NULL;
+  last = (IdxDataPtr) list->data.ptrvalue;
+  vnp = list->next;
+  prev = (Pointer PNTR) &(list->next);
+  while (vnp != NULL) {
+    next = vnp->next;
+    curr = (IdxDataPtr) vnp->data.ptrvalue;
+    compare = StringICmp (last->seqid, curr->seqid);
+    if (compare == 0) {
+      vnp->next = NULL;
+      *prev = next;
+      MemFree (curr->seqid);
+      ValNodeFreeData (vnp);
+    } else {
+      last = (IdxDataPtr) vnp->data.ptrvalue;
+      prev = (Pointer PNTR) &(vnp->next);
+    }
+    vnp = next;
+  }
+
+  return list;
+}
+
+NLM_EXTERN void CreateMasterAsnIndex (
+  CharPtr datapath,
+  CharPtr indexpath
+)
+
+{
+  BuildIdx     bi;
+  IdxDataPtr   idp;
+  Int4         len;
+  Char         str [PATH_MAX];
+  ValNodePtr   vnp;
+
+  if (StringHasNoText (indexpath)) {
+    indexpath = datapath;
+  }
+  if (StringHasNoText (indexpath)) return;
+
+  MemSet ((Pointer) &bi, 0, sizeof (BuildIdx));
+  StringNCpy_0 (str, indexpath, sizeof (str));
+  FileBuildPath (str, NULL, "master.idx");
+
+  if (FileLength (str) > 0) {
+    Message (MSG_POST, "Master index file %s already exists", str);
+    return;
+  }
+
+  bi.ofp = FileOpen (str, "w");
+
+  if (StringDoesHaveText (datapath) && StringICmp (datapath, indexpath) != 0) {
+    StringNCpy_0 (str, datapath, sizeof (str));
+    FileBuildPath (str, NULL, NULL);
+    fprintf (bi.ofp, "[%s]\n", str);
+  }
+
+  DirExplore (indexpath, NULL, ".idx", FALSE, AddOneIndex, (Pointer) &bi);
+
+  bi.head = ValNodeSort (bi.head, SortVnpByBuildIdxSeqid);
+  bi.head = UniqueVnpByBuildIdx (bi.head);
+
+  len = ValNodeLen (bi.head);
+  fprintf (bi.ofp, "<%ld>\n", (long) len);
+
+  for (vnp = bi.head; vnp != NULL; vnp = vnp->next) {
+    idp = (IdxDataPtr) vnp->data.ptrvalue;
+    if (idp == NULL) continue;
+    fprintf (bi.ofp, "%s\t%ld\t%d\n", idp->seqid, (long) idp->offset, (int) idp->filenum);
+  }
+
+  ValNodeFreeData (bi.head);
+  FileClose (bi.ofp);
+}
+
