@@ -29,7 +29,7 @@
 *
 * Version Creation Date:   1/27/96
 *
-* $Revision: 6.6 $
+* $Revision: 6.8 $
 *
 * File Description: 
 *
@@ -122,6 +122,7 @@ NLM_EXTERN CharPtr PNTR SeqIdListToCharArray (SeqIdPtr id_list, Int2 n);
 NLM_EXTERN SeqIdPtr     SeqIdReplaceID (SeqIdPtr head, SeqIdPtr pre, SeqIdPtr sip, SeqIdPtr next);
 NLM_EXTERN BioseqPtr    BioseqReplaceID (BioseqPtr bsp, SeqIdPtr newsip);
 NLM_EXTERN void         ReplaceSeqIdWithSeqId (SeqIdPtr sip_old, SeqIdPtr sip_new, SeqEntryPtr sep);
+NLM_EXTERN void         ReplaceSeqIdWithSeqIdInFeat (SeqIdPtr old_id, SeqIdPtr new_id, SeqFeatPtr sfp);
 NLM_EXTERN SeqEntryPtr  SeqEntryReplaceSeqID (SeqEntryPtr source_sep, SeqIdPtr sip);
 /*********************************************************
 ***
@@ -264,7 +265,8 @@ NLM_EXTERN Boolean insertchar_atcaret (CharPtr str, EditAlignDataPtr adp);
 
 NLM_EXTERN SeqEntryPtr getfirst_sep(SeqEntryPtr sep, Uint1 bsp_mol);
 
-NLM_EXTERN void CleanUpSegGap (SeqAlignPtr sap);
+NLM_EXTERN Boolean CleanUpSegGap (SeqAlignPtr sap);
+NLM_EXTERN Int4 RemoveSegGapsInSeqEntry (SeqEntryPtr sep);
 
 #endif
 
