@@ -259,7 +259,8 @@ Uint2 entityID, Uint4 itemID, Uint2 itemtype)
 	if (pdp) {
 		descr = AsnIoMemCopy(pdp, (AsnReadFunc) PubdescAsnRead,
 											(AsnWriteFunc) PubdescAsnWrite);
-		vnp = ValNodeNew(NULL);
+		if (descr == NULL) return NULL;
+        vnp = ValNodeNew(NULL);
 		vnp->choice = PUB_Equiv;
 		vnp->data.ptrvalue = descr->pub;
 		psp = (PubStructPtr) MemNew(sizeof(PubStruct));
@@ -1595,6 +1596,12 @@ NLM_EXTERN void EntryStripSerialNumber (SeqEntryPtr sep)
 	}
 }
 
+NLM_EXTERN void ForceStripSerialNumber (SeqEntryPtr sep)
+{
+	if (sep == NULL) return;
+	SeqEntryExplore(sep, NULL, StripSerialNumber);
+}
+
 NLM_EXTERN ValNodePtr remove_node(ValNodePtr head, ValNodePtr x)
 {
 	ValNodePtr	v, p;
