@@ -31,7 +31,28 @@
  * Version Creation Date: 03/12/98
  *
  * $Log: vast2mage.c,v $
- * Revision 6.3  1998/05/19 20:21:17  madej
+ * Revision 6.10  2000/01/31 19:59:12  lewisg
+ * fix output of date in pdb header
+ *
+ * Revision 6.9  1999/10/13 20:19:35  zimmerma
+ * DZ: Removed use of temporary files - html output redirected to stdout
+ *
+ * Revision 6.8  1999/05/07 13:53:02  zimmerma
+ * Changed call to InstBSAnnotSet() to pass Chain and SlaveChain params
+ *
+ * Revision 6.7  1999/02/10 14:42:53  addess
+ * fixed problem with not being able to read new files
+ *
+ * Revision 6.6  1998/10/14  17:17:35  addess
+ * sending aligned chains to MAGE
+ *
+ * Revision 6.5  1998/07/17  18:47:15  madej
+ * Allow Mage to work with Vast Search.
+ *
+ * Revision 6.4  1998/06/11  19:11:20  madej
+ * Part of a fix for a problem in Vast search.
+ *
+ * Revision 6.3  1998/05/19  20:21:17  madej
  * Add general WWW routines for running on Sun servers.
  *
  * Revision 6.2  1998/03/30  19:13:25  madej
@@ -54,6 +75,7 @@
 #include "mmdblocl.h"
 #include "mmdbdata.h"
 #include "vast2mage.h"
+#include "vastsrv.h"
 
 static char *BaseURL;
 static FILE *OutputFile = NULL;
@@ -64,7 +86,6 @@ extern CharPtr KineColors[];
 extern Int1 ColorNumKinBB[];
 extern Int1 ColorNumKinSC[];
 extern Int1 ColorNumKinAC[];
-
  
 
 void LIBCALLBACK AlignKinVirt(PFB pfbThis, Int4 iModel,  Int4 iIndex, Pointer ptr)
@@ -144,10 +165,10 @@ void LIBCALL AlignKinHeader(PDNMS pdnmsThis,  FILE *pFile, Boolean master)
    	depyear = pbssThis->database_entry_date->data[1];
    	depday = pbssThis->database_entry_date->data[3];
 	
-   	fprintf(pFile,"PDB Deposition:\n%2d-%3s-%2d\n\n",
+   	fprintf(pFile,"PDB Deposition:\n%2d-%3s-%02d\n\n",
                    (int) depday,
                    NCBI_months[pbssThis->database_entry_date->data[2]-1],
-                   (int) depyear);
+                   (int) depyear%100);
      }
   fprintf(pFile,"Class:\n%s\n\n", pmsdThis->pcPdbClass);
   fflush(pFile);
@@ -315,11 +336,9 @@ static Int2 WriteKinPairAlign(PDNMS pdnmsMaster,
     PMLD  pmldThis = NULL;
     Int2 iPDBCount = 0;
 
-    if (pdnmsSlave == NULL) {
-	printf("Content-type: text/html\n");
-	printf("<h3>It's NULL right at entry...</h3>\n");
+    if (pdnmsSlave == NULL)
 	return 0;
-    }
+
     fprintf(pFile, "@text\n");
     fprintf(pFile, "NCBI - Generated Kinemage File Alignment From MMDB\n\n");
     fflush(pFile);
@@ -361,16 +380,16 @@ Boolean LIBCALL VastToMage(WWWInfoPtr www_info)
 	FILE *pIn = NULL;
 	Char pcBuf[100], pcLine[256], giBuf[20], URL[200];
 	CharPtr pcTest, pcL1 = NULL, www_arg;
-	Int4 GetGi, Fid, Fsid, iFileExists = 0, indx;
+	CharPtr JobID = NULL, pcPass;
+	Int4 GetGi, Fid, Fsid, iFileExists = 0, indx, complexity;
 	BiostrucAnnotSetPtr pbsa = NULL; 
 	BiostrucAnnotSetPtr pbsaShort = NULL;
 	PDNMS pdnmsMaster = NULL, pdnmsSlave = NULL;
-	Int2 iTest = 0, iPDB = 0, iColor;
+	Int2 iTest = 0, iPDB = 0, iColor, ret;
 	AsnIoPtr aip = NULL; 
 	Byte bRender;
 	Char *IPAddress = getenv("REMOTE_HOST");
- 
-
+        Boolean Chain;
 
 	if ((indx = WWWFindName(www_info, "uid")) < 0) {
 		printf("Content-type: text/html\n\n");
@@ -390,8 +409,36 @@ Boolean LIBCALL VastToMage(WWWInfoPtr www_info)
 		return 0;
 	}
 
+	/* vsid and pass are to look at alignments from VAST Search */
+	if ((indx = WWWFindName(www_info, "vsid")) >= 0) {
+		www_arg = WWWGetValueByIndex(www_info, indx);
+		JobID = StringSave(www_arg);
+
+		if ((indx = WWWFindName(www_info, "pass")) < 0) {
+			printf("Content-type: text/html\n\n");
+			printf("<body bgcolor = \"#f0f0f0\">\n");
+			printf("<h2>VAST SEARCH</h2>\n");
+			printf("<h3>Password required.</h3>\n");
+			return 0;
+		}
+		else {
+			www_arg = WWWGetValueByIndex(www_info, indx);
+			pcPass = StringSave(www_arg);
+
+			if ((ret = Check_VastSearch_Password(pcPass, JobID)) != 1) {
+				if (ret == 2) return 0;
+				printf("Content-type: text/html\n\n");
+				printf("<body bgcolor = \"#f0f0f0\">\n");
+				printf("<h2>VAST SEARCH</h2>\n");
+				printf("<h3>Incorrect password.</h3>\n"); 
+				return 0;
+			}
+		}
+	}
+
 	if ((indx = WWWFindName(www_info, "hit")) < 0) {
 		printf("Content-type: text/html\n\n");
+		printf("<body bgcolor = \"#f0f0f0\">\n");
 		printf("<br>\n<h2>No alignment was selected!</h2>\n");
 		printf("<h3>Please click on a box in the leftmost column of the table.</h3>\n");
 		return 0;
@@ -425,8 +472,19 @@ Boolean LIBCALL VastToMage(WWWInfoPtr www_info)
 		printf("<h3>Non-numeric master alignment code - no results.</h3>\n");
 		return 0;
 	}
+        
+        if ((indx = WWWFindName(www_info, "chn_complexity")) < 0)
+            Chain = TRUE;
+        else
+        {
+          www_arg = WWWGetValueByIndex(www_info, indx);
+          complexity =(Int2)atoi(www_arg);
 
-	/* action == 0 indicates MIME; action == 1 is text; action == 2 is save */
+          if (complexity) Chain = TRUE;
+          else Chain = FALSE;
+        }
+	
+        /* action == 0 indicates MIME; action == 1 is text; action == 2 is save */
 	if ((indx = WWWFindName(www_info, "action")) < 0)
 		iPDB = 0;
 	else {
@@ -447,7 +505,11 @@ Boolean LIBCALL VastToMage(WWWInfoPtr www_info)
 	}
  
 	OpenMMDBAPI((POWER_VIEW /* ^ FETCH_ENTREZ */), NULL);
-	pbsa = VASTBsAnnotSetGet(GetGi);
+
+	if (JobID == NULL)
+		pbsa = VASTBsAnnotSetGet(Fsid);
+	else
+		pbsa = LocalGetFeatureSet(GetGi, Fsid, JobID);
 
 	if (pbsa == NULL) {
 		printf("Content-type: text/html\n\n");
@@ -485,8 +547,12 @@ Boolean LIBCALL VastToMage(WWWInfoPtr www_info)
 	 * between the two.  It looks like the slaves are loaded in the latter routine.
 	 * InstBSAnnotSet calls BiostrucAddFeature.
 	 */
-	InstBSAnnotSet(pbsaShort);
+
+        InstBSAnnotSet(pbsaShort, JobID, Chain, VSPATH); /* now uses mmdbapi1 version */
+	pdnmsMaster = GetMasterModelstruc();
+	/***** This is causing a problem at line 126, where pmsdThis->pbsBS does not exist!
 	pdnmsMaster = GetSelectedModelstruc();
+	*****/
 
 	if (pdnmsMaster == NULL) {
 		printf("Content-type: text/html\n\n");
@@ -504,33 +570,23 @@ Boolean LIBCALL VastToMage(WWWInfoPtr www_info)
 		return 0;
 	}
  
-	strcpy(OutputName, GetTempName("vast3")); 
-
-	if((OutputFile = FileOpen(OutputName,WRITE)) == NULL) {
-		printf("Content-type: text/html\n\n");
-		printf("<h2>VASTSERV Error (VastToMage)</h2>\n");
-		printf("<h3>Temp file open failed.</h3>\n");
-		CloseMMDBAPI();
-		return 0;
-	}
-
 	/* Kinemage file generation */
      
      if (iPDB == 2)
      {
-       fprintf(OutputFile, "Content-type: application/octet-stream\n\n");
+       fprintf(stdout, "Content-type: application/octet-stream\n\n");
      }
      else if (iPDB == 1)
      {
-       fprintf(OutputFile, "Content-type: text/html\n\n");  
-       fprintf(OutputFile, "<HTML><body><pre>\n");
+       fprintf(stdout, "Content-type: text/html\n\n");  
+       fprintf(stdout, "<HTML><body><pre>\n");
      }
      else
-       fprintf(OutputFile, "Content-type: chemical/x-kinemage\n\n"); /* MIME */
+       fprintf(stdout, "Content-type: chemical/x-kinemage\n\n"); /* MIME */
   
 	bRender = (Byte) (KIN_VIRTUAL | KIN_HET);
 	iColor = KIN_COLOR_NUMBER;
-	iTest = WriteKinPairAlign(pdnmsMaster, pdnmsSlave, OutputFile, iColor, bRender);
+	iTest = WriteKinPairAlign(pdnmsMaster, pdnmsSlave, stdout, iColor, bRender);
 
   if (!iTest)
     {
@@ -544,12 +600,7 @@ Boolean LIBCALL VastToMage(WWWInfoPtr www_info)
       exit(1);
     }
  
-  fflush(OutputFile);
-  if (OutputFile != stdout)
-    {
-      fclose(OutputFile);
-      PrintFile(OutputName);
-    }
+  fflush(stdout);
     
   CloseMMDBAPI();
   MMDBFini();
