@@ -1,4 +1,4 @@
-/* $Id: ncbi_heapmgr.c,v 6.46 2008/12/19 19:29:37 kazimird Exp $
+/* $Id: ncbi_heapmgr.c,v 6.50 2012/04/19 16:09:32 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -60,7 +60,7 @@
  *
  * Prior to the heap use, the initialization is required, which comprises
  * call to either 'HEAP_Create' or 'HEAP_Attach' with the information about
- * the base heap pointer. 'HEAP_Create' also takes the size of initial
+ * the base heap pointer.  'HEAP_Create' also takes the size of initial
  * heap area (if there is one), and size of chunk (usually, a page size)
  * to be used in heap expansions (defaults to alignment if provided as 0).
  * Additionally (but not compulsory) the application program can provide
@@ -158,36 +158,39 @@ struct SHEAP_tag {
     TNCBI_Size       last;    /* Current index of last heap block (RW heap)  */
     TNCBI_Size       chunk;   /* Aligned;  0 when the heap is read-only      */
     FHEAP_Resize     resize;  /* != NULL when resizeable (RW heap only)      */
-    void*            arg;     /* Aux argument to pass to "resize"            */
-    unsigned int     refc;    /* Reference counter (copy heap, 0=original)   */
+    void*            auxarg;  /* Auxiliary argument to pass to "resize"      */
+    unsigned int     refcnt;  /* Reference count (for heap copy, 0=original) */
     int              serial;  /* Serial number as assigned by (Attach|Copy)  */
 };
 
 
-static int/*bool*/ s_HEAP_fast   = 1/*true*/;
-static int/*bool*/ s_HEAP_newalk = 0/*false*/;
+static int/*bool*/ s_HEAP_fast = 1/*true*/;
 
 
-#define _HEAP_ALIGN(a, b)     (((unsigned long)(a) + (b) - 1) & ~((b) - 1))
+#define _HEAP_ALIGN_EX(a, b)  ((((unsigned long)(a) + ((b) - 1)) / (b)) * (b))
+#define _HEAP_ALIGN(a, b)     (( (unsigned long)(a) + ((b) - 1)) & ~((b) - 1))
 #define _HEAP_ALIGNSHIFT      4
 #define _HEAP_ALIGNMENT       (1 << _HEAP_ALIGNSHIFT)
 #define HEAP_ALIGN(a)         _HEAP_ALIGN(a, _HEAP_ALIGNMENT)
 #define HEAP_LAST             0x80000000UL
 #define HEAP_USED             0x0DEAD2F0UL
 #define HEAP_FREE             0
-#define HEAP_NEXT(b)          ((SHEAP_HeapBlock*)((char*) b + b->head.size))
+#define HEAP_NEXT(b)          ((SHEAP_HeapBlock*)((char*)(b) + (b)->head.size))
 #define HEAP_INDEX(b, base)   ((TNCBI_Size)((b) - (base)))
 #define HEAP_ISFREE(b)        (((b)->head.flag & ~HEAP_LAST) == HEAP_FREE)
 #define HEAP_ISUSED(b)        (((b)->head.flag & ~HEAP_LAST) == HEAP_USED)
 #define HEAP_ISLAST(b)        ( (b)->head.flag &  HEAP_LAST)
 
 
-HEAP HEAP_Create(void* base,       TNCBI_Size   size,
-                 TNCBI_Size chunk, FHEAP_Resize resize, void* arg)
+HEAP HEAP_Create(void*      base,  TNCBI_Size   size,
+                 TNCBI_Size chunk, FHEAP_Resize resize, void* auxarg)
 {
     HEAP heap;
 
     assert(_HEAP_ALIGNMENT == sizeof(SHEAP_HeapBlock));
+    assert(_HEAP_ALIGN_EX(1, sizeof(SHEAP_Block)) ==
+           _HEAP_ALIGN   (1, sizeof(SHEAP_Block)));
+
     if (!base != !size)
         return 0;
     if (size  &&  size < _HEAP_ALIGNMENT) {
@@ -199,15 +202,14 @@ HEAP HEAP_Create(void* base,       TNCBI_Size   size,
     }
     if (!(heap = (HEAP) malloc(sizeof(*heap))))
         return 0;
-    size &= ~(_HEAP_ALIGNMENT - 1);
     heap->base   = (SHEAP_HeapBlock*) base;
     heap->size   = size >> _HEAP_ALIGNSHIFT;
     heap->free   = 0;
     heap->last   = 0;
-    heap->chunk  = chunk        ? (TNCBI_Size) HEAP_ALIGN(chunk) : 0;
-    heap->resize = heap->chunk  ? resize                         : 0;
-    heap->arg    = heap->resize ? arg                            : 0;
-    heap->refc   = 0/*original*/;
+    heap->chunk  = chunk        ? HEAP_ALIGN(chunk) : 0;
+    heap->resize = heap->chunk  ? resize            : 0;
+    heap->auxarg = heap->resize ? auxarg            : 0;
+    heap->refcnt = 0/*original*/;
     heap->serial = 0;
     if (base) {
         SHEAP_HeapBlock* b = heap->base;
@@ -218,7 +220,7 @@ HEAP HEAP_Create(void* base,       TNCBI_Size   size,
                          (long) base));
         }
         b->head.flag = HEAP_FREE | HEAP_LAST;
-        b->head.size = size;
+        b->head.size = size & ~(_HEAP_ALIGNMENT - 1);
         b->nextfree  = 0;
         b->prevfree  = 0;
     }
@@ -231,6 +233,9 @@ HEAP HEAP_AttachFast(const void* base, TNCBI_Size size, int serial)
     HEAP heap;
 
     assert(_HEAP_ALIGNMENT == sizeof(SHEAP_HeapBlock));
+    assert(_HEAP_ALIGN_EX(1, sizeof(SHEAP_Block)) ==
+           _HEAP_ALIGN   (1, sizeof(SHEAP_Block)));
+
     if (!base != !size  ||  !(heap = (HEAP) calloc(1, sizeof(*heap))))
         return 0;
     if (_HEAP_ALIGN(base, sizeof(SHEAP_Block)) != (unsigned long) base) {
@@ -238,23 +243,23 @@ HEAP HEAP_AttachFast(const void* base, TNCBI_Size size, int serial)
                     ("Heap Attach: Unaligned base (0x%08lX)", (long) base));
     }
     heap->base   = (SHEAP_HeapBlock*) base;
-    heap->size   = HEAP_ALIGN(size) >> _HEAP_ALIGNSHIFT;
+    heap->size   = size >> _HEAP_ALIGNSHIFT;
     heap->serial = serial;
     if (size != heap->size << _HEAP_ALIGNSHIFT) {
         CORE_LOGF_X(4, eLOG_Warning,
-                    ("Heap Attach: Heap size alignment (%u->%u) "
-                     "can result in garbage in data",
+                    ("Heap Attach: Heap size truncation (%u->%u) "
+                     "can result in missing data",
                      size, heap->size << _HEAP_ALIGNSHIFT));
     }
     return heap;
 }
 
 
-HEAP HEAP_Attach(const void* base, int serial)
+HEAP HEAP_AttachEx(const void* base, TNCBI_Size maxsize, int serial)
 {
     TNCBI_Size size = 0;
 
-    if (base) {
+    if (base  &&  (!maxsize  ||  maxsize > sizeof(SHEAP_Block))) {
         const SHEAP_HeapBlock* b = (const SHEAP_HeapBlock*) base;
         for (;;) {
             if (!HEAP_ISUSED(b)  &&  !HEAP_ISFREE(b)) {
@@ -265,6 +270,17 @@ HEAP HEAP_Attach(const void* base, int serial)
                 return 0;
             }
             size += b->head.size;
+            if (maxsize  &&
+                (maxsize < size  ||
+                 (maxsize - size < sizeof(SHEAP_Block)  &&  !HEAP_ISLAST(b)))){
+                CORE_LOGF_X(34, eLOG_Error,
+                            ("Heap Attach: Runaway heap @%u (0x%08X, %u)"
+                             " size=%u vs. maxsize=%u",
+                             HEAP_INDEX(b, (SHEAP_HeapBlock*) base),
+                             b->head.flag, b->head.size,
+                             size, maxsize));
+                return 0;
+            }
             if (HEAP_ISLAST(b))
                 break;
             b = HEAP_NEXT(b);
@@ -274,6 +290,12 @@ HEAP HEAP_Attach(const void* base, int serial)
 }
 
 
+HEAP HEAP_Attach(const void* base, int serial)
+{
+    return HEAP_AttachEx(base, 0, serial);
+}
+
+
 /* Collect garbage in the heap, moving all contents to the
  * top, and merging all free blocks at the end into a single
  * large free block.  Return pointer to that free block, or
@@ -282,7 +304,7 @@ HEAP HEAP_Attach(const void* base, int serial)
 static SHEAP_HeapBlock* s_HEAP_Collect(HEAP heap, TNCBI_Size* prev)
 {
     SHEAP_HeapBlock* b = heap->base;
-    SHEAP_HeapBlock *f = 0;
+    SHEAP_HeapBlock* f = 0;
     TNCBI_Size free = 0;
 
     *prev = 0;
@@ -378,7 +400,7 @@ static SHEAP_Block* s_HEAP_Book(HEAP heap, SHEAP_HeapBlock* b,
             heap->base[b->nextfree].prevfree = b->prevfree;
             heap->base[b->prevfree].nextfree = b->nextfree;
             if (heap->free == size)
-                heap->free = b->prevfree;
+                heap->free =  b->prevfree;
         } else {
             /* the only free block */
             assert(b->prevfree == b->nextfree);
@@ -392,12 +414,12 @@ static SHEAP_Block* s_HEAP_Book(HEAP heap, SHEAP_HeapBlock* b,
 
 
 static SHEAP_Block* s_HEAP_Take(HEAP heap, SHEAP_HeapBlock* b,
-                                TNCBI_Size size, TNCBI_Size real,
+                                TNCBI_Size size, TNCBI_Size need,
                                 int/*bool*/ fast)
 {
     SHEAP_Block* n = s_HEAP_Book(heap, b, size, fast);
-    if (size -= real)
-        memset((char*) n + real, 0, size); /* block padding (if any) zeroed */
+    if (size -= need)
+        memset((char*) n + need, 0, size); /* block padding (if any) zeroed */
     return n;
 }
 
@@ -406,12 +428,12 @@ static const char* s_HEAP_Id(char* buf, HEAP h)
 {
     if (!h)
         return "";
-    if (h->serial  &&  h->refc)
-        sprintf(buf, "[C%d%sR%u]", abs(h->serial),&"-"[h->serial > 0],h->refc);
+    if (h->serial  &&  h->refcnt)
+        sprintf(buf,"[C%d%sR%u]",abs(h->serial),&"-"[h->serial > 0],h->refcnt);
     else if (h->serial)
-        sprintf(buf, "[C%d%s]", abs(h->serial), &"-"[h->serial > 0]);
-    else if (h->refc)
-        sprintf(buf, "[R%u]", h->refc);
+        sprintf(buf,"[C%d%s]", abs(h->serial), &"-"[h->serial > 0]);
+    else if (h->refcnt)
+        sprintf(buf,"[R%u]", h->refcnt);
     else
         strcpy(buf, "");
     return buf;
@@ -440,18 +462,23 @@ static SHEAP_Block* s_HEAP_Alloc(HEAP heap, TNCBI_Size size, int/*bool*/ fast)
         return 0;
 
     size += (TNCBI_Size) sizeof(SHEAP_Block);
-    need  = (TNCBI_Size) HEAP_ALIGN(size);
+    need  = HEAP_ALIGN(size);
 
     free = 0;
     if (heap->free < heap->size) {
         f = heap->base + heap->free;
         b = f;
         do {
-            if (!HEAP_ISFREE(b)) {
+            if (!HEAP_ISFREE(b)
+                ||  (!fast  &&
+                     ((char*) b + b->head.size >
+                      (char*)(heap->base + heap->size)  ||
+                      heap->base + b->nextfree > heap->base + heap->size))) {
                 CORE_LOGF_X(8, eLOG_Error,
                             ("Heap Alloc%s: Heap%s corrupt "
                              "@%u/%u (0x%08X, %u)",
-                             s_HEAP_Id(_id, heap), b == f ? " header" : "",
+                             s_HEAP_Id(_id, heap),
+                             b == f  &&  !HEAP_ISFREE(b) ? " header" : "",
                              HEAP_INDEX(b, heap->base), heap->size,
                              b->head.flag, b->head.size));
                 return 0;
@@ -463,17 +490,16 @@ static SHEAP_Block* s_HEAP_Alloc(HEAP heap, TNCBI_Size size, int/*bool*/ fast)
         } while (b != f);
     }
 
-    /* Heap exhausted: no large enough, free block found */
+    /* Heap exhausted: no large enough and free block found */
     if (free >= need)
         b = s_HEAP_Collect(heap, &free/*dummy*/);
     else if (!heap->resize)
         return 0;
     else {
         TNCBI_Size dsize = heap->size << _HEAP_ALIGNSHIFT;
-        TNCBI_Size hsize = ((dsize + need + heap->chunk - 1)
-                            / heap->chunk) * heap->chunk;
+        TNCBI_Size hsize = _HEAP_ALIGN_EX(dsize + need, heap->chunk);
         SHEAP_HeapBlock* base = (SHEAP_HeapBlock*)
-            heap->resize(heap->base, hsize, heap->arg);
+            heap->resize(heap->base, hsize, heap->auxarg);
         if (_HEAP_ALIGN(base, sizeof(SHEAP_Block)) != (unsigned long) base) {
             CORE_LOGF_X(9, eLOG_Warning,
                         ("Heap Alloc%s: Unaligned base (0x%08lX)",
@@ -703,84 +729,134 @@ static SHEAP_Block* s_HEAP_Walk(const HEAP heap, const SHEAP_Block* ptr)
     SHEAP_HeapBlock* b;
     char _id[32];
 
-    if (!p  ||  (p >= heap->base  &&  p < heap->base + heap->size)) {
-        b = p ? HEAP_NEXT(p) : heap->base;
-        if (b < heap->base + heap->size  &&  b->head.size > sizeof(SHEAP_Block)
-            &&  HEAP_NEXT(b) <= heap->base + heap->size) {
-            if ((HEAP_ISFREE(b) || HEAP_ISUSED(b))  &&
-                (!s_HEAP_newalk || HEAP_ALIGN(b->head.size) == b->head.size)) {
-                if (s_HEAP_newalk) {
-                    if (HEAP_ISUSED(b)  &&  heap->chunk/*RW heap*/  &&
-                        heap->base + heap->free == b) {
-                        CORE_LOGF_X(20, eLOG_Warning,
-                                    ("Heap Walk%s: Used block @ free ptr %u",
-                                     s_HEAP_Id(_id, heap), heap->free));
-                    } else if (HEAP_ISFREE(b)
-                               &&  (b->prevfree >= heap->size  ||
-                                    b->nextfree >= heap->size  ||
-                                    !HEAP_ISFREE(heap->base + b->prevfree)  ||
-                                    !HEAP_ISFREE(heap->base + b->nextfree)  ||
-                                    (b->prevfree != b->nextfree
-                                     &&  (heap->base + b->prevfree == b  ||
-                                          heap->base + b->nextfree == b)))) {
-                        CORE_LOGF_X(21, eLOG_Warning,
-                                    ("Heap Walk%s: Free list corrupt @%u/%u"
-                                     " (%u, <-%u, %u->)", s_HEAP_Id(_id, heap),
-                                     HEAP_INDEX(b, heap->base), heap->size,
-                                     b->head.size, b->prevfree, b->nextfree));
-                    }
-                }
-                /* Block 'b' seems okay for walking onto, but... */
-                if (!p)
-                    return &b->head;
-                if (HEAP_ISLAST(p)) {
-                    CORE_LOGF_X(22, eLOG_Error,
-                                ("Heap Walk%s: Misplaced last block @%u",
-                                 s_HEAP_Id(_id,heap),
-                                 HEAP_INDEX(p, heap->base)));
-                } else if (s_HEAP_newalk  &&  heap->chunk/*RW heap*/  &&
-                           HEAP_ISLAST(b)  &&  heap->base + heap->last != b) {
-                    CORE_LOGF_X(23, eLOG_Error,
-                                ("Heap Walk%s: Last block @%u "
-                                 "not @ last ptr %u",
-                                 s_HEAP_Id(_id, heap),
-                                 HEAP_INDEX(b, heap->base), heap->last));
-                } else if (HEAP_ISFREE(p)  &&  HEAP_ISFREE(b)) {
-                    const SHEAP_HeapBlock* c = heap->base;
-                    while (c < p) {
-                        if (HEAP_ISFREE(c)  &&  HEAP_NEXT(c) >= HEAP_NEXT(b))
-                            break;
-                        c = HEAP_NEXT(c);
-                    }
-                    if (c < p)
-                        return &b->head;
-                    CORE_LOGF_X(24, eLOG_Error,
-                                ("Heap Walk%s: Adjacent free blocks "
-                                 "@%u and @%u",
-                                 s_HEAP_Id(_id, heap),
-                                 HEAP_INDEX(p, heap->base),
-                                 HEAP_INDEX(b, heap->base)));
-                } else
-                    return &b->head;
-            } else {
-                CORE_LOGF_X(25, eLOG_Error,
-                            ("Heap Walk%s: Heap corrupt @%u/%u (0x%08X, %u)",
-                             s_HEAP_Id(_id, heap), HEAP_INDEX(b, heap->base),
-                             heap->size, b->head.flag, b->head.size));
-            }
-        } else if (b > heap->base + heap->size) {
+    if (p  &&  (p < heap->base  ||  p >= heap->base + heap->size
+                ||  p->head.size <= sizeof(SHEAP_Block)
+                ||  HEAP_ALIGN(p->head.size) != p->head.size
+                ||  (!HEAP_ISFREE(p)  &&  !HEAP_ISUSED(p)))) {
+        CORE_LOGF_X(28, eLOG_Error,
+                    ("Heap Walk%s: Alien pointer",
+                     s_HEAP_Id(_id, heap)));
+        return 0;
+    }
+    b = p ? HEAP_NEXT(p) : heap->base;
+
+    if (b >= heap->base + heap->size
+        ||  b->head.size <= sizeof(SHEAP_Block)
+        ||  HEAP_ALIGN(b->head.size) != b->head.size
+        ||  (!HEAP_ISFREE(b)  &&  !HEAP_ISUSED(b))
+        ||  HEAP_NEXT(b) > heap->base + heap->size) {
+        if (b != heap->base + heap->size  ||  (b  &&  !p)) {
             CORE_LOGF_X(26, eLOG_Error,
-                        ("Heap Walk%s: Heap corrupt", s_HEAP_Id(_id, heap)));
+                        ("Heap Walk%s: Heap corrupt",
+                         s_HEAP_Id(_id, heap)));
         } else if (b  &&  !HEAP_ISLAST(p)) {
             CORE_LOGF_X(27, eLOG_Error,
                         ("Heap Walk%s: Last block lost",
                          s_HEAP_Id(_id, heap)));
         }
-    } else {
-        CORE_LOGF_X(28, eLOG_Error,
-                    ("Heap Walk%s: Alien pointer", s_HEAP_Id(_id, heap)));
+        return 0;
     }
-    return 0;
+
+    if (HEAP_ISFREE(b)) {
+        const SHEAP_HeapBlock* c = b;
+        if (c->prevfree >= heap->size  ||
+            c->nextfree >= heap->size  ||
+            !HEAP_ISFREE(heap->base + c->prevfree)  ||
+            !HEAP_ISFREE(heap->base + c->nextfree)) {
+            c = 0;
+        } else if (c->prevfree == c->nextfree  &&
+                   heap->base  +  c->nextfree == c) {
+            if (heap->chunk/*RW heap*/  &&  heap->base + heap->free != c)
+                c = 0;
+        } else {
+            int/*bool*/ origin = !heap->chunk/*RW: false, RO: true*/;
+            size_t n;
+            for (n = 0;  n < heap->size;  n++) {
+                const SHEAP_HeapBlock* s = c;
+                c = heap->base + c->nextfree;
+                if (!HEAP_ISFREE(c)  ||  c == s
+                    ||  c->nextfree >= heap->size
+                    ||  c->prevfree != s->nextfree) {
+                    c = 0;
+                    break;
+                }
+                if (c == heap->base + heap->free)
+                    origin = 1/*true*/;
+                if (c == b) {
+                    if (!origin)
+                        c = s/*NB: != c => != b*/;
+                    break;
+                }
+            }
+        }
+        if (!c  ||  c != b) {
+            CORE_LOGF_X(21, eLOG_Error,
+                        ("Heap Walk%s: Free list %s @%u/%u"
+                         " (%u, <-%u, %u->)",
+                         s_HEAP_Id(_id, heap),
+                         c ? "broken" : "corrupt",
+                         HEAP_INDEX(b, heap->base), heap->size,
+                         b->head.size, b->prevfree, b->nextfree));
+            return 0;
+        }
+    }
+    if (HEAP_ISUSED(b)  &&  heap->chunk/*RW heap*/) {
+        size_t n;
+        /* check that a used block is not within the free chain but
+           ignoring any inconsistencies in the free chain here */
+        const SHEAP_HeapBlock* c = heap->base + heap->free;
+        for (n = 0;  c < heap->base + heap->size  &&  n < heap->size;  ++n) {
+            if (!HEAP_ISFREE(c))
+                break;
+            if (c <= b  &&  b < HEAP_NEXT(c)) {
+                CORE_LOGF_X(20, eLOG_Error,
+                            ("Heap Walk%s: Used block @%u within"
+                             " the free one @%u",
+                             s_HEAP_Id(_id, heap),
+                             HEAP_INDEX(b, heap->base),
+                             HEAP_INDEX(c, heap->base)));
+                return 0;
+            }
+            if (c == heap->base + c->nextfree)
+                break;
+            c = heap->base + c->nextfree;
+            if (c == heap->base + heap->free)
+                break;
+        }
+    }
+
+    /* Block 'b' seems okay for walking onto, but... */
+    if (p) {
+        if (HEAP_ISLAST(p)) {
+            CORE_LOGF_X(22, eLOG_Error,
+                        ("Heap Walk%s: Misplaced last block @%u",
+                         s_HEAP_Id(_id,heap),
+                         HEAP_INDEX(p, heap->base)));
+        } else if (heap->chunk/*RW heap*/
+                   &&  HEAP_ISLAST(b)  &&  heap->base + heap->last != b) {
+            CORE_LOGF_X(23, eLOG_Error,
+                        ("Heap Walk%s: Last block @%u "
+                         "not @ last ptr %u",
+                         s_HEAP_Id(_id, heap),
+                         HEAP_INDEX(b, heap->base), heap->last));
+        } else if (HEAP_ISFREE(p)  &&  HEAP_ISFREE(b)) {
+            const SHEAP_HeapBlock* c = heap->base;
+            while (c < p) {
+                if (HEAP_ISFREE(c)  &&  HEAP_NEXT(c) >= HEAP_NEXT(b))
+                    break;
+                c = HEAP_NEXT(c);
+            }
+            if (c >= p) {
+                CORE_LOGF_X(24, eLOG_Error,
+                            ("Heap Walk%s: Adjacent free blocks "
+                             "@%u and @%u",
+                             s_HEAP_Id(_id, heap),
+                             HEAP_INDEX(p, heap->base),
+                             HEAP_INDEX(b, heap->base)));
+            }
+        }
+    }
+    return &b->head;
 }
 
 
@@ -793,10 +869,10 @@ SHEAP_Block* HEAP_Walk(const HEAP heap, const SHEAP_Block* ptr)
     assert(!heap->base == !heap->size);
 
     if (s_HEAP_fast) {
-        SHEAP_HeapBlock* b = (SHEAP_HeapBlock*) ptr;
-        if (!b)
+        SHEAP_HeapBlock* b;
+        if (!ptr)
             return &heap->base->head;
-        b = HEAP_NEXT(b);
+        b = HEAP_NEXT((SHEAP_HeapBlock*) ptr);
         return b < heap->base + heap->size ? &b->head : 0;
     }
     return s_HEAP_Walk(heap, ptr);
@@ -837,7 +913,7 @@ HEAP HEAP_Trim(HEAP heap)
 
     if (heap->resize) {
         SHEAP_HeapBlock* base = (SHEAP_HeapBlock*)
-            heap->resize(heap->base, hsize, heap->arg);
+            heap->resize(heap->base, hsize, heap->auxarg);
         if (!hsize)
             assert(!base);
         else if (!base)
@@ -873,70 +949,82 @@ HEAP HEAP_Trim(HEAP heap)
 
 HEAP HEAP_Copy(const HEAP heap, size_t extra, int serial)
 {
-    HEAP       newheap;
-    TNCBI_Size size, hsize;
+    HEAP       copy;
+    TNCBI_Size size;
+
+    assert(_HEAP_ALIGN_EX(1, sizeof(SHEAP_Block)) ==
+           _HEAP_ALIGN   (1, sizeof(SHEAP_Block)));
 
     if (!heap)
         return 0;
     assert(!heap->base == !heap->size);
 
-    size  = _HEAP_ALIGN(sizeof(*newheap), sizeof(SHEAP_Block));
-    hsize = heap->size << _HEAP_ALIGNSHIFT;
-    if (!(newheap = (HEAP) malloc(size + hsize + extra)))
+    size = heap->size << _HEAP_ALIGNSHIFT;
+    copy = (HEAP) malloc(sizeof(*copy) +
+                         (size ? sizeof(SHEAP_Block) - 1 + size : 0) + extra);
+    if (!copy)
         return 0;
-    newheap->base = (SHEAP_HeapBlock*)(heap->base ? (char*)newheap + size : 0);
-    newheap->size   = heap->size;
-    newheap->free   = 0;
-    newheap->chunk  = 0/*read-only*/;
-    newheap->resize = 0;
-    newheap->arg    = 0;
-    newheap->refc   = 1/*copy*/;
-    newheap->serial = serial;
-    if (hsize) {
-        memcpy(newheap->base, heap->base, hsize);
-        assert(memset((char*) newheap->base + hsize, 0, extra));
+    if (size) {
+        char* base = (char*) copy + sizeof(*copy);
+        base += _HEAP_ALIGN(base, sizeof(SHEAP_Block)) - (unsigned long) base;
+        assert(_HEAP_ALIGN(base, sizeof(SHEAP_Block)) == (unsigned long) base);
+        copy->base = (SHEAP_HeapBlock*) base;
+    } else
+        copy->base = 0;
+    copy->size   = heap->size;
+    copy->free   = 0;
+    copy->chunk  = 0/*read-only*/;
+    copy->resize = 0;
+    copy->auxarg = 0;
+    copy->refcnt = 1/*copy*/;
+    copy->serial = serial;
+    if (size) {
+        memcpy(copy->base, heap->base, size);
+        assert(memset((char*) copy->base + size, 0, extra));
     }
-    return newheap;
+    return copy;
 }
 
 
-void HEAP_AddRef(HEAP heap)
+unsigned int HEAP_AddRef(HEAP heap)
 {
     if (!heap)
-        return;
+        return 0;
     assert(!heap->base == !heap->size);
-    if (heap->refc) {
-        heap->refc++;
-        assert(heap->refc);
+    if (heap->refcnt) {
+        heap->refcnt++;
+        assert(heap->refcnt);
     }
+    return heap->refcnt;
 }
 
 
-void HEAP_Detach(HEAP heap)
+unsigned int HEAP_Detach(HEAP heap)
 {
     if (!heap)
-        return;
+        return 0;
     assert(!heap->base == !heap->size);
-    if (!heap->refc  ||  !--heap->refc) {
-        memset(heap, 0, sizeof(*heap));
-        free(heap);
-    }
+    if (heap->refcnt  &&  --heap->refcnt)
+        return heap->refcnt;
+    memset(heap, 0, sizeof(*heap));
+    free(heap);
+    return 0;
 }
 
 
-void HEAP_Destroy(HEAP heap)
+unsigned int HEAP_Destroy(HEAP heap)
 {
     char _id[32];
 
     if (!heap)
-        return;
+        return 0;
     assert(!heap->base == !heap->size);
-    if (!heap->chunk  &&  !heap->refc) {
+    if (!heap->chunk  &&  !heap->refcnt) {
         CORE_LOGF_X(33, eLOG_Error,
                     ("Heap Destroy%s: Heap read-only", s_HEAP_Id(_id, heap)));
     } else if (heap->resize/*NB: NULL for heap copies*/)
-        verify(heap->resize(heap->base, 0, heap->arg) == 0);
-    HEAP_Detach(heap);
+        verify(heap->resize(heap->base, 0, heap->auxarg) == 0);
+    return HEAP_Detach(heap);
 }
 
 
@@ -967,7 +1055,8 @@ int HEAP_Serial(const HEAP heap)
 }
 
 
-void HEAP_Options(ESwitch fast, ESwitch newalk)
+/*ARGSUSED*/
+void HEAP_Options(ESwitch fast, ESwitch ignored)
 {
     switch (fast) {
     case eOff:
@@ -978,13 +1067,4 @@ void HEAP_Options(ESwitch fast, ESwitch newalk)
     default:
         break;
     }
-    switch (newalk) {
-    case eOff:
-        s_HEAP_newalk = 0/*false*/;
-        break;
-    case eOn:
-        s_HEAP_newalk = 1/*true*/;
-    default:
-        break;
-    }
 }
