@@ -1,7 +1,7 @@
 #ifndef CONNECT___NCBI_SERVICE_CONNECTOR__H
 #define CONNECT___NCBI_SERVICE_CONNECTOR__H
 
-/*  $Id: ncbi_service_connector.h,v 6.11 2005/08/12 19:20:06 lavr Exp $
+/* $Id: ncbi_service_connector.h,v 6.13 2011/05/26 19:09:31 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -50,18 +50,19 @@
 extern "C" {
 #endif
 
-
-typedef const SSERV_Info* (*FSERVICE_GetNextInfo)(SERV_ITER iter, void* data);
-typedef void              (*FSERVICE_CleanupData)(void* data);
+    
 typedef void              (*FSERVICE_ResetData)  (void* data);
+typedef void              (*FSERVICE_CleanupData)(void* data);
+typedef const SSERV_Info* (*FSERVICE_GetNextInfo)(void* data, SERV_ITER iter);
 
 
 typedef struct {
     void*                data;
-    FSERVICE_ResetData   reset;         /* called at each close           */
-    FSERVICE_CleanupData cleanup;       /* called at destruction          */
-    FSERVICE_GetNextInfo get_next_info; /* called to get conn point       */
-    THCC_Flags           flags;         /* only fHCC_Flushable is honored */
+    FSERVICE_ResetData   reset;         /* called at each close (before iter)*/
+    FSERVICE_CleanupData cleanup;       /* called at destruction             */
+    FSERVICE_GetNextInfo get_next_info; /* called to get conn point          */
+    FHTTP_ParseHeader    parse_header;  /* called if data source is HTTP     */
+    THTTP_Flags          flags;         /* fHCC_Flushable | fHCC_NoAutoRetry */
 } SSERVICE_Extra;
 
 
@@ -83,45 +84,4 @@ extern NCBI_XCONNECT_EXPORT CONNECTOR SERVICE_CreateConnectorEx
 
 /* @} */
 
-
-/*
- * --------------------------------------------------------------------------
- * $Log: ncbi_service_connector.h,v $
- * Revision 6.11  2005/08/12 19:20:06  lavr
- * +SSERVICE_Extra::flags (for fHCC_Flushable)
- *
- * Revision 6.10  2003/04/09 19:05:52  siyan
- * Added doxygen support
- *
- * Revision 6.9  2003/01/17 19:44:20  lavr
- * Reduce dependencies
- *
- * Revision 6.8  2003/01/08 01:59:33  lavr
- * DLL-ize CONNECT library for MSVC (add NCBI_XCONNECT_EXPORT)
- *
- * Revision 6.7  2002/09/19 18:05:09  lavr
- * Header file guard macro changed; log moved to end
- *
- * Revision 6.6  2002/04/26 16:27:13  lavr
- * SSERVICE_Params: reset added for use in open/close pairs
- *
- * Revision 6.5  2001/09/24 20:25:11  lavr
- * +SSERVICE_Extra, +4th parameter for SERVICE_CreateConnectorEx()
- * -SERVICE_CreateConnector() - now implemented as macro
- *
- * Revision 6.4  2001/09/10 21:20:19  lavr
- * Few unimportant layout changes
- *
- * Revision 6.3  2001/06/04 17:00:18  lavr
- * Include files adjusted
- *
- * Revision 6.2  2000/12/29 17:48:34  lavr
- * Accepted server types included in SERVICE_CreateConnectorEx arguments.
- *
- * Revision 6.1  2000/10/07 22:15:12  lavr
- * Initial revision
- *
- * ==========================================================================
- */
-
 #endif /* CONNECT___NCBI_SERVICE_CONNECTOR__H */
