@@ -1,7 +1,7 @@
 #ifndef CONNECT___NCBI_TYPES__H
 #define CONNECT___NCBI_TYPES__H
 
-/* $Id: ncbi_types.h,v 6.16 2009/11/10 15:54:40 kazimird Exp $
+/* $Id: ncbi_types.h,v 6.22 2012/05/02 19:19:42 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -48,6 +48,13 @@
  */
 
 #include <connect/connect_export.h>
+#ifndef _WIN32
+#  ifndef   __STDC_FORMAT_MACROS
+#    define __STDC_FORMAT_MACROS
+#  endif /*!__STDC_FORMAT_MACROS*/
+#  include <inttypes.h>
+#  include <stdint.h>
+#endif /*_WIN32*/
 #include <stddef.h>
 
 
@@ -67,8 +74,8 @@ extern "C" {
  * @sa CTimeout, g_CTimeoutToSTimeout, g_STimeoutToCTimeout
  */
 typedef struct STimeoutTag {
-    unsigned int sec;  /**< seconds (truncated to the platf.-dep. max. limit)*/
-    unsigned int usec; /**< microseconds (always truncated by mod. 1,000,000)*/
+    unsigned int sec;  /**< seconds                         */
+    unsigned int usec; /**< microseconds (modulo 1,000,000) */
 } STimeout;
 
 #define kDefaultTimeout  ((const STimeout*)(-1))
@@ -97,18 +104,42 @@ extern NCBI_XCONNECT_EXPORT STimeout*     NcbiMsToTimeout
  * type, please apply equivalent changes to both definitions.
  */
 
-/** Aux. enum to set/unset/default various features
+/** Aux. enum to set/unset/default various features.
  */
-typedef enum {
+typedef enum ENcbiSwitch {
     eOff = 0,
     eOn,
     eDefault
 } ESwitch;
 
-#endif  /* !defined(NCBI_ESWITCH_DEFINED) */
+#endif /*!NCBI_ESWITCH_DEFINED*/
 
 
-/** Fixed size analogs of size_t and time_t (mainly for IPC)
+#ifndef NCBI_EOWNERSHIP_DEFINED
+#define NCBI_EOWNERSHIP_DEFINED
+
+/*
+ * ATTENTION!   Do not change this enumeration!
+ *
+ * It must always be kept in sync with its C++ counterpart defined in
+ * "corelib/ncbimisc.hpp". If you absolutely(sic!) need to alter this
+ * type, please apply equivalent changes to both definitions.
+ */
+
+/** Ownership relations between objects.
+ *
+ * Can be used to define or transfer ownership of objects.
+ * For example, specify if a CSocket object owns its underlying SOCK object.
+ */
+typedef enum ENcbiOwnership {
+    eNoOwnership,       /** No ownership is assumed                 */
+    eTakeOwnership      /** An object can take ownership of another */
+} EOwnership;
+
+#endif /*!NCBI_EOWNERSHIP_DEFINED*/
+
+
+/** Fixed-size analogs of size_t and time_t (mainly for IPC)
  */
 typedef unsigned int TNCBI_Size;
 typedef unsigned int TNCBI_Time;
@@ -116,6 +147,21 @@ typedef unsigned int TNCBI_Time;
 #define NCBI_TIME_INFINITE ((TNCBI_Time)(-1))
 
 
+/** Big integer for file size and position
+ */
+
+#if defined(__MINGW32__)  ||  defined(__MINGW64__)
+typedef unsigned long long TNCBI_BigCount;
+#  define NCBI_BIGCOUNT_FORMAT_SPEC "I64u"
+#elif defined(_WIN32)
+typedef unsigned __int64   TNCBI_BigCount;
+#  define NCBI_BIGCOUNT_FORMAT_SPEC "I64u"
+#else
+typedef uint64_t           TNCBI_BigCount;
+#  define NCBI_BIGCOUNT_FORMAT_SPEC PRIu64
+#endif
+
+
 #ifdef __cplusplus
 }  /* extern "C" */
 #endif
