@@ -1,4 +1,4 @@
-/* $Id: test_ncbi_core.c,v 6.20 2010/02/05 20:35:04 kazimird Exp $
+/* $Id: test_ncbi_core.c,v 6.23 2011/02/16 15:02:10 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -33,6 +33,7 @@
  */
 
 #include <connect/ncbi_util.h>
+#include "../ncbi_ansi_ext.h"
 #include "../ncbi_assert.h"
 #include <stdlib.h>
 #include <errno.h>
@@ -337,14 +338,36 @@ static void TEST_UTIL_Log(void)
 }
 
 
+/* NOTE: closes STDIN */
 static void TEST_CORE_GetUsername(void)
 {
+    static const char* null =
+#ifdef NCBI_OS_MSWIN
+        "NUL"
+#else
+        "/dev/null"
+#endif /*NCBI_OS_MSWIN*/
+        ;
     char buffer[512];
-    const char* username = CORE_GetUsername(buffer, sizeof(buffer));
+    const char* temp = CORE_GetUsername(buffer, sizeof(buffer));
+    char* user = temp  &&  *temp ? strdup(temp) : 0;
+    printf("Username = %s%s%s%s\n",
+           temp ? (*temp ? "" : "\"") : "<",
+           temp ?   temp              : "NULL",
+           temp ? (*temp ? "" : "\"") : ">",
+           !temp ^ !user ? ", error!" : "");
+    verify(freopen(null, "r", stdin));
+    temp = CORE_GetUsername(buffer, sizeof(buffer));
     printf("Username = %s%s%s\n",
-           username ? (*username ? "" : "\"") : "<",
-           username ?   username              : "NULL",
-           username ? (*username ? "" : "\"") : ">");
+           temp ? (*temp ? "" : "\"") : "<",
+           temp ?   temp              : "NULL",
+           temp ? (*temp ? "" : "\"") : ">");
+    if (temp  &&  !*temp)
+        temp = 0;
+    assert((!temp  &&  !user)  ||
+           ( temp  &&   user  &&  strcasecmp(temp, user) == 0));
+    if (user)
+        free(user);
 }
 
 
