@@ -1,4 +1,4 @@
-/*  $Id: test_ncbi_disp.c,v 6.35 2009/02/03 16:39:35 kazimird Exp $
+/* $Id: test_ncbi_disp.c,v 6.38 2010/06/04 14:59:37 kazimird Exp $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -33,8 +33,6 @@
 #include "../ncbi_ansi_ext.h"
 #include "../ncbi_lbsmd.h"
 #include "../ncbi_priv.h"               /* CORE logging facilities */
-#include "../ncbi_servicep.h"
-#include <connect/ncbi_heapmgr.h>
 #include <stdlib.h>
 #include <time.h>
 /* This header must go last */
@@ -180,7 +178,7 @@ int main(int argc, const char* argv[])
     }
 
     if (n_found != 0)
-        CORE_LOGF(eLOG_Note, ("Test complete: %d server(s) found", n_found));
+        CORE_LOGF(eLOG_Note, ("%d server(s) found", n_found));
     else
         CORE_LOG(eLOG_Fatal, "Requested service not found");
 
@@ -203,6 +201,7 @@ int main(int argc, const char* argv[])
     }
 #endif
 
+    CORE_LOG(eLOG_Note, "TEST completed successfully");
     CORE_SetLOG(0);
     return 0;
 }
