@@ -1,4 +1,4 @@
-/* $Id: ncbithr.c,v 6.32 2001/12/14 21:09:20 ivanov Exp $ */
+/* $Id: ncbithr.c,v 6.38 2003/12/04 18:02:43 rsmith Exp $ */
 /*****************************************************************************
 
     Name: ncbithr.c
@@ -35,6 +35,25 @@
  Modification History:
 -----------------------------------------------------------------------------
 * $Log: ncbithr.c,v $
+* Revision 6.38  2003/12/04 18:02:43  rsmith
+* Move includes out of definition of NlmCPUNumber.
+*
+* Revision 6.37  2003/09/19 22:58:38  coulouri
+* NetBSD does not (yet?) have pthread_attr_setschedpolicy()
+*
+* Revision 6.36  2003/05/05 11:57:34  rsmith
+* Codewarrior and MSC compilers use the same declaration for thread_exit_arr and thread_self.
+*
+* Revision 6.35  2003/03/06 15:12:27  coulouri
+* add mach/mach.h header for codewarrior
+*
+* Revision 6.34  2003/03/06 14:15:04  coulouri
+* add mach support for NlmCPUNumber
+*
+* Revision 6.33  2002/03/12 15:50:00  ivanov
+* Changed a name created mutex from "Nlm_InitLock32" to NULL
+* in the NlmMutexInit() under WIN32
+*
 * Revision 6.32  2001/12/14 21:09:20  ivanov
 * Enable threads under WIN32 in MT-configurations
 *
@@ -414,7 +433,7 @@ static  thread_key_t thread_exit_key;
 #elif defined (POSIX_THREADS_AVAIL)
 static pthread_key_t thread_exit_key;
 #elif defined (WIN32_THREADS_AVAIL)
-#ifdef _MSC_VER
+#if defined(_MSC_VER)  || defined(COMP_METRO)
 static __declspec( thread ) TOnExitArrayPtr thread_exit_arr = NULL;
 static __declspec( thread ) HANDLE          thread_self     = NULL;
 #else
@@ -776,6 +795,7 @@ NLM_EXTERN TNlmThread NlmThreadCreateEx(TNlmThreadStart  theStartFunction,
      if (pthread_attr_setscope(&attr, PTHREAD_SCOPE_BOUND_NP) != 0)
        /* SGI-HNC: Otherwise default to PTHREAD_SCOPE_PROCESS */
 #endif
+#ifndef OS_UNIX_NETBSD
       if (!pthread_attr_setscope(&attr, PTHREAD_SCOPE_PROCESS)  &&
           !pthread_attr_setschedpolicy(&attr, SCHED_OTHER)  &&
           priority != eTP_Default) { /* adjust the thread priority */
@@ -789,6 +809,7 @@ NLM_EXTERN TNlmThread NlmThreadCreateEx(TNlmThreadStart  theStartFunction,
         }
 #endif
       }
+#endif
 
     if (pthread_create(&thread_id, &attr,
                        NlmThreadWrapper, (void *)wrapper_data) == 0) {
@@ -2036,7 +2057,7 @@ NLM_EXTERN TNlmMutex NlmMutexInit(TNlmMutexPtr theMutexPtr)
 #elif defined(WIN32_THREADS_AVAIL)
   {{
     if (s_Init_mutex == NULL) {
-      HANDLE x_Init_mutex = CreateMutex(NULL, FALSE, "Nlm_InitLock32");
+      HANDLE x_Init_mutex = CreateMutex(NULL, FALSE, NULL);
       if ( x_Init_mutex )
         s_Init_mutex = x_Init_mutex;
       else
@@ -2544,9 +2565,28 @@ NLM_EXTERN Boolean NlmThreadsAvailable(void)
 }
 
 
+#if defined(OS_UNIX_DARWIN)
+#include <mach/mach.h>
+#include <mach/mach_host.h>
+#include <mach/host_info.h> 
+#endif
+
 NLM_EXTERN Int4 NlmCPUNumber(void)
 {
-#if defined(WIN32)
+#if defined(OS_UNIX_DARWIN)
+
+  host_basic_info_data_t hinfo;
+  mach_msg_type_number_t hinfo_count = HOST_BASIC_INFO_COUNT;
+  kern_return_t rc;
+
+  rc=host_info( mach_host_self(), HOST_BASIC_INFO, (host_info_t) &hinfo, &hinfo_count);
+
+  if (rc != KERN_SUCCESS)
+    return -1;
+
+  return hinfo.avail_cpus;
+
+#elif defined(WIN32)
   SYSTEM_INFO sysInfo;
   GetSystemInfo(&sysInfo);
   return sysInfo.dwNumberOfProcessors;
