@@ -29,7 +29,7 @@
 *
 * Version Creation Date:   5/12/05
 *
-* $Revision: 1.14 $
+* $Revision: 1.30 $
 *
 * File Description:
 *
@@ -50,7 +50,7 @@
 #include <toasn3.h>
 #include <pmfapi.h>
 
-#define NPS2GPSAPP_VER "2.2"
+#define NPS2GPSAPP_VER "2.9"
 
 CharPtr NPS2GPSAPPLICATION = NPS2GPSAPP_VER;
 
@@ -59,9 +59,15 @@ typedef struct n2gdata {
   CharPtr  outfile;
   Boolean  failure;
   Boolean  lock;
+  Boolean  byTscriptID;
   Boolean  byFeatID;
   Boolean  useProtID;
   Boolean  refSeqTitles;
+  Boolean  smarttitle;
+  Boolean  noncoding;
+  Boolean  removeunnecxref;
+  CharPtr  genDb;
+  CharPtr  genQual;
 } N2GData, PNTR N2GPtr;
 
 typedef struct npsseqs {
@@ -191,54 +197,42 @@ static void LclMakeNucProtCDS (
 
 /* copy gene from contig onto nuc-prot, single interval on cdna bioseq */
 
-static void LclCopyGene (
+static GeneRefPtr LclCopyGeneWork (
   SeqFeatPtr sfp,
-  Pointer userdata
+  BioseqPtr bsp
 )
 
 {
-  BioseqPtr          bsp;
-  SeqMgrFeatContext  gcontext;
-  SeqFeatPtr         gene, copy, temp;
-  GeneRefPtr         grp, xref;
-  Boolean            partial5, partial3;
+  SeqFeatPtr  gene, copy, temp;
+  GeneRefPtr  grp = NULL, xref;
+  Boolean     partial5, partial3;
 
-  /* input mrna features are multi-interval on contig */
+  if (sfp == NULL || bsp == NULL) return NULL;
+  if (sfp->data.choice != SEQFEAT_RNA) return NULL;
 
-  if (sfp->data.choice != SEQFEAT_RNA) return;
+  gene = GetGeneForFeature (sfp);
 
-  /* find cdna product of mrna */
-
-  bsp = BioseqFindFromSeqLoc (sfp->product);
-  if (bsp == NULL) return;
-
-  /* check for gene xref */
-
-  xref = SeqMgrGetGeneXref (sfp);
-  if (xref != NULL) {
-    if (SeqMgrGeneIsSuppressed (xref)) return;
+  if (gene == NULL) {
+    xref = SeqMgrGetGeneXref (sfp);
+    if (xref == NULL) return NULL;
+    if (SeqMgrGeneIsSuppressed (xref)) return NULL;
 
     /* copy gene xref for new gene feature */
 
     grp = AsnIoMemCopy (xref,
                         (AsnReadFunc) GeneRefAsnRead,
                         (AsnWriteFunc) GeneRefAsnWrite);
-    if (grp == NULL) return;
+    if (grp == NULL) return NULL;
 
     /* make new gene feature on full-length of cdna */
 
     copy = CreateNewFeatureOnBioseq (bsp, SEQFEAT_GENE, NULL);
-    if (copy == NULL) return;
+    if (copy == NULL) return NULL;
 
     copy->data.value.ptrvalue = grp;
-    return;
+    return grp;
   }
 
-  /* overlapping gene should be single interval on contig */
-
-  gene = SeqMgrGetOverlappingGene (sfp->location, &gcontext);
-  if (gene == NULL) return;
-
   CheckSeqLocForPartial (gene->location, &partial5, &partial3);
 
   /* copy gene feature fields to paste into new gene feature */
@@ -246,14 +240,14 @@ static void LclCopyGene (
   temp = AsnIoMemCopy (gene,
                        (AsnReadFunc) SeqFeatAsnRead,
                        (AsnWriteFunc) SeqFeatAsnWrite);
-  if (temp == NULL) return;
+  if (temp == NULL) return NULL;
 
   /* make new gene feature on full-length of cdna */
 
   copy = CreateNewFeatureOnBioseq (bsp, SEQFEAT_GENE, NULL);
   if (copy == NULL) {
     SeqFeatFree (temp);
-    return;
+    return NULL;
   }
 
   /* paste fields from temp copy of original gene */
@@ -276,6 +270,30 @@ static void LclCopyGene (
 
   SeqLocFree (temp->location);
   MemFree (temp); /* do not SeqFeatFree */
+
+  grp = (GeneRefPtr) copy->data.value.ptrvalue;
+
+  return grp;
+}
+
+static void LclCopyGene (
+  SeqFeatPtr sfp,
+  Pointer userdata
+)
+
+{
+  BioseqPtr  bsp;
+
+  /* input mrna features are multi-interval on contig */
+
+  if (sfp->data.choice != SEQFEAT_RNA) return;
+
+  /* find cdna product of mrna */
+
+  bsp = BioseqFindFromSeqLoc (sfp->product);
+  if (bsp == NULL) return;
+
+  LclCopyGeneWork (sfp, bsp);
 }
 
 static void LclAddMrnaTitles (
@@ -352,6 +370,217 @@ static void LclAddMrnaTitles (
   SeqDescrAddPointer (&(bsp->descr), Seq_descr_title, (Pointer) str);
 }
 
+static CharPtr RnaTypeLabel (
+  SeqFeatPtr rna
+)
+
+{
+  if (rna == NULL) return "RNA";
+  switch (rna->idx.subtype) {
+    case FEATDEF_preRNA :
+      return "preRNA";
+    case FEATDEF_mRNA :
+      return "mRNA";
+    case FEATDEF_tRNA :
+      return "tRNA";
+    case FEATDEF_rRNA :
+      return "rRNA";
+    case FEATDEF_snRNA :
+      return "snRNA";
+    case FEATDEF_scRNA :
+      return "scRNA";
+    case FEATDEF_otherRNA :
+      return "otherRNA";
+    case FEATDEF_snoRNA :
+      return "snoRNA";
+    case FEATDEF_ncRNA :
+      return "ncRNA";
+    case FEATDEF_tmRNA :
+      return "tmRNA";
+    default :
+      break;
+  }
+  return "RNA";
+}
+
+static void LclMakeOneRnaTitle (
+  SeqFeatPtr rna,
+  SeqFeatPtr gene,
+  CharPtr label,
+  CharPtr organism,
+  Boolean alt_splice
+)
+
+{
+  BioseqPtr          bsp;
+  SeqMgrFeatContext  ccontext;
+  SeqFeatPtr         cds;
+  GeneRefPtr         grp;
+  Char               id [64];
+  CharPtr            lbl = NULL;
+  size_t             len;
+  CharPtr            ptr;
+  CharPtr            str;
+  CharPtr            typ = NULL;
+
+  if (rna == NULL || rna->product == NULL) return;
+
+  grp = SeqMgrGetGeneXref (rna);
+  if (SeqMgrGeneIsSuppressed (grp)) return;
+  if (grp == NULL && gene != NULL) {
+    grp = (GeneRefPtr) gene->data.value.ptrvalue;
+  }
+  if (grp == NULL) return;
+
+  bsp = BioseqFindFromSeqLoc (rna->product);
+  if (bsp == NULL) return;
+  SeqIdWrite (bsp->id, id, PRINTID_TEXTID_ACC_VER, sizeof (id) - 1);
+
+  typ = RnaTypeLabel (rna); 
+  lbl = StringSaveNoNull (label);
+
+  cds = SeqMgrGetNextFeature (bsp, NULL, SEQFEAT_CDREGION, 0, &ccontext);
+
+  len = StringLen (organism) + StringLen (grp->locus_tag) + StringLen (grp->locus) +
+        StringLen (id) + StringLen (" transcript variant") + StringLen (lbl) +
+        StringLen (" mRNA, complete cds.") + StringLen (typ) + 20;
+  str = (CharPtr) MemNew (len * sizeof (Char));
+  if (str == NULL) return;
+  str [0] = '\0';
+
+  if (StringDoesHaveText (organism)) {
+    StringCat (str, organism);
+  }
+  if (lbl != NULL) {
+    StringCat (str, " ");
+    ptr = StringStr (lbl, ", transcript variant ");
+    if (ptr != NULL) {
+      *ptr = '\0';
+      ptr += 2;
+      StringCat (str, lbl);
+      if (StringDoesHaveText (grp->locus)) {
+          StringCat (str, " (");
+          StringCat (str, grp->locus);
+          StringCat (str, ")");
+      }
+      StringCat (str, ", ");
+      StringCat (str, ptr);
+    } else {
+      StringCat (str, lbl);
+      if (StringDoesHaveText (grp->locus)) {
+          StringCat (str, " (");
+          StringCat (str, grp->locus);
+          StringCat (str, ")");
+      }
+    }
+  }
+
+  StringCat (str, ", ");
+  StringCat (str, typ);
+  StringCat (str, ".");
+
+  SeqDescrAddPointer (&(bsp->descr), Seq_descr_title, (Pointer) str);
+  MemFree (lbl);
+}
+
+typedef struct gcmdata {
+  SeqFeatPtr  gene;
+  SeqFeatPtr  feat;
+  CharPtr     label;
+} GmcData, PNTR GmcDataPtr;
+
+static int LIBCALLBACK SortByGenePtr (
+  VoidPtr vp1,
+  VoidPtr vp2
+)
+
+{
+  GmcDataPtr gdp1, gdp2;
+
+  if (vp1 == NULL || vp2 == NULL) return 0;
+  gdp1 = (GmcDataPtr) vp1;
+  gdp2 = (GmcDataPtr) vp2;
+  if (gdp1 == NULL || gdp2 == NULL) return 0;
+
+  if (gdp1->gene > gdp2->gene) return -1;
+  if (gdp1->gene < gdp2->gene) return 1;
+
+  if (gdp1->feat > gdp2->feat) return -1;
+  if (gdp1->feat < gdp2->feat) return 1;
+
+  return 0;
+}
+
+static void LclMakeSmartRnaTitles (
+  BioseqPtr bsp,
+  CharPtr organism
+)
+
+{
+  SeqMgrFeatContext  context;
+  GmcDataPtr         gdp, head;
+  GeneRefPtr         grp;
+  Int2               i, j, k, numgene, numrna;
+  SeqFeatPtr         sfp;
+
+  if (bsp == NULL) return;
+
+  numgene = 0;
+  numrna = 0;
+
+  sfp = SeqMgrGetNextFeature (bsp, NULL, 0, 0, &context);
+  while (sfp != NULL) {
+    switch (sfp->data.choice) {
+      case SEQFEAT_GENE :
+        numgene++;
+        break;
+      case SEQFEAT_RNA :
+        numrna++;
+        break;
+      default :
+        break;
+    }
+    sfp = SeqMgrGetNextFeature (bsp, sfp, 0, 0, &context);
+  }
+
+  /* if (numgene == 0) return; */
+
+  if (numrna > 0) {
+    head = (GmcDataPtr) MemNew (sizeof (GmcData) * (size_t) (numrna + 1));
+    if (head != NULL) {
+      gdp = head;
+      sfp = SeqMgrGetNextFeature (bsp, NULL, SEQFEAT_RNA, 0, &context);
+      while (sfp != NULL) {
+        if (sfp->product != NULL) {
+          gdp->feat = sfp;
+          gdp->label = context.label;
+          grp = SeqMgrGetGeneXref (sfp);
+          if (grp == NULL || (! SeqMgrGeneIsSuppressed (grp))) {
+            gdp->gene = SeqMgrGetOverlappingGene (sfp->location, NULL);
+          }
+          gdp++;
+        }
+        sfp = SeqMgrGetNextFeature (bsp, sfp, SEQFEAT_RNA, 0, &context);
+      }
+      HeapSort (head, (size_t) numrna, sizeof (GmcData), SortByGenePtr);
+      for (i = 0; i < numrna; i += j) {
+        sfp = head [i].gene;
+        for (j = 1; i + j < numrna && sfp == head [i + j].gene; j++) continue;
+        if (j == 1) {
+          /* no alt splicing */
+          LclMakeOneRnaTitle (head [i].feat, head [i].gene, head [i].label, organism, FALSE);
+        } else {
+          /* is alt splicing */
+          for (k = 0; k < j; k++) {
+            LclMakeOneRnaTitle (head [i + k].feat, head [i + k].gene, head [i + k].label, organism, TRUE);
+          }
+        }
+      }
+    }
+    MemFree (head);
+  }
+}
+
 static SeqIdPtr MakeIdFromLocusTag (
   SeqFeatPtr mrna
 )
@@ -391,12 +620,32 @@ static SeqIdPtr MakeIdFromLocusTag (
   return NULL;
 }
 
+static SeqIdPtr MakeIdFromTscriptID (
+  SeqFeatPtr mrna
+)
+
+{
+  GBQualPtr  gbq;
+  SeqIdPtr   sip;
+
+  if (mrna == NULL) return NULL;
+
+  for (gbq = mrna->qual; gbq != NULL; gbq = gbq->next) {
+    if (StringICmp (gbq->qual, "orig_transcript_id") != 0) continue;
+    if (StringHasNoText (gbq->val)) continue;
+    sip = MakeSeqID (gbq->val);
+    if (sip != NULL) return sip;
+  }
+
+  return NULL;
+}
+
 static SeqIdPtr MakeIdFromProtein (
   BioseqPtr pbsp
 )
 
 {
-  Char      buf [64], tmp [64];
+  Char      buf [128], tmp [128];
   SeqIdPtr  sip;
 
   if (pbsp == NULL) return NULL;
@@ -410,6 +659,46 @@ static SeqIdPtr MakeIdFromProtein (
   return MakeSeqID (tmp);
 }
 
+static void AddGeneralIdFromQual (
+  BioseqPtr bsp,
+  SeqFeatPtr sfp,
+  CharPtr genDb,
+  CharPtr genQual,
+  CharPtr suffix
+)
+
+{
+  GBQualPtr  gbq;
+  SeqIdPtr   sip;
+  Char       tmp [128];
+  CharPtr    val = NULL;
+
+  if (bsp == NULL || sfp == NULL || StringHasNoText (genDb)) return;
+
+  if (StringHasNoText (genQual)) {
+    genQual = "standard_name";
+  }
+
+  for (gbq = sfp->qual; gbq != NULL; gbq = gbq->next) {
+    if (StringICmp (gbq->qual, genQual) != 0) continue;
+    val = gbq->val;
+  }
+  if (StringHasNoText (val)) return;
+
+  StringCpy (tmp, "gnl|");
+  StringCat (tmp, genDb);
+  StringCat (tmp, "|");
+  StringCat (tmp, val);
+  if (StringDoesHaveText (suffix)) {
+    StringCat (tmp, suffix);
+  }
+  sip = MakeSeqID (tmp);
+  if (sip == NULL) return;
+
+  sip->next = bsp->id;
+  bsp->id = sip;
+}
+
 static void InstantiateMrnaIntoProt (
   SeqFeatPtr cds,
   SeqFeatPtr mrna,
@@ -457,9 +746,17 @@ static void InstantiateMrnaIntoProt (
   /*
   mbsp->id = MakeIdFromLocusTag (mrna);
   */
-  if (ngp->useProtID) {
+  if (ngp->byTscriptID) {
+    mbsp->id = MakeIdFromTscriptID (mrna);
+  } else if (ngp->useProtID) {
     mbsp->id = MakeIdFromProtein (pbsp);
   }
+  if (StringDoesHaveText (ngp->genDb)) {
+    AddGeneralIdFromQual (mbsp, mrna, ngp->genDb, ngp->genQual, NULL);
+    if (mbsp->id == NULL) {
+      AddGeneralIdFromQual (mbsp, cds, ngp->genDb, ngp->genQual, ".mrna");
+    }
+  }
   if (mbsp->id == NULL) {
     mbsp->id = MakeNewProteinSeqIdEx (mrna->location, NULL, NULL, ctrp);
   }
@@ -494,6 +791,54 @@ static void InstantiateMrnaIntoProt (
   AddSeqEntryToSeqEntry (psep, msep, FALSE);
 }
 
+static void RemoveOrigIDs (
+  SeqFeatPtr sfp
+)
+
+{
+  GBQualPtr       gbq, nextqual;
+  GBQualPtr PNTR  prevqual;
+
+  if (sfp == NULL) return;
+
+  gbq = sfp->qual;
+  prevqual = (GBQualPtr PNTR) &(sfp->qual);
+
+  while (gbq != NULL) {
+    nextqual = gbq->next;
+    if (StringICmp (gbq->qual, "orig_protein_id") == 0 ||
+        StringICmp (gbq->qual, "orig_transcript_id") == 0) {
+      *(prevqual) = gbq->next;
+      gbq->next = NULL;
+      GBQualFree (gbq);
+    } else {
+      prevqual = (GBQualPtr PNTR) &(gbq->next);
+    }
+    gbq = nextqual;
+  }
+}
+
+static void RemoveOrigPrefix (
+  SeqFeatPtr sfp,
+  Pointer userdata
+)
+
+{
+  GBQualPtr  gbq;
+
+  if (sfp == NULL) return;
+
+  /* copy smaller string without orig_ prefix into existing allocated memory */
+
+  for (gbq = sfp->qual; gbq != NULL; gbq = gbq->next) {
+    if (StringICmp (gbq->qual, "orig_protein_id") == 0) {
+      StringCpy (gbq->qual, "protein_id");
+    } else if (StringICmp (gbq->qual, "orig_transcript_id") == 0) {
+      StringCpy (gbq->qual, "transcript_id");
+    }
+  }
+}
+
 static void RemoveFeatScratch (
   SeqFeatPtr sfp,
   Pointer userdata
@@ -547,6 +892,8 @@ static Boolean CdsIsPseudo (
 
   gene = SeqMgrGetOverlappingGene (cds->location, &gcontext);
   if (gene == NULL) return FALSE;
+  if (gene->pseudo) return TRUE;
+
   grp = (GeneRefPtr) gene->data.value.ptrvalue;
   if (grp == NULL) return FALSE;
   return grp->pseudo;
@@ -559,11 +906,11 @@ static void LoopThroughCDSs (
 )
 
 {
+  SeqFeatPtr         cds;
   Int2               count;
   SeqMgrFeatContext  fcontext;
   Boolean            goOn;
   LoopData           ld;
-  SeqFeatPtr         sfp;
   CharPtr            str;
 
   /* loop through CDS features, finding single unused mRNA partner */
@@ -571,16 +918,16 @@ static void LoopThroughCDSs (
   goOn = TRUE;
   while (goOn) {
     goOn = FALSE;
-    sfp = SeqMgrGetNextFeature (bsp, NULL, SEQFEAT_CDREGION, 0, &fcontext);
-    while (sfp != NULL) {
-      if (sfp->idx.scratch == NULL) {
+    cds = SeqMgrGetNextFeature (bsp, NULL, SEQFEAT_CDREGION, 0, &fcontext);
+    while (cds != NULL) {
+      if (cds->idx.scratch == NULL) {
         ld.count = 0;
         ld.mrna = NULL;
-        count = SeqMgrGetAllOverlappingFeatures (sfp->location, FEATDEF_mRNA, NULL, 0,
+        count = SeqMgrGetAllOverlappingFeatures (cds->location, FEATDEF_mRNA, NULL, 0,
                                                  CHECK_INTERVALS, (Pointer) &ld, FindSingleMrnaProc);
         if (ld.count == 1 && ld.mrna != NULL) {
-          InstantiateMrnaIntoProt (sfp, ld.mrna, ctrp, ngp);
-          sfp->idx.scratch = (Pointer) MemNew (sizeof (Int4));
+          InstantiateMrnaIntoProt (cds, ld.mrna, ctrp, ngp);
+          cds->idx.scratch = (Pointer) MemNew (sizeof (Int4));
           ld.mrna->idx.scratch = (Pointer) MemNew (sizeof (Int4));
           goOn = TRUE;
         } else {
@@ -592,16 +939,16 @@ static void LoopThroughCDSs (
         }
       }
 
-      sfp = SeqMgrGetNextFeature (bsp, sfp, SEQFEAT_CDREGION, 0, &fcontext);
+      cds = SeqMgrGetNextFeature (bsp, cds, SEQFEAT_CDREGION, 0, &fcontext);
     }
   }
 
   /* if any CDSs were not promoted, record failure */
 
-  sfp = SeqMgrGetNextFeature (bsp, NULL, SEQFEAT_CDREGION, 0, &fcontext);
-  while (sfp != NULL) {
-    if (sfp->idx.scratch == NULL) {
-      if (sfp->product == NULL && CdsIsPseudo (sfp)) {
+  cds = SeqMgrGetNextFeature (bsp, NULL, SEQFEAT_CDREGION, 0, &fcontext);
+  while (cds != NULL) {
+    if (cds->idx.scratch == NULL) {
+      if (cds->product == NULL && CdsIsPseudo (cds)) {
         /* do not complain about pseudo CDS not having product or matching mRNA */
       } else {
         if (ngp != NULL) {
@@ -614,22 +961,77 @@ static void LoopThroughCDSs (
         Message (MSG_POSTERR, "Failed to match CDS '%s' to mRNA", str);
       }
     }
-    sfp = SeqMgrGetNextFeature (bsp, sfp, SEQFEAT_CDREGION, 0, &fcontext);
+    cds = SeqMgrGetNextFeature (bsp, cds, SEQFEAT_CDREGION, 0, &fcontext);
   }
 }
 
+static Boolean ReciprocalTranscriptIDs (
+  SeqFeatPtr cds,
+  SeqFeatPtr mrna
+)
+
+{
+  GBQualPtr  gbq;
+  CharPtr    tid1 = NULL, tid2 = NULL;
+
+  if (cds == NULL || mrna == NULL) return FALSE;
+
+  for (gbq = cds->qual; gbq != NULL; gbq = gbq->next) {
+    if (StringICmp (gbq->qual, "orig_transcript_id") != 0) continue;
+    if (StringHasNoText (gbq->val)) continue;
+    tid1 = gbq->val;
+  }
+
+  for (gbq = mrna->qual; gbq != NULL; gbq = gbq->next) {
+    if (StringICmp (gbq->qual, "orig_transcript_id") != 0) continue;
+    if (StringHasNoText (gbq->val)) continue;
+    tid2 = gbq->val;
+  }
+
+  if (tid1 == NULL || tid2 == NULL) return FALSE;
+  if (StringICmp (tid1, tid2) == 0) return TRUE;
+
+  return FALSE;
+}
+
+static SeqFeatPtr GetCDSByProteinID (
+  SeqFeatPtr mrna
+)
+
+{
+  BioseqPtr   bsp;
+  SeqFeatPtr  cds;
+  GBQualPtr   gbq;
+  SeqIdPtr    sip;
+
+  if (mrna == NULL) return NULL;
+
+  for (gbq = mrna->qual; gbq != NULL; gbq = gbq->next) {
+    if (StringICmp (gbq->qual, "orig_protein_id") != 0) continue;
+    if (StringHasNoText (gbq->val)) continue;
+    sip = MakeSeqID (gbq->val);
+    if (sip == NULL) continue;
+    bsp = BioseqFind (sip);
+    if (bsp == NULL) continue;
+    cds = SeqMgrGetCDSgivenProduct (bsp, NULL);
+    if (cds != NULL) return cds;
+  }
+
+  return NULL;
+}
+
 static SeqFeatPtr GetmRNAByFeatureID (
   SeqFeatPtr cds
 )
 
 {
-  SeqFeatPtr         mRNA = NULL;
-  SeqFeatXrefPtr     xref;
-  ObjectIdPtr        oip;
-  Char               buf [32];
+  SeqFeatPtr      mRNA = NULL;
+  SeqFeatXrefPtr  xref;
+  ObjectIdPtr     oip;
+  Char            buf [32];
 
   if (cds == NULL) return NULL;
-  
+
   xref = cds->xref;
   while (xref != NULL && mRNA == NULL) {
     if (xref->id.choice == 3) {
@@ -642,13 +1044,216 @@ static SeqFeatPtr GetmRNAByFeatureID (
           mRNA = SeqMgrGetFeatureByFeatID (cds->idx.entityID, NULL, buf, NULL, NULL);
         }
       }
-    }
+    } 
     xref = xref->next;
   }
+
   return mRNA;
 }
 
-static void NPStoGPS (
+static void InstantiateNCRNA (
+  SeqFeatPtr ncrna,
+  SeqEntryPtr top,
+  CharPtr organism,
+  Int2Ptr ctrp,
+  N2GPtr ngp
+)
+
+{
+  Uint1         biomol = 0;
+  ByteStorePtr  bs;
+  BioseqPtr     bsp;
+  SeqFeatPtr    copy, temp;
+  GeneRefPtr    grp;
+  Int4          len;
+  CharPtr       locus = NULL;
+  MolInfoPtr    mip;
+  Boolean       partial5, partial3;
+  CharPtr       prod = NULL;
+  RNAGenPtr     rgp;
+  CharPtr       rnaseq;
+  RnaRefPtr     rrp;
+  SeqDescrPtr   sdp;
+  SeqEntryPtr   sep;
+  CharPtr       ttl = NULL;
+  CharPtr       typ;
+
+  if (ncrna == NULL || top == NULL || ngp == NULL) return;
+  if (ncrna->product != NULL) return;
+
+  rrp = (RnaRefPtr) ncrna->data.value.ptrvalue;
+  if (rrp == NULL) return;
+
+  switch (rrp->type) {
+    case RNA_TYPE_premsg:
+     biomol = MOLECULE_TYPE_PRE_MRNA;
+     break;
+    case RNA_TYPE_rRNA:
+      biomol = MOLECULE_TYPE_RRNA;
+      break;
+    case RNA_TYPE_snRNA:
+      biomol = MOLECULE_TYPE_SNRNA;
+      break;
+    case RNA_TYPE_scRNA:
+      biomol = MOLECULE_TYPE_SCRNA;
+      break;
+    case RNA_TYPE_snoRNA:
+      biomol = MOLECULE_TYPE_SNORNA;
+      break;
+    case RNA_TYPE_ncRNA:
+      biomol = MOLECULE_TYPE_NCRNA;
+      break;
+    default:
+      return;
+  }
+
+  rnaseq = GetSequenceByFeature (ncrna);
+  if (rnaseq == NULL) return;
+  len = (Int4) StringLen (rnaseq);
+
+  bs = BSNew (len + 2);
+  if (bs == NULL) return;
+  BSWrite (bs, (VoidPtr) rnaseq, len);
+  MemFree (rnaseq);
+
+  bsp = BioseqNew ();
+  if (bsp == NULL) return;
+  bsp->repr = Seq_repr_raw;
+  bsp->mol = Seq_mol_rna;
+  bsp->seq_data_type = Seq_code_iupacna;
+  bsp->seq_data = (SeqDataPtr) bs;
+  bsp->length = BSLen (bs);
+  BioseqPack (bsp);
+
+  if (ngp->byTscriptID) {
+    bsp->id = MakeIdFromTscriptID (ncrna);
+  }
+  if (StringDoesHaveText (ngp->genDb)) {
+    AddGeneralIdFromQual (bsp, ncrna, ngp->genDb, ngp->genQual, NULL);
+  }
+  if (bsp->id == NULL) {
+    bsp->id = MakeNewProteinSeqIdEx (ncrna->location, NULL, NULL, ctrp);
+  }
+  CheckSeqLocForPartial (ncrna->location, &partial5, &partial3);
+  SeqMgrAddToBioseqIndex (bsp);
+
+  sep = SeqEntryNew ();
+  if (sep == NULL) return;
+  sep->choice = 1;
+  sep->data.ptrvalue = (Pointer) bsp;
+  SeqMgrSeqEntry (SM_BIOSEQ, (Pointer) bsp, sep);
+
+  SetSeqFeatProduct (ncrna, bsp);
+
+  AddSeqEntryToSeqEntry (top, sep, FALSE);
+
+  mip = MolInfoNew ();
+  if (mip == NULL) return;
+  mip->biomol = biomol;
+
+  if (partial5 && partial3) {
+    mip->completeness = 5;
+  } else if (partial5) {
+    mip->completeness = 3;
+  } else if (partial3) {
+    mip->completeness = 4;
+  }
+  SeqDescrAddPointer (&(bsp->descr), Seq_descr_molinfo, (Pointer) mip);
+
+  grp = LclCopyGeneWork (ncrna, bsp);
+  if (grp != NULL) {
+    locus = grp->locus;
+    if (StringHasNoText (locus)) {
+      locus = grp->desc;
+    }
+  }
+
+  if (rrp->ext.choice == 1) {
+    prod = (CharPtr) rrp->ext.value.ptrvalue;
+  } else if (rrp->ext.choice == 3) {
+    rgp = (RNAGenPtr) rrp->ext.value.ptrvalue;
+    if (rgp != NULL) {
+      prod = rgp->product;
+    }
+  }
+  if (StringHasNoText (prod)) {
+    for (sdp = bsp->descr; sdp != NULL; sdp = sdp->next) {
+      if (sdp->choice != Seq_descr_comment) continue;
+      prod = (CharPtr) sdp->data.ptrvalue;
+    }
+  }
+
+  len = StringLen (organism) + StringLen (prod) + StringLen (locus);
+  if (len < 1) return;
+  ttl = (CharPtr) MemNew (sizeof (Char) * (len + 100));
+  if (ttl == NULL) return;
+  *ttl = '\0';
+
+  if (StringDoesHaveText (organism)) {
+    StringCat (ttl, organism);
+  }
+  if (StringDoesHaveText (prod)) {
+    StringCat (ttl, " ");
+    StringCat (ttl, prod);
+  }
+  if (StringDoesHaveText (locus)) {
+    StringCat (ttl, " (");
+    StringCat (ttl, locus);
+    StringCat (ttl, ")");
+  }
+  typ = RnaTypeLabel (ncrna);
+  StringCat (ttl, ", ");
+  StringCat (ttl, typ);
+  StringCat (ttl, ".");
+
+  if (StringDoesHaveText (ttl)) {
+    SeqDescrAddPointer (&(bsp->descr), Seq_descr_title, (Pointer) StringSave (ttl));
+  }
+
+  RemoveOrigIDs (ncrna);
+
+  CheckSeqLocForPartial (ncrna->location, &partial5, &partial3);
+
+  /* copy ncrna feature fields to paste into new ncrna feature */
+
+  temp = AsnIoMemCopy (ncrna,
+                       (AsnReadFunc) SeqFeatAsnRead,
+                       (AsnWriteFunc) SeqFeatAsnWrite);
+  if (temp == NULL) return;
+
+  /* make new ncrna feature on full-length of instantiated RNA */
+
+  copy = CreateNewFeatureOnBioseq (bsp, SEQFEAT_RNA, NULL);
+  if (copy == NULL) {
+    SeqFeatFree (temp);
+    return;
+  }
+
+  /* paste fields from temp copy of original ncrna */
+
+  copy->data.value.ptrvalue = temp->data.value.ptrvalue;
+  copy->partial = temp->partial;
+  copy->excpt = temp->excpt;
+  copy->comment = temp->comment;
+  copy->qual = temp->qual;
+  copy->title = temp->title;
+  copy->ext = temp->ext;
+  copy->cit = temp->cit;
+  copy->exp_ev = temp->exp_ev;
+  copy->xref = temp->xref;
+  copy->dbxref = temp->dbxref;
+  copy->pseudo = temp->pseudo;
+  copy->except_text = temp->except_text;
+
+  SetSeqLocPartial (copy->location, partial5, partial3);
+
+  SeqLocFree (temp->location);
+  SeqLocFree (temp->product);
+  MemFree (temp); /* do not SeqFeatFree */
+}
+
+static void PromoteNonCoding (
+  SeqEntryPtr sep,
   Uint2 entityID,
   CharPtr filename,
   N2GPtr ngp,
@@ -660,8 +1265,118 @@ static void NPStoGPS (
   BioseqPtr          bsp;
   BioseqSetPtr       bssp;
   Int2               ctr = 1;
+  SeqMgrFeatContext  nccontext;
+  SeqFeatPtr         ncrna;
+  SeqEntryPtr        old, tmp, top;
+  ObjMgrDataPtr      omdptop;
+  ObjMgrData         omdata;
+  CharPtr            organism;
+  OrgRefPtr          orp;
+  Uint2              parenttype;
+  Pointer            parentptr;
+  SeqDescrPtr        sdp;
+
+  if (sep == NULL) return;
+
+  if (sep->choice == 2) {
+    bssp = (BioseqSetPtr) sep->data.ptrvalue;
+    if (bssp == NULL) return;
+
+    /* recursively visit components of genbank set */
+
+    if (bssp->_class == BioseqseqSet_class_genbank) {
+      for (sep = bssp->seq_set; sep != NULL; sep = sep->next) {
+        PromoteNonCoding (sep, entityID, filename, ngp, descr);
+      }
+      return;
+    }
+  }
+
+  if (SeqMgrFeaturesAreIndexed (entityID) == 0) {
+    SeqMgrIndexFeatures (entityID, NULL);
+  }
+
+  top = sep;
+
+  if (StringHasNoText (filename)) {
+    filename = "?";
+  }
+
+  bsp = FindNucBioseq (top);
+  if (bsp == NULL) {
+    Message (MSG_OK, "Unable to find nucleotide Bioseq in %s", filename);
+    if (ngp != NULL) {
+      ngp->failure = TRUE;
+    }
+    return;
+  }
+
+  if (sep->choice == 1) {
+    SaveSeqEntryObjMgrData (top, &omdptop, &omdata);
+    GetSeqEntryParent (top, &parentptr, &parenttype);
+
+    bssp = BioseqSetNew ();
+    if (bssp == NULL) return;
+    bssp->_class = BioseqseqSet_class_gen_prod_set;
+
+    tmp = SeqEntryNew ();
+    if (tmp == NULL) return;
+    tmp->choice = 1;
+    tmp->data.ptrvalue = sep->data.ptrvalue;
+    bssp->seq_set = tmp;
+
+    sep->choice = 2;
+    sep->data.ptrvalue = bssp;
+
+    SeqMgrLinkSeqEntry (top, parenttype, parentptr);
+    RestoreSeqEntryObjMgrData (top, omdptop, &omdata);
+
+    SeqMgrClearFeatureIndexes (entityID, NULL);
+    SeqMgrIndexFeatures (entityID, NULL);
+  }
+
+  old = SeqEntrySetScope (top);
+
+  organism = NULL;
+  for (sdp = descr; sdp != NULL; sdp = sdp->next) {
+    if (sdp->choice != Seq_descr_source) continue;
+    biop = (BioSourcePtr) sdp->data.ptrvalue;
+    if (biop == NULL) continue;
+    orp = biop->org;
+    if (orp == NULL) continue;
+    if (! StringHasNoText (orp->taxname)) {
+      organism = orp->taxname;
+    }
+  }
+
+  ctr = (Int2) VisitBioseqsInSep (top, NULL, NULL) + 1;
+
+  ncrna = SeqMgrGetNextFeature (bsp, NULL, SEQFEAT_RNA, 0, &nccontext);
+  while (ncrna != NULL) {
+    InstantiateNCRNA (ncrna, top, organism, &ctr, ngp);
+    ncrna = SeqMgrGetNextFeature (bsp, ncrna, SEQFEAT_RNA, 0, &nccontext);
+  }
+
+  SeqEntrySetScope (old);
+
+  SeqMgrClearFeatureIndexes (entityID, NULL);
+}
+
+static void NPStoGPS (
+  SeqEntryPtr sep,
+  Uint2 entityID,
+  CharPtr filename,
+  N2GPtr ngp,
+  SeqDescrPtr descr
+)
+
+{
+  BioSourcePtr       biop;
+  BioseqPtr          bsp;
+  BioseqSetPtr       bssp;
+  SeqFeatPtr         cds, gene, mrna, sfp, lastsfp;
+  Int2               ctr = 1;
   SeqMgrFeatContext  fcontext, gcontext, mcontext;
-  SeqFeatPtr         gene, mrna, sfp, lastsfp;
   GeneRefPtr         grp;
   Int4Ptr            iptr;
   SeqEntryPtr        old, top;
@@ -672,10 +1387,26 @@ static void NPStoGPS (
   SeqAnnotPtr        sap, annot, lastsap;
   SeqDescrPtr        sdp;
 
-  top = GetTopSeqEntryForEntityID (entityID);
-  if (top == NULL || top->choice != 2) return;
-  bssp = (BioseqSetPtr) top->data.ptrvalue;
-  if (bssp == NULL || bssp->_class != BioseqseqSet_class_nuc_prot) return;
+  if (sep == NULL || sep->choice != 2) return;
+  bssp = (BioseqSetPtr) sep->data.ptrvalue;
+  if (bssp == NULL) return;
+
+  /* recursively visit components of genbank set */
+
+  if (bssp->_class == BioseqseqSet_class_genbank) {
+    for (sep = bssp->seq_set; sep != NULL; sep = sep->next) {
+      NPStoGPS (sep, entityID, filename, ngp, descr);
+    }
+    return;
+  }
+
+  if (bssp->_class != BioseqseqSet_class_nuc_prot) return;
+
+  if (SeqMgrFeaturesAreIndexed (entityID) == 0) {
+    SeqMgrIndexFeatures (entityID, NULL);
+  }
+
+  top = sep;
 
   if (StringHasNoText (filename)) {
     filename = "?";
@@ -725,65 +1456,84 @@ static void NPStoGPS (
 
   ctr = (Int2) VisitBioseqsInSep (top, NULL, NULL) + 1;
 
-  /* count mRNAs per overlapping gene */
+  if (ngp->byTscriptID) {
 
-  mrna = SeqMgrGetNextFeature (bsp, NULL, 0, FEATDEF_mRNA, &mcontext);
-  while (mrna != NULL) {
-    grp = SeqMgrGetGeneXref (mrna);
-    if (grp == NULL) {
-      gene = SeqMgrGetOverlappingGene (mrna->location, NULL);
-      if (gene != NULL) {
-        iptr = (Int4Ptr) gene->idx.scratch;
-        if (iptr == NULL) {
-          iptr = (Int4Ptr) MemNew (sizeof (Int4));
-          gene->idx.scratch = (Pointer) iptr;
-        }
-        if (iptr != NULL) {
-          (*iptr)++;
+    /* use orig_protein_id and orig_transcript_id gbquals */
+
+    mrna = SeqMgrGetNextFeature (bsp, NULL, 0, FEATDEF_mRNA, &fcontext);
+    while (mrna != NULL) {
+      cds = GetCDSByProteinID (mrna);
+      if (cds != NULL) {
+        if (ReciprocalTranscriptIDs (cds, mrna)) {
+          InstantiateMrnaIntoProt (cds, mrna, &ctr, ngp);
+          RemoveOrigIDs (cds);
+          RemoveOrigIDs (mrna);
+        } else {
+          Message (MSG_POSTERR, "CDS and mRNA have non-reciprocal protein_id/transcript_id qualifiers");
         }
       }
+      mrna = SeqMgrGetNextFeature (bsp, mrna, 0, FEATDEF_mRNA, &fcontext);
     }
-    mrna = SeqMgrGetNextFeature (bsp, mrna, 0, FEATDEF_mRNA, &mcontext);
-  }
 
-  /* only leave genes with multiple mRNAs marked */
-
-  gene = SeqMgrGetNextFeature (bsp, NULL, SEQFEAT_GENE, 0, &gcontext);
-  while (gene != NULL) {
-    iptr = (Int4Ptr) gene->idx.scratch;
-    if (iptr != NULL) {
-      if (*iptr == 1) {
-        /* if count was 1, clear scratch */
-        gene->idx.scratch = MemFree (gene->idx.scratch);
-      } else {
-        /* if count was > 1, just reset count, do not clear scratch */
-        *iptr = 0;
-      }
-    }
-    gene = SeqMgrGetNextFeature (bsp, gene, SEQFEAT_GENE, 0, &gcontext);
-  }
-
-  if (ngp->byFeatID) {
+  } else if (ngp->byFeatID) {
 
     /* trust feature ID cross-references */
 
-    sfp = SeqMgrGetNextFeature (bsp, NULL, SEQFEAT_CDREGION, 0, &fcontext);
-    while (sfp != NULL) {
-      mrna = GetmRNAByFeatureID (sfp);
+    cds = SeqMgrGetNextFeature (bsp, NULL, SEQFEAT_CDREGION, 0, &fcontext);
+    while (cds != NULL) {
+      mrna = GetmRNAByFeatureID (cds);
       if (mrna != NULL) {
-        InstantiateMrnaIntoProt (sfp, mrna, &ctr, ngp);
+        InstantiateMrnaIntoProt (cds, mrna, &ctr, ngp);
       }
-      sfp = SeqMgrGetNextFeature (bsp, sfp, SEQFEAT_CDREGION, 0, &fcontext);
+      cds = SeqMgrGetNextFeature (bsp, cds, SEQFEAT_CDREGION, 0, &fcontext);
     }
 
   } else {
 
+    /* count mRNAs per overlapping gene */
+  
+    mrna = SeqMgrGetNextFeature (bsp, NULL, 0, FEATDEF_mRNA, &mcontext);
+    while (mrna != NULL) {
+      grp = SeqMgrGetGeneXref (mrna);
+      if (grp == NULL) {
+        gene = SeqMgrGetOverlappingGene (mrna->location, NULL);
+        if (gene != NULL) {
+          iptr = (Int4Ptr) gene->idx.scratch;
+          if (iptr == NULL) {
+            iptr = (Int4Ptr) MemNew (sizeof (Int4));
+            gene->idx.scratch = (Pointer) iptr;
+          }
+          if (iptr != NULL) {
+            (*iptr)++;
+          }
+        }
+      }
+      mrna = SeqMgrGetNextFeature (bsp, mrna, 0, FEATDEF_mRNA, &mcontext);
+    }
+  
+    /* only leave genes with multiple mRNAs marked */
+  
+    gene = SeqMgrGetNextFeature (bsp, NULL, SEQFEAT_GENE, 0, &gcontext);
+    while (gene != NULL) {
+      iptr = (Int4Ptr) gene->idx.scratch;
+      if (iptr != NULL) {
+        if (*iptr == 1) {
+          /* if count was 1, clear scratch */
+          gene->idx.scratch = MemFree (gene->idx.scratch);
+        } else {
+          /* if count was > 1, just reset count, do not clear scratch */
+          *iptr = 0;
+        }
+      }
+      gene = SeqMgrGetNextFeature (bsp, gene, SEQFEAT_GENE, 0, &gcontext);
+    }
+
     /* make cDNA bioseq from mRNA feature, package with protein product */
 
     LoopThroughCDSs (bsp, &ctr, ngp);
-  }
 
-  VisitFeaturesInSep (top, NULL, RemoveFeatScratch);
+    VisitFeaturesInSep (top, NULL, RemoveFeatScratch);
+  }
 
   SeqMgrLinkSeqEntry (top, parenttype, parentptr);
 
@@ -815,10 +1565,14 @@ static void NPStoGPS (
     }
   }
 
-  sfp = SeqMgrGetNextFeature (bsp, NULL, 0, FEATDEF_mRNA, &mcontext);
-  while (sfp != NULL) {
-    LclAddMrnaTitles (sfp->product, organism, ngp->refSeqTitles);
-    sfp = SeqMgrGetNextFeature (bsp, sfp, 0, FEATDEF_mRNA, &mcontext);
+  if (ngp->smarttitle) {
+    LclMakeSmartRnaTitles (bsp, organism);
+  } else {
+    mrna = SeqMgrGetNextFeature (bsp, NULL, 0, FEATDEF_mRNA, &mcontext);
+    while (mrna != NULL) {
+      LclAddMrnaTitles (mrna->product, organism, ngp->refSeqTitles);
+      mrna = SeqMgrGetNextFeature (bsp, mrna, 0, FEATDEF_mRNA, &mcontext);
+    }
   }
 
   SeqMgrClearFeatureIndexes (bssp->idx.entityID, NULL);
@@ -897,7 +1651,7 @@ static void ProcessOneRecord (
       if (ngp->lock) {
         bsplist = LockFarComponents (sep);
       }
-    
+
       str = StringRChr (filename, DIRDELIMCHR);
       if (str != NULL) {
         str++;
@@ -929,7 +1683,21 @@ static void ProcessOneRecord (
 
       /* convert from nuc-prot set to genomic-product set */
 
-      NPStoGPS (entityID, file, ngp, descr1);
+      NPStoGPS (sep, entityID, file, ngp, descr1);
+
+      if (ngp->noncoding) {
+        PromoteNonCoding (sep, entityID, file, ngp, descr1);
+      }
+
+      if (ngp->byTscriptID) {
+        VisitFeaturesInSep (sep, NULL, RemoveOrigPrefix);
+      } 
+
+      if (ngp->removeunnecxref) {
+        SeqMgrClearFeatureIndexes (entityID, NULL);
+        SeqMgrIndexFeatures (entityID, NULL);
+        VisitFeaturesInSep (sep, NULL, RemoveUnnecessaryGeneXrefs);
+      }
 
       /* put pubs and biosources onto genomic-product set */
 
@@ -985,17 +1753,24 @@ static void ProcessOneRecord (
 
 /* Args structure contains command-line arguments */
 
-#define p_argInputPath     0
-#define r_argOutputPath    1
-#define i_argInputFile     2
-#define o_argOutputFile    3
-#define f_argFilter        4
-#define x_argSuffix        5
-#define R_argRemote        6
-#define L_argLockFar       7
-#define F_argUseFeatID     8
-#define P_argUseProtID     9
-#define D_argRefSeqTitles 10
+typedef enum {
+  p_argInputPath = 0,
+  r_argOutputPath,
+  i_argInputFile,
+  o_argOutputFile,
+  f_argFilter,
+  x_argSuffix,
+  R_argRemote,
+  L_argLockFar,
+  T_argUseTscriptID,
+  F_argUseFeatID,
+  P_argUseProtID,
+  G_argGeneralID,
+  D_argRefSeqTitles,
+  Q_argSmartTitle,
+  N_argNonCoding,
+  U_argUnnecXref
+} Arguments;
 
 
 Args myargs [] = {
@@ -1015,21 +1790,30 @@ Args myargs [] = {
     TRUE, 'R', ARG_BOOLEAN, 0.0, 0, NULL},
   {"Lock Components in Advance", "F", NULL, NULL,
     TRUE, 'L', ARG_BOOLEAN, 0.0, 0, NULL},
+  {"Map by Transcript ID", "F", NULL, NULL,
+    TRUE, 'T', ARG_BOOLEAN, 0.0, 0, NULL},
   {"Map by Feature ID", "F", NULL, NULL,
     TRUE, 'F', ARG_BOOLEAN, 0.0, 0, NULL},
   {"mRNA ID from Protein", "F", NULL, NULL,
     TRUE, 'P', ARG_BOOLEAN, 0.0, 0, NULL},
+  {"General ID Database", NULL, NULL, NULL,
+    TRUE, 'G', ARG_STRING, 0.0, 0, NULL},
   {"RefSeq mRNA Titles", "F", NULL, NULL,
     TRUE, 'D', ARG_BOOLEAN, 0.0, 0, NULL},
+  {"Special mRNA Titles", "F", NULL, NULL,
+    TRUE, 'Q', ARG_BOOLEAN, 0.0, 0, NULL},
+  {"Promote Non-Coding RNAs", "F", NULL, NULL,
+    TRUE, 'N', ARG_BOOLEAN, 0.0, 0, NULL},
+  {"Remove Unnecessary Gene Xrefs", "F", NULL, NULL,
+    TRUE, 'U', ARG_BOOLEAN, 0.0, 0, NULL},
 };
 
 Int2 Main (void)
 
 {
-  Char     app [64];
-  CharPtr  directory, filter, infile, outfile, results, suffix;
+  Char     app [64], genDbAndQual [128];
+  CharPtr  directory, filter, infile, outfile, ptr, results, suffix;
   N2GData  ngd;
-  N2GPtr   ngp;
   Boolean  remote;
 
   /* standard setup */
@@ -1069,12 +1853,24 @@ Int2 Main (void)
   }
 
   MemSet ((Pointer) &ngd, 0, sizeof (N2GData));
-  ngp = &ngd;
   ngd.failure = FALSE;
   ngd.lock = (Boolean) myargs [L_argLockFar].intvalue;
+  ngd.byTscriptID = (Boolean) myargs [T_argUseTscriptID].intvalue;
   ngd.byFeatID = (Boolean) myargs [F_argUseFeatID].intvalue;
   ngd.useProtID = (Boolean) myargs [P_argUseProtID].intvalue;
   ngd.refSeqTitles = (Boolean) myargs [D_argRefSeqTitles].intvalue;
+  ngd.smarttitle = (Boolean) myargs [Q_argSmartTitle].intvalue;
+  ngd.noncoding = (Boolean) myargs [N_argNonCoding].intvalue;
+  ngd.removeunnecxref = (Boolean) myargs [U_argUnnecXref].intvalue;
+  genDbAndQual [0] = '\0';
+  StringNCpy_0 (genDbAndQual, myargs [G_argGeneralID].strvalue, sizeof (genDbAndQual));
+  ngd.genDb = genDbAndQual;
+  ptr = StringChr (genDbAndQual, ':');
+  if (ptr != NULL) {
+    *ptr = '\0';
+    ptr++;
+    ngd.genQual = ptr;
+  }
 
   directory = (CharPtr) myargs [p_argInputPath].strvalue;
   results = (CharPtr) myargs [r_argOutputPath].strvalue;
