@@ -27,7 +27,7 @@
 *
 * Author:  Denis Vakatov, Jinghui Zhang
 *
-* $Revision: 6.1 $
+* $Revision: 6.4 $
 *
 * File Description:
 *  Draw style-dependent feature images for the feature legend map
@@ -35,6 +35,15 @@
 *
 * ----------------------------------------------------------------------------
 * $Log: fea2seg.c,v $
+* Revision 6.4  1999/10/04 17:46:22  kans
+* include vibrant.h
+*
+* Revision 6.3  1999/05/06 21:21:13  vakatov
+* Stricter type casting
+*
+* Revision 6.2  1998/06/16 18:33:46  kans
+* fixed unix compiler warnings
+*
 * Revision 6.1  1997/09/16 21:24:50  vakatov
 * SmartDrawText():  restore font after the AddTextLabel() call
 * fit_string():  use FitStringWidth() functionality
@@ -62,6 +71,7 @@
 * ----------------------------------------------------------------------------
 */
 
+#include <vibrant.h>
 #include <fea2seg.h>
 #include <fstyle.h>
 
@@ -137,7 +147,7 @@ static Boolean feature2image(SegmenT seg,
 {
   BigScalar style, shape;
   Int2      arrow = NO_ARROW;
-  Int4      x0, x1, x2, x3;
+  Int4      x0 = 0, x1 = 0, x2 = 0, x3 = 0;
   Int4      y = (limits->top + limits->bottom) / 2;
   Int4      x = (limits->left + limits->right) / 2;
 
@@ -340,7 +350,7 @@ static Boolean feature2label(SegmenT seg, Int2 feature,
 
     if (max_length < StringLen( str ))
       {
-        str = StringNCat(MemNew(max_length + 1), str, max_length);
+        str = StringNCat((char*)MemNew(max_length + 1), str, max_length);
         if ( !str )
           return FALSE;
         free_str = TRUE;
