@@ -29,7 +29,7 @@
 *   
 * Version Creation Date: 9/94
 *
-* $Revision: 6.46 $
+* $Revision: 6.49 $
 *
 * File Description:  Object manager for feature definitions
 *
@@ -702,7 +702,10 @@ static CharPtr featDefSetMemStr = "FeatDefGroupSet ::= {\n" \
 "{ typelabel \"tmRNA\" , menulabel \"Transfer-messenger RNA\" , featdef-key 95 , seqfeat-key 5 , entrygroup 3 , displaygroup 3 , molgroup na } ,\n" \
 "{ typelabel \"CloneRef\" , menulabel \"Clone Reference\" , featdef-key 96 , seqfeat-key 21 , entrygroup 0 , displaygroup 0 , molgroup na } ,\n" \
 "{ typelabel \"VariationRef\" , menulabel \"Variation Reference\" , featdef-key 97 , seqfeat-key 22 , entrygroup 0 , displaygroup 0 , molgroup na } ,\n" \
-"{ typelabel \"mobile_element\" , menulabel \"Mobile genetic element\" , featdef-key 98 , seqfeat-key 8 , entrygroup 1 , displaygroup 1 , molgroup na  } } };\n";
+"{ typelabel \"mobile_element\" , menulabel \"Mobile genetic element\" , featdef-key 98 , seqfeat-key 8 , entrygroup 1 , displaygroup 1 , molgroup na } ,\n" \
+"{ typelabel \"centromere\" , menulabel \"Centromere\" , featdef-key 99 , seqfeat-key 8 , entrygroup 1 , displaygroup 1 , molgroup na } ,\n" \
+"{ typelabel \"telomere\" , menulabel \"Telomere\" , featdef-key 100 , seqfeat-key 8 , entrygroup 1 , displaygroup 1 , molgroup na } ,\n" \
+"{ typelabel \"assembly_gap\" , menulabel \"Assembly Gap\" , featdef-key 101 , seqfeat-key 8 , entrygroup 0 , displaygroup 4 , molgroup na } } };\n";
 #endif
 
 /*****************************************************************************
@@ -1281,6 +1284,19 @@ protref:    if (prp->name != NULL)
                     return (len - buflen);
                 }
             }
+            else if(! StringICmp("variation", ifp->key))
+            {
+                /* For variation, label should be a 
+                   list of replace quals */
+                for (gbp = sfp->qual; gbp != NULL; gbp = gbp->next)
+                {
+                    if (! StringICmp("replace", gbp->qual)) {
+                        diff = LabelCopy(buf, gbp->val, buflen);
+                        buflen -= diff; buf += diff;
+                    }
+                }
+                return (len - buflen);
+            }
             else if (labeltype == OM_LABEL_CONTENT) /* show key */
             {
                 if (! StringICmp("CDS", ifp->key))
