@@ -29,7 +29,7 @@
 *   
 * Version Creation Date: 4/1/94
 *
-* $Revision: 6.0 $
+* $Revision: 6.2 $
 *
 * File Description:  Object manager for print templates
 *
@@ -40,6 +40,12 @@
 *
 *
 * $Log: objprt.c,v $
+* Revision 6.2  1998/08/26 17:43:18  kans
+* fixed -v -fd warnings in label functions
+*
+* Revision 6.1  1998/08/24 18:28:07  kans
+* removed solaris -v -fd warnings
+*
 * Revision 6.0  1997/08/25 18:50:22  madden
 * Revision changed to 6.0
 *
@@ -96,7 +102,7 @@ NLM_EXTERN Boolean LIBCALL ObjPrtAsnLoad(void)
 *
 **************************************************/
 
-NLM_EXTERN PrintTemplatePtr LIBCALL PrintTemplateNew()
+NLM_EXTERN PrintTemplatePtr LIBCALL PrintTemplateNew(void)
 {
 	PrintTemplatePtr ptp;
 	PrintTemplatePtr PNTR tmp;
@@ -325,7 +331,7 @@ erret:
 *
 **************************************************/
 
-NLM_EXTERN PrintFormatPtr LIBCALL PrintFormatNew()
+NLM_EXTERN PrintFormatPtr LIBCALL PrintFormatNew(void)
 {
 
 	return (PrintFormatPtr) MemNew(sizeof(PrintFormat));
@@ -657,7 +663,7 @@ erret:
 *
 **************************************************/
 
-NLM_EXTERN PrintFormBlockPtr LIBCALL PrintFormBlockNew()
+NLM_EXTERN PrintFormBlockPtr LIBCALL PrintFormBlockNew(void)
 {
 	return (PrintFormBlockPtr) MemNew(sizeof(PrintFormBlock));
 }
@@ -800,7 +806,7 @@ erret:AsnUnlinkType(orig);
 *
 **************************************************/
 
-NLM_EXTERN PrintFormBooleanPtr LIBCALL PrintFormBooleanNew()
+NLM_EXTERN PrintFormBooleanPtr LIBCALL PrintFormBooleanNew(void)
 {
 	return (PrintFormBooleanPtr) MemNew(sizeof(PrintFormBoolean));
 }
@@ -913,7 +919,7 @@ erret:AsnUnlinkType(orig);
 *    PrintFormEnumNew()
 *
 **************************************************/
-NLM_EXTERN PrintFormEnumPtr LIBCALL PrintFormEnumNew()
+NLM_EXTERN PrintFormEnumPtr LIBCALL PrintFormEnumNew(void)
 {
 	return (PrintFormEnumPtr) MemNew(sizeof(PrintFormEnum));
 }
@@ -1030,7 +1036,7 @@ erret:AsnUnlinkType(orig);
 *    PrintFormTextNew()
 *
 **************************************************/
-NLM_EXTERN PrintFormTextPtr LIBCALL PrintFormTextNew()
+NLM_EXTERN PrintFormTextPtr LIBCALL PrintFormTextNew(void)
 {
 	return (PrintFormTextPtr) MemNew(sizeof(PrintFormText));
 }
@@ -1132,7 +1138,7 @@ erret:AsnUnlinkType(orig);
 *    UserFormatNew()
 *
 **************************************************/
-NLM_EXTERN UserFormatPtr LIBCALL UserFormatNew()
+NLM_EXTERN UserFormatPtr LIBCALL UserFormatNew(void)
 {
 	return (UserFormatPtr) MemNew(sizeof(UserFormat));
 }
