@@ -29,7 +29,7 @@
 *   
 * Version Creation Date: 4/1/91
 *
-* $Revision: 6.1 $
+* $Revision: 6.6 $
 *
 * File Description:  Object manager for module NCBI-Seqres
 *
@@ -41,6 +41,21 @@
 *
 *
 * $Log: objres.c,v $
+* Revision 6.6  2004/05/12 20:41:56  kans
+* set aip->io_failure in several erret blocks for compatibility of old object loaders with new ones
+*
+* Revision 6.5  2004/04/01 13:43:08  lavr
+* Spell "occurred", "occurrence", and "occurring"
+*
+* Revision 6.4  1998/12/09 20:37:52  kans
+* changed compl to compr to avoid new c++ symbol collision
+*
+* Revision 6.3  1998/08/26 17:43:19  kans
+* fixed -v -fd warnings in label functions
+*
+* Revision 6.2  1998/08/24 18:28:08  kans
+* removed solaris -v -fd warnings
+*
 * Revision 6.1  1997/10/10 17:50:49  bazhin
 * Fixed bug related to freing memory in SeqGraphFree() function.
 *
@@ -101,6 +116,8 @@ static Int2 LIBCALLBACK SeqGraphLabelFunc ( Pointer data, CharPtr buffer, Int2 b
 
 NLM_EXTERN Int2 LIBCALL SeqGraphLabel (SeqGraphPtr sgp, CharPtr buffer, Int2 buflen, Uint1 content)
 {
+	Int2 rsult = 0;
+
 	if ((sgp == NULL) || (buflen < 1))
 		return 0;
 
@@ -111,9 +128,9 @@ NLM_EXTERN Int2 LIBCALL SeqGraphLabel (SeqGraphPtr sgp, CharPtr buffer, Int2 buf
 		case OM_LABEL_SUMMARY:
 		case OM_LABEL_TYPE:
 		default:
-			return LabelCopy(buffer, graphtypename, buflen);
+			rsult = LabelCopy(buffer, graphtypename, buflen);
 	}
-	return 0;
+	return rsult;
 }
 
 static Boolean loaded = FALSE;
@@ -123,7 +140,7 @@ static Boolean loaded = FALSE;
 *   SeqResAsnLoad()
 *
 *****************************************************************************/
-NLM_EXTERN Boolean LIBCALL SeqResAsnLoad ()
+NLM_EXTERN Boolean LIBCALL SeqResAsnLoad (void)
 {
     if (loaded)
         return TRUE;
@@ -162,7 +179,7 @@ NLM_EXTERN Boolean LIBCALL SeqResAsnLoad ()
 *   SeqGraphNew()
 *
 *****************************************************************************/
-NLM_EXTERN SeqGraphPtr LIBCALL SeqGraphNew ()
+NLM_EXTERN SeqGraphPtr LIBCALL SeqGraphNew (void)
 {
     return (SeqGraphPtr)MemNew(sizeof(SeqGraph));
 }
@@ -247,7 +264,7 @@ NLM_EXTERN Boolean LIBCALL SeqGraphAsnWrite (SeqGraphPtr sgp, AsnIoPtr aip, AsnT
     }
     if (sgp->flags[0])
     {
-        av.intvalue = sgp->compl;
+        av.intvalue = sgp->compr;
         if (! AsnWrite(aip, SEQ_GRAPH_comp, &av)) goto erret;
     }
     if (sgp->flags[1])
@@ -317,9 +334,9 @@ erret:
 *
 *   SeqGraphAsnRead(aip, atp)
 *   	atp is the current type (if identifier of a parent struct)
-*            assumption is readIdent has occured
+*            assumption is readIdent has occurred
 *       if atp == NULL, then assumes it stands alone and read ident
-*            has not occured.
+*            has not occurred.
 *
 *****************************************************************************/
 NLM_EXTERN SeqGraphPtr LIBCALL SeqGraphAsnRead (AsnIoPtr aip, AsnTypePtr orig)
@@ -384,7 +401,7 @@ NLM_EXTERN SeqGraphPtr LIBCALL SeqGraphAsnRead (AsnIoPtr aip, AsnTypePtr orig)
 	if (atp == SEQ_GRAPH_comp)
     {
         if (AsnReadVal(aip, atp, &av) <= 0) goto erret;
-        sgp->compl = av.intvalue;
+        sgp->compr = av.intvalue;
         sgp->flags[0] = 1;
         atp = AsnReadId(aip, amp, atp); if (atp == NULL) goto erret;
     }
@@ -484,6 +501,7 @@ ret:
 	AsnUnlinkType(orig);       /* unlink local tree */
 	return sgp;
 erret:
+    aip->io_failure = TRUE;
     sgp = SeqGraphFree(sgp);
     goto ret;
 }
