@@ -30,7 +30,7 @@
 *
 * Version Creation Date: 5/25/95
 *
-* $Revision: 6.2 $
+* $Revision: 6.3 $
 *
 * File Description:  Utilities for sim and sim2 algorithm
 *
@@ -41,6 +41,9 @@
 *
 *
 * $Log: simutil.h,v $
+* Revision 6.3  1998/09/09 11:47:43  sirotkin
+* MAXSEG to NLM_MAX_SEG to avoid RS6000 occasional conflict
+*
 * Revision 6.2  1997/09/16 21:51:29  kans
 * uncommented SIM4ALN_choice (JZ)
 *
@@ -106,7 +109,7 @@ extern "C" {
 #define DEFAULT_PAM_O   ((FloatHi) 12.0)
 #define DEFAULT_PAM_E   ((FloatHi)4.0)
 
-#define MAXSEG 10000                    /**maximal number of segments in one**/
+#define NLM_MAXSEG 10000                    /**maximal number of segments in one**/
 #define SIZE_MATRIX     128
 
 typedef struct psimpam {	/*for parameters of sim1*/
