@@ -29,7 +29,7 @@
 *
 * Version Creation Date:   1/1/91
 *
-* $Revision: 6.0 $
+* $Revision: 6.1 $
 *
 * File Description:   Active tabular text
 *
@@ -40,6 +40,9 @@
 *
 *
 * $Log: table.c,v $
+* Revision 6.1  1998/07/02 18:24:32  vakatov
+* Cleaned the code & made it pass through the C++ compilation
+*
 * Revision 6.0  1997/08/25 18:56:44  madden
 * Revision changed to 6.0
 *
@@ -177,8 +180,8 @@ static Boolean GetCellRec (TablE t, Int2 row, Int2 column, CellRec * cellRec)
   return rsult;
 }
 
+#ifdef XXX_UNUSED_STATIC_FUNC
 static Boolean SetColRec (TablE t, Int2 column, ColRec * colRec)
-
 {
   Handle     colHandles;
   ColPtr     colPtr;
@@ -202,6 +205,8 @@ static Boolean SetColRec (TablE t, Int2 column, ColRec * colRec)
   }
   return rsult;
 }
+#endif /* XXX_UNUSED_STATIC_FUNC */
+
 
 static Boolean GetColRec (TablE t, Int2 column, ColRec * colRec)
 
