@@ -1,4 +1,4 @@
-/*  $Id: vibmouse.c,v 6.1 1997/11/26 21:30:31 vakatov Exp $
+/*  $Id: vibmouse.c,v 6.4 2001/03/28 01:40:48 juran Exp $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
@@ -31,6 +31,15 @@
 *
 * ===========================================================================
 * $Log: vibmouse.c,v $
+* Revision 6.4  2001/03/28 01:40:48  juran
+* "for (...) { continue; }", squelch warning
+*
+* Revision 6.3  1999/04/06 14:23:25  lewisg
+* add opengl replacement for viewer3d
+*
+* Revision 6.2  1998/07/02 18:24:34  vakatov
+* Cleaned the code & made it pass through the C++ compilation
+*
 * Revision 6.1  1997/11/26 21:30:31  vakatov
 * Fixed errors and warnings issued by C and C++ (GNU and Sun) compilers
 *
@@ -55,7 +64,7 @@
 #else
 #include <stdarg.h>
 #endif
-
+#include <vibrant.h>  /* move out of header.  lyg */
 #include <vibmouse.h>
 
 
@@ -296,6 +305,9 @@ static void MA_Execute(MAPtr ma, PoinT pt, enumMAction type)
           if (PointDist(pt, ma->last_pos) <= CLICK_RADIUS)
             type = MA_Click;
           break;
+
+        default:
+          break;
         }
     }
 
@@ -578,7 +590,10 @@ extern Boolean MA_UnsetGroup(MA_GroupPtr group)
     NodePtr node;
     for (node = ma->active_groups;
          node  &&  node->elem != group;
-         node = ListGetNext( node ));
+         node = ListGetNext( node ))
+    {
+      continue;
+    }
 
     if ( !node )
       return FALSE;
